@@ -263,11 +263,15 @@ void Kwave::MainWidget::dropEvent(QDropEvent *event)
 	    if (Kwave::CodecManager::canDecode(mimetype)) {
 		if (first) {
 		    // first dropped URL -> open in this window
-		    emit sigCommand(_("open(") + filename + _(")"));
+		    emit sigCommand(_("open(") +
+		                    Kwave::Parser::escape(filename) +
+		                    _(")"));
 		    first = false;
 		} else {
 		    // all others -> open a new window
-		    emit sigCommand(_("newwindow(") + filename + _(")"));
+		    emit sigCommand(_("newwindow(") +
+		                    Kwave::Parser::escape(filename) +
+		                    _(")"));
 		}
 	    }
 	}
