@@ -110,6 +110,10 @@ void addDataStrings(KAboutData &aboutdata)
                      ki18n("Author of the 'audiofile' library"),
                      "mpruett@sgi.com",
                      "http://www.68k.org/~michael/audiofile/");
+    aboutdata.addCredit(ki18n("Carlos R."),
+                     ki18n("Spanish translation"),
+                     "pureacetone@gmail.com",
+                     0);
     aboutdata.addCredit(ki18n("Erik de Castro Lopo"),
                      ki18n("Author of the 'sndfile' library"),
                      "erikd@zip.com.au",
@@ -135,7 +139,9 @@ int main( int argc, char **argv )
 {
     static KCmdLineOptions options;
 
-    options.add("!+files", ki18n("List of audio files"), 0 );
+    options.add("disable-splashscreen", ki18n("Disable the Splash Screen"), 0);
+    options.add("iconic",               ki18n("Start Kwave iconified"), 0);
+    options.add("!+files",              ki18n("List of audio files"), 0 );
 
     KAboutData about(
 	PACKAGE, "",
@@ -170,12 +176,19 @@ int main( int argc, char **argv )
 
     if (!KUniqueApplication::start()) {
 	qWarning("Kwave is already running!");
-	exit(0);
+	return 0;
     }
 
+    // check whether to start up without splash screen or in iconic mode
+    // which implicitly also disables the splash screen
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    bool show_splash = !(args && (args->isSet("disable-splashscreen") ||
+                                  args->isSet("iconic")));
+
     Kwave::App app;
     Kwave::Splash splash(_("pics/kwave-splash.png"));
-    splash.show();
+
+    if (show_splash) splash.show();
 
     int retval = app.exec();
 
