@@ -216,7 +216,7 @@ void Kwave::MenuManager::clearNumberedMenu(const QString &uid)
 
 //***************************************************************************
 void Kwave::MenuManager::addNumberedMenuEntry(const QString &uid,
-	const QString &entry)
+                                              const QString &entry)
 {
     Q_ASSERT(entry.length());
     if (!entry.length()) return;
@@ -225,7 +225,8 @@ void Kwave::MenuManager::addNumberedMenuEntry(const QString &uid,
     Kwave::MenuNode *node = (m_menu_root) ? m_menu_root->findUID(uid) : 0;
     if (node) {
 	QString cmd     = node->command();
-	QString command = cmd.contains(_("%1")) ? cmd.arg(entry) : cmd;
+	QString command = cmd.contains(_("%1")) ?
+	    cmd.arg(Kwave::Parser::escape(entry)) : cmd;
 
 	node->insertLeaf(entry, command, 0, QString());
     } else
