@@ -19,18 +19,19 @@
 
 #include <math.h>
 
-#include <QApplication>
-#include <QPainter>
-#include <QResizeEvent>
-#include <QMouseEvent>
-#include <QPaintEvent>
-#include <QVBoxLayout>
+#include <QtGui/QApplication>
+#include <QtGui/QPainter>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPaintEvent>
+#include <QtGui/QVBoxLayout>
 
 #include "libkwave/Label.h"
 #include "libkwave/MetaDataList.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 
-#include "OverViewWidget.h"
+#include "libgui/OverViewWidget.h"
 
 /**
  * interval for limiting the number of repaints per second [ms]
@@ -49,28 +50,30 @@
 
 //***************************************************************************
 //***************************************************************************
-OverViewWidget::WorkerThread::WorkerThread(OverViewWidget *overview)
+Kwave::OverViewWidget::WorkerThread::WorkerThread(
+    Kwave::OverViewWidget *overview)
     :QThread(), m_overview(overview)
 {
 }
 
 //***************************************************************************
-OverViewWidget::WorkerThread::~WorkerThread()
+Kwave::OverViewWidget::WorkerThread::~WorkerThread()
 {
     Q_ASSERT(!isRunning());
 }
 
 //***************************************************************************
-void OverViewWidget::WorkerThread::run()
+void Kwave::OverViewWidget::WorkerThread::run()
 {
     if (m_overview) m_overview->calculateBitmap();
 }
 
 //***************************************************************************
 //***************************************************************************
-OverViewWidget::OverViewWidget(SignalManager &signal, QWidget *parent)
-    :ImageView(parent), m_view_offset(0), m_view_width(0), m_signal_length(0),
-     m_selection_start(0), m_selection_length(0),
+Kwave::OverViewWidget::OverViewWidget(Kwave::SignalManager &signal,
+                                      QWidget *parent)
+    :Kwave::ImageView(parent), m_view_offset(0), m_view_width(0),
+     m_signal_length(0), m_selection_start(0), m_selection_length(0),
      m_playback_position(0), m_last_offset(0), m_cache(signal),
      m_repaint_timer(), m_labels(), m_worker_thread(this)
 {
@@ -106,7 +109,7 @@ OverViewWidget::OverViewWidget(SignalManager &signal, QWidget *parent)
 }
 
 //***************************************************************************
-OverViewWidget::~OverViewWidget()
+Kwave::OverViewWidget::~OverViewWidget()
 {
     // check: start() must be called from the GUI thread only!
     Q_ASSERT(this->thread() == QThread::currentThread());
@@ -117,13 +120,13 @@ OverViewWidget::~OverViewWidget()
 }
 
 //***************************************************************************
-void OverViewWidget::mouseMoveEvent(QMouseEvent *e)
+void Kwave::OverViewWidget::mouseMoveEvent(QMouseEvent *e)
 {
     mousePressEvent(e);
 }
 
 //***************************************************************************
-void OverViewWidget::mousePressEvent(QMouseEvent *e)
+void Kwave::OverViewWidget::mousePressEvent(QMouseEvent *e)
 {
     Q_ASSERT(e);
     if (!e) return;
@@ -144,7 +147,7 @@ void OverViewWidget::mousePressEvent(QMouseEvent *e)
 }
 
 //***************************************************************************
-void OverViewWidget::mouseDoubleClickEvent(QMouseEvent *e)
+void Kwave::OverViewWidget::mouseDoubleClickEvent(QMouseEvent *e)
 {
     Q_ASSERT(e);
     if (!e) return;
@@ -162,17 +165,17 @@ void OverViewWidget::mouseDoubleClickEvent(QMouseEvent *e)
 
     if (e->modifiers() == Qt::NoModifier) {
 	// double click without shift => zoom in
-	emit sigCommand("view:zoom_in()");
+	emit sigCommand(_("view:zoom_in()"));
     } else if (e->modifiers() == Qt::ShiftModifier) {
 	// double click with shift => zoom out
-	emit sigCommand("view:zoom_out()");
+	emit sigCommand(_("view:zoom_out()"));
     }
 
     e->accept();
 }
 
 //***************************************************************************
-sample_index_t OverViewWidget::pixels2offset(int pixels)
+sample_index_t Kwave::OverViewWidget::pixels2offset(int pixels)
 {
     int width = this->width();
     if (!width) return 0;
@@ -186,8 +189,9 @@ sample_index_t OverViewWidget::pixels2offset(int pixels)
 }
 
 //***************************************************************************
-void OverViewWidget::setRange(sample_index_t offset, sample_index_t viewport,
-                              sample_index_t total)
+void Kwave::OverViewWidget::setRange(sample_index_t offset,
+                                     sample_index_t viewport,
+                                     sample_index_t total)
 {
     m_view_offset   = offset;
     m_view_width    = viewport;
@@ -197,7 +201,8 @@ void OverViewWidget::setRange(sample_index_t offset, sample_index_t viewport,
 }
 
 //***************************************************************************
-void OverViewWidget::setSelection(sample_index_t offset, sample_index_t length)
+void Kwave::OverViewWidget::setSelection(sample_index_t offset,
+                                         sample_index_t length)
 {
     m_selection_start  = offset;
     m_selection_length = length;
@@ -206,25 +211,25 @@ void OverViewWidget::setSelection(sample_index_t offset, sample_index_t length)
 }
 
 //***************************************************************************
-void OverViewWidget::resizeEvent(QResizeEvent *)
+void Kwave::OverViewWidget::resizeEvent(QResizeEvent *)
 {
     refreshBitmap();
 }
 
 //***************************************************************************
-QSize OverViewWidget::minimumSize() const
+QSize Kwave::OverViewWidget::minimumSize() const
 {
     return QSize(30, 30);
 }
 
 //***************************************************************************
-QSize OverViewWidget::sizeHint() const
+QSize Kwave::OverViewWidget::sizeHint() const
 {
     return minimumSize();
 }
 
 //***************************************************************************
-void OverViewWidget::overviewChanged()
+void Kwave::OverViewWidget::overviewChanged()
 {
     // check: start() must be called from the GUI thread only!
     Q_ASSERT(this->thread() == QThread::currentThread());
@@ -245,13 +250,13 @@ void OverViewWidget::overviewChanged()
 }
 
 //***************************************************************************
-void OverViewWidget::metaDataChanged(Kwave::MetaDataList meta)
+void Kwave::OverViewWidget::metaDataChanged(Kwave::MetaDataList meta)
 {
     // check: start() must be called from the GUI thread only!
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    m_labels = LabelList(meta);
+    m_labels = Kwave::LabelList(meta);
 
     // only re-start the repaint timer, this hides some GUI update artifacts
     if (!m_repaint_timer.isActive()) {
@@ -262,7 +267,7 @@ void OverViewWidget::metaDataChanged(Kwave::MetaDataList meta)
 }
 
 //***************************************************************************
-void OverViewWidget::playbackPositionChanged(sample_index_t pos)
+void Kwave::OverViewWidget::playbackPositionChanged(sample_index_t pos)
 {
     // check: start() must be called from the GUI thread only!
     Q_ASSERT(this->thread() == QThread::currentThread());
@@ -300,13 +305,14 @@ void OverViewWidget::playbackPositionChanged(sample_index_t pos)
 }
 
 //***************************************************************************
-void OverViewWidget::playbackStopped()
+void Kwave::OverViewWidget::playbackStopped()
 {
     playbackPositionChanged(0);
 }
 
 //***************************************************************************
-void OverViewWidget::drawMark(QPainter &p, int x, int height, QColor color)
+void Kwave::OverViewWidget::drawMark(QPainter &p, int x, int height,
+                                     QColor color)
 {
     QPolygon mark;
     const int w = 5;
@@ -324,7 +330,7 @@ void OverViewWidget::drawMark(QPainter &p, int x, int height, QColor color)
 }
 
 //***************************************************************************
-void OverViewWidget::refreshBitmap()
+void Kwave::OverViewWidget::refreshBitmap()
 {
     // check: start() must be called from the GUI thread only!
     Q_ASSERT(this->thread() == QThread::currentThread());
@@ -343,7 +349,7 @@ void OverViewWidget::refreshBitmap()
 }
 
 //***************************************************************************
-void OverViewWidget::calculateBitmap()
+void Kwave::OverViewWidget::calculateBitmap()
 {
     sample_index_t length = m_signal_length;
     if (m_view_offset + m_view_width > m_signal_length) {
@@ -395,7 +401,7 @@ void OverViewWidget::calculateBitmap()
 
     // draw labels
     unsigned int last_label_pos = width + 1;;
-    foreach (const Label &label, m_labels) {
+    foreach (const Kwave::Label &label, m_labels) {
 	sample_index_t pos = label.pos();
 	unsigned int x = static_cast<unsigned int>(
 	    static_cast<double>(pos) * scale);
