@@ -19,22 +19,21 @@
 #include <errno.h>
 #include <math.h>
 #include <stdlib.h>
-#include <sys/time.h>
 
-#include <QBitmap>
-#include <QContextMenuEvent>
-#include <QDragLeaveEvent>
-#include <QEvent>
-#include <QFrame>
-#include <QDragEnterEvent>
-#include <QDragMoveEvent>
-#include <QDropEvent>
-#include <QMenu>
-#include <QMouseEvent>
-#include <QPaintEvent>
-#include <QResizeEvent>
-#include <QTime>
-#include <QToolTip>
+#include <QtGui/QBitmap>
+#include <QtGui/QContextMenuEvent>
+#include <QtGui/QDragLeaveEvent>
+#include <QtCore/QEvent>
+#include <QtGui/QFrame>
+#include <QtGui/QDragEnterEvent>
+#include <QtGui/QDragMoveEvent>
+#include <QtGui/QDropEvent>
+#include <QtGui/QMenu>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPaintEvent>
+#include <QtGui/QResizeEvent>
+#include <QtCore/QTime>
+#include <QtGui/QToolTip>
 
 #include <kcursor.h>
 #include <kglobal.h>
@@ -45,16 +44,11 @@
 
 #include "libkwave/ApplicationContext.h"
 #include "libkwave/ClipBoard.h"
-#include "libkwave/FileInfo.h"
-#include "libkwave/Label.h"
 #include "libkwave/LabelList.h"
-#include "libkwave/MultiTrackReader.h"
-#include "libkwave/Parser.h"
-#include "libkwave/SampleReader.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 #include "libkwave/Track.h"
 
-#include "libgui/MultiStateWidget.h"
 // #include "libgui/ShortcutWrapper.h"
 #include "libgui/SignalView.h"
 #include "libgui/SignalWidget.h"
@@ -93,8 +87,10 @@
 #define REPAINT_INTERVAL 125
 
 //***************************************************************************
-SignalWidget::SignalWidget(QWidget *parent, Kwave::ApplicationContext &context,
-                           QVBoxLayout *upper_dock, QVBoxLayout *lower_dock)
+Kwave::SignalWidget::SignalWidget(QWidget *parent,
+                                  Kwave::ApplicationContext &context,
+                                  QVBoxLayout *upper_dock,
+                                  QVBoxLayout *lower_dock)
     :QWidget(parent),
      m_context(context),
      m_views(),
@@ -109,7 +105,7 @@ SignalWidget::SignalWidget(QWidget *parent, Kwave::ApplicationContext &context,
 //    qDebug("SignalWidget::SignalWidget()");
 
     // connect to the signal manager's signals
-    SignalManager *sig = m_context.signalManager();
+    Kwave::SignalManager *sig = m_context.signalManager();
 
     connect(sig,  SIGNAL(sigTrackInserted(unsigned int, Kwave::Track *)),
             this, SLOT( slotTrackInserted(unsigned int, Kwave::Track *)));
@@ -141,31 +137,31 @@ SignalWidget::SignalWidget(QWidget *parent, Kwave::ApplicationContext &context,
 }
 
 //***************************************************************************
-bool SignalWidget::isOK()
+bool Kwave::SignalWidget::isOK()
 {
     return true;
 }
 
 //***************************************************************************
-SignalWidget::~SignalWidget()
+Kwave::SignalWidget::~SignalWidget()
 {
 }
 
 //***************************************************************************
-void SignalWidget::setZoomAndOffset(double zoom, sample_index_t offset)
+void Kwave::SignalWidget::setZoomAndOffset(double zoom, sample_index_t offset)
 {
     foreach (QPointer<Kwave::SignalView> view, m_views)
 	view->setZoomAndOffset(zoom, offset);
 }
 
 //***************************************************************************
-void SignalWidget::forwardCommand(const QString &command)
+void Kwave::SignalWidget::forwardCommand(const QString &command)
 {
     emit sigCommand(command);
 }
 
 //***************************************************************************
-void SignalWidget::requestRepaint(Kwave::SignalView *view)
+void Kwave::SignalWidget::requestRepaint(Kwave::SignalView *view)
 {
     // add the view to the repaint queue (if not already there)
     if (!m_repaint_queue.contains(view))
@@ -180,7 +176,7 @@ void SignalWidget::requestRepaint(Kwave::SignalView *view)
 }
 
 //***************************************************************************
-void SignalWidget::repaintTimerElapsed()
+void Kwave::SignalWidget::repaintTimerElapsed()
 {
     while (!m_repaint_queue.isEmpty())
     {
@@ -191,15 +187,16 @@ void SignalWidget::repaintTimerElapsed()
 }
 
 //***************************************************************************
-void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
+void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 {
     Q_ASSERT(e);
 
-    SignalManager *manager = m_context.signalManager();
+    Kwave::SignalManager *manager = m_context.signalManager();
     bool have_signal = manager && !manager->isEmpty();
     if (!have_signal)return;
     bool have_selection = manager && (manager->selection().length() > 1);
-    bool have_labels = manager && !(LabelList(manager->metaData()).isEmpty());
+    bool have_labels = manager &&
+	!(Kwave::LabelList(manager->metaData()).isEmpty());
 
     QMenu *context_menu = new QMenu(this);
     Q_ASSERT(context_menu);
@@ -212,7 +209,7 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     // undo
     QAction *action;
     action = context_menu->addAction(
-	icon_loader.loadIcon("edit-undo", KIconLoader::Toolbar),
+	icon_loader.loadIcon(_("edit-undo"), KIconLoader::Toolbar),
 	i18n("&Undo"), this, SLOT(contextMenuEditUndo()),
 	Qt::CTRL + Qt::Key_Z);
     Q_ASSERT(action);
@@ -222,7 +219,7 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 
     // redo
     action = context_menu->addAction(
-	icon_loader.loadIcon("edit-redo", KIconLoader::Toolbar),
+	icon_loader.loadIcon(_("edit-redo"), KIconLoader::Toolbar),
 	i18n("&Redo"), this, SLOT(contextMenuEditRedo()),
 	Qt::CTRL + Qt::Key_Y);
     Q_ASSERT(action);
@@ -233,22 +230,22 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 
     // cut/copy/paste
     QAction *action_cut = context_menu->addAction(
-	icon_loader.loadIcon("edit-cut", KIconLoader::Toolbar),
+	icon_loader.loadIcon(_("edit-cut"), KIconLoader::Toolbar),
 	i18n("Cu&t"), this, SLOT(contextMenuEditCut()),
 	Qt::CTRL + Qt::Key_X);
     QAction *action_copy = context_menu->addAction(
-	icon_loader.loadIcon("edit-copy", KIconLoader::Toolbar),
+	icon_loader.loadIcon(_("edit-copy"), KIconLoader::Toolbar),
 	i18n("&Copy"), this, SLOT(contextMenuEditCopy()),
 	Qt::CTRL + Qt::Key_C);
     QAction *action_paste = context_menu->addAction(
-	icon_loader.loadIcon("edit-paste", KIconLoader::Toolbar),
+	icon_loader.loadIcon(_("edit-paste"), KIconLoader::Toolbar),
 	i18n("&Paste"), this, SLOT(contextMenuEditPaste()),
 	Qt::CTRL + Qt::Key_V);
     context_menu->addSeparator();
     if (action_cut)   action_cut->setEnabled(have_selection);
     if (action_copy)  action_copy->setEnabled(have_selection);
     if (action_paste)
-	action_paste->setEnabled(!ClipBoard::instance().isEmpty());
+	action_paste->setEnabled(!Kwave::ClipBoard::instance().isEmpty());
 
     int mouse_x = mapFromGlobal(e->globalPos()).x();
     int mouse_y = mapFromGlobal(e->globalPos()).y();
@@ -264,7 +261,7 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 
     // Selection / &Save
     QAction *action_select_save = submenu_select->addAction(
-	icon_loader.loadIcon("document-save", KIconLoader::Toolbar),
+	icon_loader.loadIcon(_("document-save"), KIconLoader::Toolbar),
 	i18n("&Save..."), this, SLOT(contextMenuSaveSelection()));
     Q_ASSERT(action_select_save);
     if (!action_select_save) return;
@@ -332,7 +329,7 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 }
 
 //***************************************************************************
-void SignalWidget::wheelEvent(QWheelEvent *event)
+void Kwave::SignalWidget::wheelEvent(QWheelEvent *event)
 {
     if (!event) return;
 
@@ -357,7 +354,7 @@ void SignalWidget::wheelEvent(QWheelEvent *event)
 }
 
 //***************************************************************************
-void SignalWidget::setVerticalZoom(double zoom)
+void Kwave::SignalWidget::setVerticalZoom(double zoom)
 {
     if (zoom > VERTICAL_ZOOM_MAX) zoom = VERTICAL_ZOOM_MAX;
     if (zoom < VERTICAL_ZOOM_MIN) zoom = VERTICAL_ZOOM_MIN;
@@ -381,15 +378,15 @@ void SignalWidget::setVerticalZoom(double zoom)
 }
 
 //***************************************************************************
-int SignalWidget::viewPortWidth()
+int Kwave::SignalWidget::viewPortWidth()
 {
     if (m_views.isEmpty()) return width(); // if empty
     return m_layout.cellRect(0, 1).width();
 }
 
 //***************************************************************************
-void SignalWidget::insertRow(int index, Kwave::SignalView *view,
-                             QWidget *controls)
+void Kwave::SignalWidget::insertRow(int index, Kwave::SignalView *view,
+                                    QWidget *controls)
 {
     const int rows = m_layout.rowCount();
     const int cols = m_layout.columnCount();
@@ -419,7 +416,7 @@ void SignalWidget::insertRow(int index, Kwave::SignalView *view,
 }
 
 //***************************************************************************
-void SignalWidget::deleteRow(int index)
+void Kwave::SignalWidget::deleteRow(int index)
 {
     const int rows = m_layout.rowCount();
     const int cols = m_layout.columnCount();
@@ -441,7 +438,8 @@ void SignalWidget::deleteRow(int index)
 }
 
 //***************************************************************************
-void SignalWidget::insertView(Kwave::SignalView *view, QWidget *controls)
+void Kwave::SignalWidget::insertView(Kwave::SignalView *view,
+                                     QWidget *controls)
 {
     Q_ASSERT(m_upper_dock);
     Q_ASSERT(m_lower_dock);
@@ -577,7 +575,8 @@ void SignalWidget::insertView(Kwave::SignalView *view, QWidget *controls)
 }
 
 //***************************************************************************
-void SignalWidget::slotTrackInserted(unsigned int index, Kwave::Track *track)
+void Kwave::SignalWidget::slotTrackInserted(unsigned int index,
+                                            Kwave::Track *track)
 {
     Q_ASSERT(track);
     if (!track) return;
@@ -609,7 +608,7 @@ void SignalWidget::slotTrackInserted(unsigned int index, Kwave::Track *track)
 }
 
 //***************************************************************************
-void SignalWidget::slotTrackDeleted(unsigned int index)
+void Kwave::SignalWidget::slotTrackDeleted(unsigned int index)
 {
     // loop over all views, delete those that are bound to this track
     // and adjust the index of the following ones
@@ -652,7 +651,7 @@ void SignalWidget::slotTrackDeleted(unsigned int index)
 }
 
 //***************************************************************************
-// void SignalWidget::parseKey(int key)
+// void Kwave::SignalWidget::parseKey(int key)
 // {
 //     if ((key < 0) || (key >= m_lamps.count()))
 // 	return;
