@@ -17,31 +17,32 @@
 
 #include "config.h"
 
-#include <QMenu>
-#include <QPainter>
-#include <QPalette>
-#include <QResizeEvent>
-#include <QTime>
-#include <QVBoxLayout>
+#include <QtGui/QMenu>
+#include <QtGui/QPainter>
+#include <QtGui/QPalette>
+#include <QtGui/QResizeEvent>
+#include <QtCore/QTime>
+#include <QtGui/QVBoxLayout>
 
 #include <kiconloader.h>
 
 #include "libkwave/Label.h"
 #include "libkwave/LabelList.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 #include "libkwave/Track.h"
 
-#include "LabelItem.h"
-#include "MultiStateWidget.h"
-#include "TrackView.h"
-#include "ViewItem.h"
+#include "libgui/LabelItem.h"
+#include "libgui/MultiStateWidget.h"
+#include "libgui/TrackView.h"
+#include "libgui/ViewItem.h"
 
 /** minimum height of the view in pixel */
 #define MINIMUM_HEIGHT 100
 
 //***************************************************************************
 Kwave::TrackView::TrackView(QWidget *parent, QWidget *controls,
-                            SignalManager *signal_manager,
+                            Kwave::SignalManager *signal_manager,
                             Kwave::Track *track)
     :Kwave::SignalView(parent, controls, signal_manager,
                        Kwave::SignalView::AboveTrackTop),
@@ -71,7 +72,7 @@ Kwave::TrackView::TrackView(QWidget *parent, QWidget *controls,
 	Q_ASSERT(layout);
 	if (!layout) return;
 
-	MultiStateWidget *msw = new MultiStateWidget(0, 0);
+	Kwave::MultiStateWidget *msw = new Kwave::MultiStateWidget(0, 0);
 	Q_ASSERT(msw);
 	if (!msw) {
 	    delete layout;
@@ -79,8 +80,8 @@ Kwave::TrackView::TrackView(QWidget *parent, QWidget *controls,
 	}
 
 	// add a bitmap for off (0 and on (1)
-	msw->addPixmap("light_off.xpm");
-	msw->addPixmap("light_on.xpm");
+	msw->addPixmap(_("light_off.xpm"));
+	msw->addPixmap(_("light_on.xpm"));
 
 	// connect widget <-> track
 	connect(
@@ -175,10 +176,12 @@ QSharedPointer<Kwave::ViewItem> Kwave::TrackView::findItem(const QPoint &pos)
 
     // our display can contain labels -> find the nearest label
     double d_min = tolerance;
-    Label nearest_label;
+    Kwave::Label nearest_label;
     int  nearest_index = 0;
     int index = 0;
-    foreach (const Label &label, LabelList(m_signal_manager->metaData())) {
+    foreach (const Kwave::Label &label,
+	Kwave::LabelList(m_signal_manager->metaData()))
+    {
 	double pos = static_cast<double>(label.pos());
 	double d = (pos > offset) ? (pos - offset) : (offset - pos);
 	if (d < d_min) {
@@ -211,7 +214,7 @@ void Kwave::TrackView::handleContextMenu(const QPoint &pos, QMenu *menu)
 
     // add label
     QAction *action_label_new = submenu_label->addAction(
-	icon_loader.loadIcon("list-add", KIconLoader::Toolbar),
+	icon_loader.loadIcon(_("list-add"), KIconLoader::Toolbar),
 	i18n("&New"), this, SLOT(contextMenuLabelNew()));
     Q_ASSERT(action_label_new);
     if (!action_label_new) return;
@@ -223,7 +226,7 @@ void Kwave::TrackView::handleContextMenu(const QPoint &pos, QMenu *menu)
 //***************************************************************************
 void Kwave::TrackView::contextMenuLabelNew()
 {
-    emit sigCommand(QString("add_label(%1)").arg(m_mouse_click_position));
+    emit sigCommand(_("add_label(%1)").arg(m_mouse_click_position));
 }
 
 //***************************************************************************
@@ -343,7 +346,9 @@ void Kwave::TrackView::paintEvent(QPaintEvent *)
 
 	int last_marker = -1;
 	const sample_index_t visible = pixels2samples(width);
-	foreach (const Label &label, LabelList(m_signal_manager->metaData())) {
+	foreach (const Kwave::Label &label,
+	         Kwave::LabelList(m_signal_manager->metaData()))
+	{
 	    sample_index_t pos = label.pos();
 	    if (pos < m_offset)           continue; // outside left
 	    if (pos > m_offset + visible) break;    // far outside right, done
