@@ -20,11 +20,11 @@
 
 #include "config.h"
 
-#include <QImage>
-#include <QObject>
-#include <QPoint>
-#include <QPointer>
-#include <QWidget>
+#include <QtGui/QImage>
+#include <QtCore/QObject>
+#include <QtCore/QPoint>
+#include <QtCore/QPointer>
+#include <QtGui/QWidget>
 
 #include "kdemacros.h"
 
@@ -35,10 +35,11 @@
 
 class QPaintEvent;
 class QResizeEvent;
-class SignalManager; // forward declaration
 
-namespace Kwave {
+namespace Kwave
+{
 
+    class SignalManager; // forward declaration
     class Track;
 
     class KDE_EXPORT TrackView: public SignalView
@@ -53,7 +54,7 @@ namespace Kwave {
 	 * @param track the track object this view is bound to
 	 */
 	TrackView(QWidget *parent, QWidget *controls,
-	          SignalManager *signal_manager,
+	          Kwave::SignalManager *signal_manager,
 	          Kwave::Track *track);
 
 	/** Destructor */
@@ -91,9 +92,9 @@ namespace Kwave {
 	/**
 	 * Tries to find the nearest item that is visible in this view
 	 * at a given position
-	 * 
+	 *
 	 * @param pos position to look at, relative to view [pixels]
-	 * @return the nearest ViewObject in range 
+	 * @return the nearest ViewObject in range
 	 *         or a null pointer if nothing found
 	 */
 	virtual QSharedPointer<Kwave::ViewItem> findItem(const QPoint &pos);
@@ -128,7 +129,7 @@ namespace Kwave {
     private:
 
 	/** reference to the signal manager */
-	QPointer<SignalManager> m_signal_manager;
+	QPointer<Kwave::SignalManager> m_signal_manager;
 
 	/** the track pixmap */
 	Kwave::TrackPixmap m_pixmap;
@@ -167,3 +168,6 @@ namespace Kwave {
 }
 
 #endif /* _TRACK_VIEW_H_ */
+
+//***************************************************************************
+//***************************************************************************
