@@ -21,10 +21,11 @@
 #include <unistd.h>
 #include <sys/types.h>
 
-#include <QFile>
-#include <QFileInfo>
-#include <QMutexLocker>
-#include <QString>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QMutexLocker>
+#include <QtCore/QString>
 
 #ifdef HAVE_SYSINFO
 #include <linux/kernel.h> // for struct sysinfo
@@ -37,8 +38,8 @@
 
 #include "libkwave/memcpy.h"
 #include "libkwave/MemoryManager.h"
-
-#include "SwapFile.h"
+#include "libkwave/String.h"
+#include "libkwave/SwapFile.h"
 
 /** number of elements in the m_cached_swap list */
 #define CACHE_SIZE 16
@@ -52,7 +53,7 @@ Kwave::Handle Kwave::MemoryManager::m_last_handle = 0;
 //***************************************************************************
 Kwave::MemoryManager::MemoryManager()
     :m_physical_allocated(0), m_physical_limit(0), m_virtual_allocated(0),
-     m_virtual_limit(0), m_swap_dir("/tmp"), m_undo_limit(0),
+     m_virtual_limit(0), m_swap_dir(_("/tmp")), m_undo_limit(0),
      m_physical(), m_unmapped_swap(), m_mapped_swap(),
      m_cached_swap(), m_lock()
 {
@@ -138,7 +139,7 @@ unsigned int Kwave::MemoryManager::totalPhysical()
 
 #ifdef HAVE_SYSINFO
     // get the physically installed memory
-    quint64 installed_physical = total;
+    quint64 installed_physical;
     struct sysinfo info;
 
     sysinfo(&info);
@@ -308,13 +309,13 @@ size_t Kwave::MemoryManager::virtualUsed()
 {
     size_t used = 0;
 
-    foreach (const SwapFile *swapfile, m_cached_swap.values())
+    foreach (const Kwave::SwapFile *swapfile, m_cached_swap.values())
 	used += (swapfile->size() >> 10) + 1;
 
-    foreach (const SwapFile *swapfile, m_mapped_swap.values())
+    foreach (const Kwave::SwapFile *swapfile, m_mapped_swap.values())
 	used += (swapfile->size() >> 10) + 1;
 
-    foreach (const SwapFile *swapfile, m_unmapped_swap.values())
+    foreach (const Kwave::SwapFile *swapfile, m_unmapped_swap.values())
 	used += (swapfile->size() >> 10) + 1;
 
     return (used >> 10);
@@ -327,9 +328,9 @@ QString Kwave::MemoryManager::nextSwapFileName(Kwave::Handle handle)
     QString filename;
 
     // these 6 'X' chars are needed for mkstemp !
-    filename = "kwave-swapfile-%1-XXXXXX";
+    filename = _("kwave-swapfile-%1-XXXXXX");
     filename = filename.arg(static_cast<unsigned int>(handle),
-                            10, 10, QChar('0'));
+                            10, 10, QLatin1Char('0'));
 
     file.setFile(m_swap_dir, filename);
     return file.absoluteFilePath();
@@ -356,7 +357,7 @@ Kwave::Handle Kwave::MemoryManager::allocateVirtual(size_t size)
     if (!handle) return 0; // out of handles :-(
 
     // try to allocate
-    SwapFile *swap = new SwapFile(nextSwapFileName(handle));
+    Kwave::SwapFile *swap = new Kwave::SwapFile(nextSwapFileName(handle));
     Q_ASSERT(swap);
     if (!swap) return 0; // out of memory :-(
 
@@ -395,7 +396,7 @@ bool Kwave::MemoryManager::convertToVirtual(Kwave::Handle handle,
     if (!temp_handle) return false;
 
     // copy old stuff to new location
-    SwapFile *swap = m_unmapped_swap[temp_handle];
+    Kwave::SwapFile *swap = m_unmapped_swap[temp_handle];
     swap->write(0, mem.m_data, mem.m_size);
 
     // free the old physical memory
@@ -423,7 +424,7 @@ bool Kwave::MemoryManager::convertToPhysical(Kwave::Handle handle,
     // check: it must be in physical space, otherwise the rest makes no sense
     Q_ASSERT(m_unmapped_swap.contains(handle));
     if (!m_unmapped_swap.contains(handle)) return false;
-    SwapFile *swap = m_unmapped_swap[handle];
+    Kwave::SwapFile *swap = m_unmapped_swap[handle];
     Q_ASSERT(swap);
     if (!swap) return false;
 
@@ -476,7 +477,7 @@ void Kwave::MemoryManager::tryToMakePhysical(Kwave::Handle handle)
     Q_ASSERT(m_unmapped_swap.contains(handle));
     if (!m_unmapped_swap.contains(handle)) return;
 
-    const SwapFile *swap = m_unmapped_swap[handle];
+    const Kwave::SwapFile *swap = m_unmapped_swap[handle];
     Q_ASSERT(swap);
     if (!swap) return;
 
@@ -579,7 +580,7 @@ bool Kwave::MemoryManager::resize(Kwave::Handle handle, size_t size)
 // 	        static_cast<unsigned int>(size >> 20));
 
 	dump("resize");
-	SwapFile *swap = m_unmapped_swap[handle];
+	Kwave::SwapFile *swap = m_unmapped_swap[handle];
 	return swap->resize(size);
     }
 
@@ -617,7 +618,7 @@ void Kwave::MemoryManager::free(Kwave::Handle &handle)
 
     if (m_unmapped_swap.contains(handle)) {
 	// remove the pagefile
-	SwapFile *swap = m_unmapped_swap[handle];
+	Kwave::SwapFile *swap = m_unmapped_swap[handle];
 	m_unmapped_swap.remove(handle);
 	Q_ASSERT(!swap->mapCount());
 	delete swap;
@@ -653,7 +654,7 @@ void *Kwave::MemoryManager::map(Kwave::Handle handle)
 
     // if it is already in the cache -> shortcut !
     if (m_cached_swap.contains(handle)) {
-	SwapFile *swap = m_cached_swap[handle];
+	Kwave::SwapFile *swap = m_cached_swap[handle];
 	m_cached_swap.remove(handle);
 	m_mapped_swap.insert(handle, swap);
 // 	qDebug("Kwave::MemoryManager[%9d] - mmap -> cache hit", handle);
@@ -663,7 +664,7 @@ void *Kwave::MemoryManager::map(Kwave::Handle handle)
 
     // other simple case: already mapped
     if (m_mapped_swap.contains(handle)) {
-	SwapFile *swap = m_mapped_swap[handle];
+	Kwave::SwapFile *swap = m_mapped_swap[handle];
 	Q_ASSERT(swap->mapCount() >= 1);
 // 	qDebug("Kwave::MemoryManager[%9d] - mmap -> recursive(%d)",
 // 		handle, swap->mapCount());
@@ -673,7 +674,7 @@ void *Kwave::MemoryManager::map(Kwave::Handle handle)
     // more complicated case: unmapped swapfile
     if (m_unmapped_swap.contains(handle)) {
 	// map it into memory
-	SwapFile *swap = m_unmapped_swap[handle];
+	Kwave::SwapFile *swap = m_unmapped_swap[handle];
 	Q_ASSERT(!swap->mapCount());
 	void *mapped = swap->map();
 	if (!mapped) {
@@ -701,7 +702,7 @@ void Kwave::MemoryManager::unmapFromCache(Kwave::Handle handle)
 {
     if (m_cached_swap.contains(handle)) {
 // 	qDebug("Kwave::MemoryManager[%9d] - unmapFromCache", handle);
-	SwapFile *swap = m_cached_swap[handle];
+	Kwave::SwapFile *swap = m_cached_swap[handle];
 	Q_ASSERT(swap->mapCount() == 1);
 	swap->unmap();
 	Q_ASSERT(!swap->mapCount());
@@ -741,7 +742,7 @@ void Kwave::MemoryManager::unmap(Kwave::Handle handle)
     // must be a mapped swapfile: move it into the cache
     Q_ASSERT(m_mapped_swap.contains(handle));
     if (m_mapped_swap.contains(handle)) {
-	SwapFile *swap = m_mapped_swap[handle];
+	Kwave::SwapFile *swap = m_mapped_swap[handle];
 	Q_ASSERT(swap->mapCount());
 	if (swap->mapCount() > 1) {
 	    // only unmap and internally reduce the map count
@@ -788,7 +789,7 @@ int Kwave::MemoryManager::readFrom(Kwave::Handle handle, unsigned int offset,
 
     // still in the cache and mapped -> memcpy(...)
     if (m_cached_swap.contains(handle)) {
-	SwapFile *swap = m_cached_swap[handle];
+	Kwave::SwapFile *swap = m_cached_swap[handle];
 	Q_ASSERT(swap->mapCount() == 1);
 	char *data = reinterpret_cast<char *>(swap->address());
 	Q_ASSERT(data);
@@ -800,7 +801,7 @@ int Kwave::MemoryManager::readFrom(Kwave::Handle handle, unsigned int offset,
 
     // currently mmapped -> memcpy(...)
     if (m_mapped_swap.contains(handle)) {
-	SwapFile *swap = m_mapped_swap[handle];
+	Kwave::SwapFile *swap = m_mapped_swap[handle];
 	Q_ASSERT(swap->mapCount() >= 1);
 	char *data = reinterpret_cast<char *>(swap->address());
 	Q_ASSERT(data);
@@ -814,7 +815,7 @@ int Kwave::MemoryManager::readFrom(Kwave::Handle handle, unsigned int offset,
     Q_ASSERT(m_unmapped_swap.contains(handle));
     if (m_unmapped_swap.contains(handle)) {
 	qDebug("Kwave::MemoryManager[%9d] - readFrom -> unmapped swap", handle);
-	SwapFile *swap = m_unmapped_swap[handle];
+	Kwave::SwapFile *swap = m_unmapped_swap[handle];
 	length = swap->read(offset, buffer, length);
 	return length;
     }
@@ -858,7 +859,7 @@ int Kwave::MemoryManager::writeTo(Kwave::Handle handle, unsigned int offset,
     Q_ASSERT(m_unmapped_swap.contains(handle));
     if (m_unmapped_swap.contains(handle)) {
 	qDebug("Kwave::MemoryManager[%9d] - writeTo -> unmapped swap", handle);
-	SwapFile *swap = m_unmapped_swap[handle];
+	Kwave::SwapFile *swap = m_unmapped_swap[handle];
 	swap->write(offset, buffer, length);
 	return length;
     }
