@@ -17,9 +17,8 @@
 
 #include "config.h"
 
-#include "libkwave/FileInfo.h"
-#include "libkwave/Label.h"
 #include "libkwave/MetaDataList.h"
+#include "libkwave/String.h"
 
 //***************************************************************************
 Kwave::MetaDataList::MetaDataList()
@@ -284,7 +283,8 @@ void Kwave::MetaDataList::remove(const Kwave::MetaDataList &list)
 }
 
 //***************************************************************************
-void Kwave::MetaDataList::cropByRange(sample_index_t first, sample_index_t last)
+void Kwave::MetaDataList::cropByRange(sample_index_t first,
+                                      sample_index_t last)
 {
 
     MutableIterator it(*this);
@@ -1060,7 +1060,7 @@ void Kwave::MetaDataList::dump() const
     while (it.hasNext()) {
 	it.next();
 	const Kwave::MetaData &meta = it.value();
-	qDebug("* meta data #%s", it.key().toLocal8Bit().data());
+	qDebug("* meta data #%s", DBG(it.key()));
 	meta.dump();
     }
     qDebug("-----------------");
