@@ -18,8 +18,8 @@
 
 #include "config.h"
 
-#include "libkwave/KwaveSampleArray.h"
 #include "libkwave/MultiTrackWriter.h"
+#include "libkwave/SampleArray.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/undo/UndoInsertAction.h"
 #include "libkwave/undo/UndoModifyAction.h"
@@ -32,9 +32,9 @@ Kwave::MultiTrackWriter::MultiTrackWriter()
 }
 
 //***************************************************************************
-Kwave::MultiTrackWriter::MultiTrackWriter(SignalManager &signal_manager,
+Kwave::MultiTrackWriter::MultiTrackWriter(Kwave::SignalManager &signal_manager,
                                           const QList<unsigned int> &track_list,
-                                          InsertMode mode,
+                                          Kwave::InsertMode mode,
                                           sample_index_t left,
                                           sample_index_t right)
     :Kwave::MultiWriter()
@@ -46,8 +46,8 @@ Kwave::MultiTrackWriter::MultiTrackWriter(SignalManager &signal_manager,
 }
 
 //***************************************************************************
-Kwave::MultiTrackWriter::MultiTrackWriter(SignalManager &signal_manager,
-                                          InsertMode mode)
+Kwave::MultiTrackWriter::MultiTrackWriter(Kwave::SignalManager &signal_manager,
+                                          Kwave::InsertMode mode)
     :Kwave::MultiWriter()
 {
     QList<unsigned int> track_list = signal_manager.selectedTracks();
@@ -79,13 +79,13 @@ Kwave::MultiTrackWriter::~MultiTrackWriter()
 }
 
 //***************************************************************************
-bool Kwave::MultiTrackWriter::init(SignalManager &signal_manager,
+bool Kwave::MultiTrackWriter::init(Kwave::SignalManager &signal_manager,
                                    const QList<unsigned int> &track_list,
-                                   InsertMode mode,
+                                   Kwave::InsertMode mode,
                                    sample_index_t left,
                                    sample_index_t right)
 {
-    UndoTransactionGuard guard(signal_manager, 0);
+    Kwave::UndoTransactionGuard guard(signal_manager, QString());
 
     unsigned int index = 0;
     foreach (unsigned int track, track_list) {
@@ -95,7 +95,7 @@ bool Kwave::MultiTrackWriter::init(SignalManager &signal_manager,
 	    track, mode, left, right);
 	if (writer) {
 	    insert(index++, writer);
-	    
+
 	    // get the real/effective left and right sample
 	    left  = writer->first();
 	    right = writer->last();
@@ -109,7 +109,7 @@ bool Kwave::MultiTrackWriter::init(SignalManager &signal_manager,
     // skip all that undo handling below if undo is not enabled
     // or the writer creation has failed
     if (!signal_manager.undoEnabled()) return true;
-    
+
     // enter a new undo transaction and let it close when the writer closes
     signal_manager.startUndoTransaction();
     QObject::connect(this, SIGNAL(destroyed()),
@@ -119,12 +119,12 @@ bool Kwave::MultiTrackWriter::init(SignalManager &signal_manager,
     // create an undo action for the modification of the samples
     UndoAction *undo = 0;
     switch (mode) {
-	case Append:
-	case Insert: {
-	    undo = new UndoInsertAction(
-		signal_manager.parentWidget(), 
-		track_list, 
-		left, 
+	case Kwave::Append:
+	case Kwave::Insert: {
+	    undo = new Kwave::UndoInsertAction(
+		signal_manager.parentWidget(),
+		track_list,
+		left,
 		right - left + 1
 	    );
 
@@ -133,14 +133,15 @@ bool Kwave::MultiTrackWriter::init(SignalManager &signal_manager,
 		QObject::connect(
 		    last_writer,
 		    SIGNAL(sigSamplesWritten(sample_index_t)),
-		    static_cast<UndoInsertAction *>(undo),
+		    static_cast<Kwave::UndoInsertAction *>(undo),
 		    SLOT(setLength(sample_index_t)));
 	    }
 	    break;
 	}
-	case Overwrite: {
+	case Kwave::Overwrite: {
 	    foreach (unsigned int track, track_list) {
-		undo = new UndoModifyAction(track, left, right - left + 1);
+		undo = new Kwave::UndoModifyAction(
+		    track, left, right - left + 1);
 		if (!signal_manager.registerUndoAction(undo)) {
 		    // aborted, do not continue without undo
 		    clear();
@@ -151,7 +152,9 @@ bool Kwave::MultiTrackWriter::init(SignalManager &signal_manager,
 	}
     }
 
-    if ((mode != Overwrite) && !signal_manager.registerUndoAction(undo)) {
+    if ( (mode != Kwave::Overwrite) &&
+	 !signal_manager.registerUndoAction(undo) )
+    {
 	// aborted, do not continue without undo
 	clear();
 	return false;
