@@ -21,17 +21,18 @@
 
 #include "config.h"
 
-#include <QObject>
-#include <QList>
+#include <QtCore/QObject>
+#include <QtCore/QList>
 
 #include <kdemacros.h>
 
 #include "libkwave/InsertMode.h"
 #include "libkwave/MultiWriter.h"
 
-class SignalManager;
+namespace Kwave
+{
 
-namespace Kwave {
+    class SignalManager;
 
     /**
      * A MultiTrackWriter encapsulates a set of <c>TrackWriter</c>s for
@@ -54,10 +55,10 @@ namespace Kwave {
 	 * @param left index of the first sample
 	 * @param right index of the last sample
 	 */
-	MultiTrackWriter(SignalManager &signal_manager,
-			const QList<unsigned int> &track_list,
-			InsertMode mode,
-			sample_index_t left, sample_index_t right);
+	MultiTrackWriter(Kwave::SignalManager &signal_manager,
+	                 const QList<unsigned int> &track_list,
+	                 Kwave::InsertMode mode,
+	                 sample_index_t left, sample_index_t right);
 
 	/**
 	 * Constructor that opens a set of Writers using the currently
@@ -67,16 +68,17 @@ namespace Kwave {
 	 * @param signal_manager reference to a SignalManager
 	 * @param mode specifies where and how to insert
 	 */
-	MultiTrackWriter(SignalManager &signal_manager, InsertMode mode);
+	MultiTrackWriter(Kwave::SignalManager &signal_manager,
+	                 Kwave::InsertMode mode);
 
 	/** Destructor */
 	virtual ~MultiTrackWriter();
 
     private:
-    
+
 	/**
 	 * Intializer, see constructor...
-	 * 
+	 *
 	 * @param signal_manager reference to a SignalManager
 	 * @param track_list array of indices of tracks for reading
 	 * @param mode specifies where and how to insert
@@ -84,12 +86,15 @@ namespace Kwave {
 	 * @param right index of the last sample
 	 * @internal
 	 */
-	bool init(SignalManager &signal_manager,
+	bool init(Kwave::SignalManager &signal_manager,
 	          const QList<unsigned int> &track_list,
-	          InsertMode mode,
+	          Kwave::InsertMode mode,
 	          sample_index_t left, sample_index_t right);
 
     };
 }
 
 #endif /* _MULTI_TRACK_WRITER_H_ */
+
+//***************************************************************************
+//***************************************************************************
