@@ -17,12 +17,13 @@
 
 #include "config.h"
 
-#include <dlfcn.h>
 #include <errno.h>
-#include <pthread.h>
+#include <unistd.h>
 
-#include <QApplication>
-#include <QMutableListIterator>
+#include <QtGui/QApplication>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QLibrary>
+#include <QtCore/QMutableListIterator>
 
 #include <kglobal.h>
 #include <kconfig.h>
@@ -31,15 +32,11 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 
-#include "libkwave/KwaveMultiPlaybackSink.h"
-#include "libkwave/KwavePlugin.h"
+#include "libkwave/Plugin.h"
 #include "libkwave/MessageBox.h"
-#include "libkwave/MultiTrackReader.h"
-#include "libkwave/Parser.h"
+#include "libkwave/MultiPlaybackSink.h"
 #include "libkwave/PlayBackDevice.h"
 #include "libkwave/PlaybackDeviceFactory.h"
-#include "libkwave/PluginContext.h"
-#include "libkwave/SampleReader.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/Utils.h"
 #include "libkwave/Writer.h"
@@ -49,74 +46,20 @@
 #include "libkwave/PluginManager.h"
 
 //***************************************************************************
-//***************************************************************************
-Kwave::PluginManager::PluginDeleter::PluginDeleter(Kwave::Plugin *plugin,
-                                                   void *handle)
-  :QObject(), m_plugin(plugin), m_handle(handle)
-{
-    Q_ASSERT(m_plugin);
-}
-
-//***************************************************************************
-Kwave::PluginManager::PluginDeleter::~PluginDeleter()
-{
-    // check: this must be called from the GUI thread only!
-    Q_ASSERT(this->thread() == QThread::currentThread());
-    Q_ASSERT(this->thread() == qApp->thread());
-
-    // empty the event queues before deleting
-    qApp->processEvents();
-    qApp->flush();
-
-    // delete the plugin, this should also remove everything it has allocated
-    Q_ASSERT(m_plugin);
-    if (m_plugin) delete m_plugin;
-
-    // empty the event queues before unmap, in case the destructors
-    // queued something
-    qApp->processEvents();
-    qApp->flush();
-
-    // now the handle of the shared object can be cleared too
-    dlclose(m_handle);
-}
-
-//***************************************************************************
-//***************************************************************************
-
 // static initializers
 
-QMap<QString, Kwave::PluginManager::PluginInfo> \
-    Kwave::PluginManager::m_found_plugins;
-
-Kwave::PluginManager::PluginList Kwave::PluginManager::m_unique_plugins;
-
-static QList<PlaybackDeviceFactory *> m_playback_factories;
+QMap<QString, Kwave::PluginManager::PluginModule>
+    Kwave::PluginManager::m_plugin_modules;
 
 //***************************************************************************
 Kwave::PluginManager::PluginManager(QWidget *parent,
-                                    SignalManager &signal_manager)
-    :m_loaded_plugins(),
+                                    Kwave::SignalManager &signal_manager)
+    :m_plugin_instances(),
      m_running_plugins(),
      m_parent_widget(parent),
      m_signal_manager(signal_manager),
      m_view_manager(0)
 {
-    // connect all unique plugins
-    foreach (KwavePluginPointer p, m_unique_plugins) {
-	Q_ASSERT(p && p->isUnique());
-	if (p) {
-	    // increase the use count of the existing unique plugin
-	    p->use();
-
-	    // maybe we will become responsible for releasing
-	    // the plugin (when it is in use but the plugin manager
-	    // who has created it is already finished)
-	    connect(p,    SIGNAL(sigClosed(Kwave::Plugin *)),
-	            this, SLOT(pluginClosed(Kwave::Plugin *)),
-	            Qt::QueuedConnection);
-	}
-    }
 }
 
 //***************************************************************************
@@ -128,29 +71,44 @@ Kwave::PluginManager::~PluginManager()
     // wait until all plugins are really closed
     this->sync();
 
-    // release all unique plugins
-    foreach (KwavePluginPointer p, m_unique_plugins) {
-	Q_ASSERT(p && p->isUnique());
-	if (p) p->release();
-	this->sync();
-    }
-
-    // release all own persistent plugins
-    foreach (KwavePluginPointer p, m_loaded_plugins) {
+    // give all plugins that still are loaded the chance to do some cleanups
+    // or unregistration tasks. Ideally this should also trigger a "release"
+    // of these remaining plugins, so that afterwards we have no more
+    // plugin instances left.
+    while (!m_plugin_instances.isEmpty()) {
+	KwavePluginPointer p = m_plugin_instances.takeLast();
 	Q_ASSERT(p);
-	if (p && p->isPersistent()) p->release();
-	this->sync();
+	if (p) p->unload();
     }
 
-    // release all own plugins that are left (should be an empty list!)
-    while (!m_loaded_plugins.isEmpty()) {
-	KwavePluginPointer p = m_loaded_plugins.takeLast();
-	Q_ASSERT(p);
-	qWarning("RELEASING LOADED PLUGIN '%s'", p->name().toLocal8Bit().data());
-	if (p) p->release();
-	this->sync();
-    }
+    // this should make the cleanup handlers run (deferred delete)
+    qApp->processEvents();
+    qApp->flush();
 
+    // release all loaded modules
+    foreach (QString name, m_plugin_modules.keys()) {
+	PluginModule &p = m_plugin_modules[name];
+	p.m_use_count--;
+
+// 	qDebug("PluginManager: releasing module '%s' [refcnt=%d]",
+// 	       DBG(name), p.m_use_count);
+	if (p.m_use_count == 0) {
+	    // take out the pointer to the loadable module
+	    QLibrary *module = p.m_module;
+	    p.m_module = 0;
+
+	    // remove the module from the list
+	    m_plugin_modules.remove(name);
+
+	    // now the handle of the shared object can be released too
+	    if (module) {
+		module->unload();
+		delete module;
+	    }
+	} else {
+	    // still in use
+	}
+    }
 }
 
 //***************************************************************************
@@ -158,26 +116,30 @@ void Kwave::PluginManager::loadAllPlugins()
 {
     // Try to load all plugins. This has to be called only once per
     // instance of the main window!
-    // NOTE: this also implicitely makes it resident if it is persistent or unique
-    foreach (QString name, m_found_plugins.keys()) {
-	KwavePluginPointer plugin = loadPlugin(name);
+    // NOTE: this also gives each plugin the chance to stay in memory
+    //       if necessary (e.g. for codecs)
+    foreach (QString name, m_plugin_modules.keys()) {
+	KwavePluginPointer plugin = createPluginInstance(name);
 	if (plugin) {
-// 	    QString state = "";
-// 	    if (plugin->isPersistent()) state += "(persistent)";
-// 	    if (plugin->isUnique()) state += "(unique)";
-// 	    if (!state.length()) state = "(normal)";
-// 	    qDebug("PluginManager::loadAllPlugins(): plugin '%s' %s",
-// 		   plugin->name().toLocal8Bit().data(),
-// 		   state.toLocal8Bit().data());
+// 	    qDebug("PluginManager::loadAllPlugins(): plugin '%s'",
+// 		   DBG(plugin->name()));
 
-	    // reduce use count again, unique and persistent plugins
-	    // stay loaded with use count 1
+	    // get the last settings and call the "load" function
+	    // now the plugin is present and loaded
+	    QStringList last_params = loadPluginDefaults(name);
+	    plugin->load(last_params);
+
+	    // reduce use count again, we loaded the plugin only to give
+	    // it a chance to register some service if necessary (e.g. a
+	    // codec)
+	    // Most plugins fall back to use count zero and will be
+	    // deleted again.
 	    plugin->release();
 	} else {
 	    // loading failed => remove it from the list
-	    qWarning("PluginManager::loadAllPlugins(): removing '%s' "\
-	            "from list", name.toLocal8Bit().data());
-	    m_found_plugins.remove(name);
+	    qWarning("PluginManager::loadAllPlugins(): removing '%s' "
+	            "from list", DBG(name));
+	    m_plugin_modules.remove(name);
 	}
     }
 }
@@ -189,153 +151,48 @@ void Kwave::PluginManager::stopAllPlugins()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    if (!m_loaded_plugins.isEmpty())
-	foreach (KwavePluginPointer plugin, m_loaded_plugins)
+    if (!m_plugin_instances.isEmpty())
+	foreach (KwavePluginPointer plugin, m_plugin_instances)
 	    if (plugin && plugin->isRunning())
 		plugin->stop() ;
-    if (!m_unique_plugins.isEmpty())
-	foreach (KwavePluginPointer plugin, m_unique_plugins)
-	    if (plugin && plugin->isRunning())
-		plugin->stop();
 
     sync();
 }
 
 //***************************************************************************
-Kwave::Plugin *Kwave::PluginManager::loadPlugin(const QString &name)
+Kwave::Plugin *Kwave::PluginManager::createPluginInstance(const QString &name)
 {
     // check: this must be called from the GUI thread only!
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    // first find out if the plugin is already loaded and persistent
-    foreach (KwavePluginPointer p, m_loaded_plugins) {
-	Q_ASSERT(p);
-	if (p && p->isPersistent() && (p->name() == name)) {
-	    qDebug("PluginManager::loadPlugin('%s')"\
-	           "-> returning pointer to persistent",
-	           name.toLocal8Bit().data());
-	    p->use();
-	    return p;
-	}
-    }
-
-    // find out if the plugin is already loaded and unique
-    foreach (KwavePluginPointer p, m_unique_plugins) {
-	if (p && (p->name() == name)) {
-	    Q_ASSERT(p->isUnique());
-	    Q_ASSERT(p->isPersistent());
-	    qDebug("PluginManager::loadPlugin('%s')"\
-	           "-> returning pointer to unique+persistent",
-	           name.toLocal8Bit().data());
-	    p->use();
-	    return p;
-	}
-    }
-
-    // show a warning and abort if the plugin is unknown
-    if (!(m_found_plugins.contains(name))) {
-	QString message =
-	    i18n("The plugin '%1' is unknown or invalid.", name);
-	Kwave::MessageBox::error(m_parent_widget, message,
-	    i18n("Error On Loading Plugin"));
-	return 0;
-    }
-    QString &filename = m_found_plugins[name].m_filename;
-
-    // try to get the file handle of the plugin's binary
-    void *handle = dlopen(filename.toLocal8Bit(), RTLD_NOW);
-    if (!handle) {
-	QString message = i18n("Unable to load the file\n'%1'\n"\
-	                       "that contains the plugin '%2'.",
-	                       filename, name);
-	Kwave::MessageBox::error(m_parent_widget, message,
+    // show an error message and abort if the plugin is unknown
+    if (!(m_plugin_modules.contains(name))) {
+	Kwave::MessageBox::error(m_parent_widget,
+	    i18n("The plugin '%1' is unknown or invalid.", name),
 	    i18n("Error On Loading Plugin"));
 	return 0;
     }
 
-    // get the loader function
-    Kwave::Plugin *(*plugin_loader)(const PluginContext *c) = 0;
-
-    // hardcoded, should always work when the
-    // symbols are declared as extern "C"
-    const char *sym_version = "version";
-    const char *sym_author  = "author";
-    const char *sym_loader  = "load";
-
-    // get the plugin's author
-    const char *author = "";
-    const char **pauthor =
-	static_cast<const char **>(dlsym(handle, sym_author));
-    Q_ASSERT(pauthor);
-    if (pauthor) author=*pauthor;
-    if (!author) author = i18n("(Unknown)").toLocal8Bit();
-
-    // get the plugin's version string
-    const char *version = "";
-    const char **pver =
-	static_cast<const char **>(dlsym(handle, sym_version));
-    Q_ASSERT(pver);
-    if (pver) version=*pver;
-    if (!version) version = i18n("(Unknown)").toLocal8Bit();
-
-    plugin_loader =
-        reinterpret_cast<Kwave::Plugin *(*)(const PluginContext *)>(
-	reinterpret_cast<qint64>(dlsym(handle, sym_loader)));
-    Q_ASSERT(plugin_loader);
-    if (!plugin_loader) {
-	// plugin is null, out of memory or not found
-	qWarning("PluginManager::loadPlugin('%s'): "\
-		"plugin does not contain a loader, "\
-		"maybe it is damaged or the wrong version?",
-		name.toLocal8Bit().data());
-	dlclose(handle);
-	return 0;
-    }
-
-    PluginContext context(
-	*this,
-	handle,
-	name,
-	version,
-	author
-    );
+    PluginModule &info = m_plugin_modules[name];
+//     qDebug("loadPlugin(%s) [module use count=%d]",
+//         DBG(name), info.m_use_count);
 
     // call the loader function to create an instance
-    Kwave::Plugin *plugin = (*plugin_loader)(&context);
+    Kwave::Plugin *plugin = info.m_loader(*this);
     Q_ASSERT(plugin);
     if (!plugin) {
-	qWarning("PluginManager::loadPlugin('%s'): out of memory",
-	         name.toLocal8Bit().data());
-	dlclose(handle);
+	qWarning("PluginManager::loadPlugin('%s'): out of memory", DBG(name));
 	return 0;
     }
+    // now we have a newly created plugin, the use count is 1
 
-    if (plugin->isUnique()) {
-	// append unique plugins to the global list of unique plugins
-	plugin->use();
-	m_unique_plugins.append(plugin);
-    } else {
-	// append the plugin into our list of loaded plugins
-	if (plugin->isPersistent()) {
-	    plugin->use();
-	}
-	m_loaded_plugins.append(plugin);
-    }
-
-    // now we have a newly created plugin, the use count is
-    // 1 for normal plugins
-    // 2 for persistent plugins
-    // 2 for unique plugins
+    // append to our list of loaded plugins
+    m_plugin_instances.append(plugin);
 
     // connect all necessary signals/slots
     connectPlugin(plugin);
 
-    // get the last settings and call the "load" function
-    // now the plugin is present and loaded
-    QStringList last_params = loadPluginDefaults(name, plugin->version());
-    plugin->load(last_params);
-
     return plugin;
 }
 
@@ -354,7 +211,7 @@ int Kwave::PluginManager::executePlugin(const QString &name,
     sync();
 
     // load the new plugin
-    KwavePluginPointer plugin = loadPlugin(name);
+    KwavePluginPointer plugin = createPluginInstance(name);
     if (!plugin) return -ENOMEM;
 
     if (params) {
@@ -363,8 +220,7 @@ int Kwave::PluginManager::executePlugin(const QString &name,
 	result = plugin->start(*params);
 
 	// maybe the start() function has called close() ?
-	if (!m_unique_plugins.contains(plugin) &&
-	    !m_loaded_plugins.contains(plugin)) {
+	if (!m_plugin_instances.contains(plugin)) {
 	    qDebug("PluginManager: plugin closed itself in start()");
 	    result = -1;
 	    plugin = 0;
@@ -375,7 +231,7 @@ int Kwave::PluginManager::executePlugin(const QString &name,
 	}
     } else {
 	// load previous parameters from config
-	QStringList last_params = loadPluginDefaults(name, plugin->version());
+	QStringList last_params = loadPluginDefaults(name);
 
 	// call the plugin's setup function
 	params = plugin->setup(last_params);
@@ -386,24 +242,23 @@ int Kwave::PluginManager::executePlugin(const QString &name,
 	    // emit a new command.
 
 	    // store parameters for the next time
-	    savePluginDefaults(name, plugin->version(), *params);
+	    savePluginDefaults(name, *params);
 
 	    // We DO NOT call the plugin's "execute"
 	    // function directly, as it should be possible
 	    // to record all function calls in the
 	    // macro recorder
-	    command = "plugin:execute(";
+	    command = _("plugin:execute(");
 	    command += name;
 	    foreach (const QString &p, *params)
-		command += ", " + p;
+		command += _(", ") + p;
 	    delete params;
-	    command += ")";
+	    command += _(")");
 //	    qDebug("PluginManager: command='%s'",command.data());
 	}
     }
 
-    // now the plugin is no longer needed here, so delete it
-    // if it has not already been detached
+    // now the plugin is no longer needed here, release it
     if (plugin) plugin->release();
 
     // emit a command, let the toplevel window (and macro recorder) get
@@ -420,12 +275,10 @@ bool Kwave::PluginManager::canClose()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    if (!m_loaded_plugins.isEmpty())
-	foreach (KwavePluginPointer plugin, m_loaded_plugins)
-	    if (plugin && !plugin->canClose()) return false;
-    if (!m_unique_plugins.isEmpty())
-	foreach (KwavePluginPointer plugin, m_unique_plugins)
+    if (!m_plugin_instances.isEmpty())
+	foreach (KwavePluginPointer plugin, m_plugin_instances)
 	    if (plugin && !plugin->canClose()) return false;
+
     return true;
 }
 
@@ -437,12 +290,10 @@ bool Kwave::PluginManager::onePluginRunning()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    if (!m_loaded_plugins.isEmpty())
-	foreach (KwavePluginPointer plugin, m_loaded_plugins)
-	    if (plugin && plugin->isRunning()) return true;
-    if (!m_unique_plugins.isEmpty())
-	foreach (KwavePluginPointer plugin, m_unique_plugins)
+    if (!m_plugin_instances.isEmpty())
+	foreach (KwavePluginPointer plugin, m_plugin_instances)
 	    if (plugin && plugin->isRunning()) return true;
+
     return false;
 }
 
@@ -460,6 +311,7 @@ void Kwave::PluginManager::sync()
 	Kwave::yield();
 	qApp->processEvents();
 	qApp->flush();
+	usleep(100000);
     }
 }
 
@@ -467,18 +319,18 @@ void Kwave::PluginManager::sync()
 int Kwave::PluginManager::setupPlugin(const QString &name)
 {
     // load the plugin
-    Kwave::Plugin* plugin = loadPlugin(name);
+    Kwave::Plugin* plugin = createPluginInstance(name);
     if (!plugin) return -ENOMEM;
 
     // now the plugin is present and loaded
-    QStringList last_params = loadPluginDefaults(name, plugin->version());
+    QStringList last_params = loadPluginDefaults(name);
 
     // call the plugin's setup function
     QStringList *params = plugin->setup(last_params);
     if (params) {
 	// we have a non-zero parameter list, so
 	// the setup function has not been aborted.
-	savePluginDefaults(name, plugin->version(), *params);
+	savePluginDefaults(name, *params);
 	delete params;
     } else {
 	plugin->release();
@@ -490,14 +342,18 @@ int Kwave::PluginManager::setupPlugin(const QString &name)
 }
 
 //***************************************************************************
-QStringList Kwave::PluginManager::loadPluginDefaults(const QString &name,
-                                                     const QString &version)
+QStringList Kwave::PluginManager::loadPluginDefaults(const QString &name)
 {
     QString def_version;
-    QString section("plugin ");
+    QString section = _("plugin ");
     QStringList list;
     section += name;
 
+    // get the plugin version
+    if (!m_plugin_modules.contains(name)) return list;
+    const PluginModule &info = m_plugin_modules[name];
+    QString version = info.m_version;
+
     Q_ASSERT(KGlobal::config());
     if (!KGlobal::config()) return list;
     KConfigGroup cfg = KGlobal::config()->group(section);
@@ -509,23 +365,33 @@ QStringList Kwave::PluginManager::loadPluginDefaults(const QString &name,
 	return list;
     }
     if (!(def_version == version)) {
-	qDebug("PluginManager::loadPluginDefaults: "\
-	    "plugin '%s': defaults for version '%s' not loaded, found "\
-	    "old ones of version '%s'.", name.toLocal8Bit().data(),
-	    version.toLocal8Bit().data(), def_version.toLocal8Bit().data());
+	qDebug("PluginManager::loadPluginDefaults: "
+	    "plugin '%s': defaults for version '%s' not loaded, found "
+	    "old ones of version '%s'.",
+	    DBG(name), DBG(version), DBG(def_version));
+
+	// delete the old settings
+	cfg.deleteEntry("version");
+	cfg.deleteEntry("defaults");
+
 	return list;
     }
 
-    list = cfg.readEntry("defaults").split(',');
+    list = cfg.readEntry("defaults").split(QLatin1Char(','));
     return list;
 }
 
 //***************************************************************************
 void Kwave::PluginManager::savePluginDefaults(const QString &name,
-                                              const QString &version,
                                               QStringList &params)
 {
-    QString section("plugin ");
+
+    // get the plugin version
+    if (!m_plugin_modules.contains(name)) return;
+    const PluginModule &info = m_plugin_modules[name];
+    QString version = info.m_version;
+
+    QString section = _("plugin ");
     section += name;
 
     Q_ASSERT(KGlobal::config());
@@ -577,25 +443,13 @@ void Kwave::PluginManager::selectRange(sample_index_t offset,
 
 //***************************************************************************
 Kwave::SampleSink *Kwave::PluginManager::openMultiTrackPlayback(
-    unsigned int tracks, const QString *name)
+    unsigned int tracks,
+    const Kwave::PlayBackParam *playback_params
+)
 {
-    QString device_name;
-
-    // locate the corresponding playback device factory (plugin)
-    device_name = (name) ? QString(*name) : QString("");
-    PlayBackDevice *device = 0;
-    PlaybackDeviceFactory *factory = 0;
-    foreach (PlaybackDeviceFactory *f, m_playback_factories) {
-	Q_ASSERT(f);
-	if (f && f->supportsDevice(device_name)) {
-	    factory = f;
-	    break;
-	}
-    }
-    if (!factory) return 0;
-
-    // open the playback device with it's default parameters
-    device = factory->openDevice(device_name, tracks);
+    Kwave::PlayBackDevice *device =
+	m_signal_manager.playbackController().openDevice(
+	    tracks, playback_params);
     if (!device) return 0;
 
     // create the multi track playback sink
@@ -605,7 +459,7 @@ Kwave::SampleSink *Kwave::PluginManager::openMultiTrackPlayback(
 }
 
 //***************************************************************************
-PlaybackController &Kwave::PluginManager::playbackController()
+Kwave::PlaybackController &Kwave::PluginManager::playbackController()
 {
     return m_signal_manager.playbackController();
 }
@@ -644,23 +498,16 @@ void Kwave::PluginManager::pluginClosed(Kwave::Plugin *p)
     Q_ASSERT(this->thread() == qApp->thread());
 
     Q_ASSERT(p);
-    Q_ASSERT(!m_loaded_plugins.isEmpty() || !m_unique_plugins.isEmpty());
     if (!p) return;
 
     // disconnect the signals to avoid recursion
     disconnectPlugin(p);
 
-    if (m_loaded_plugins.contains(p)) m_loaded_plugins.removeAll(p);
-    if (m_unique_plugins.contains(p)) m_unique_plugins.removeAll(p);
+    if (m_plugin_instances.contains(p))
+        m_plugin_instances.removeAll(p);
 
     // schedule the deferred delete/unload of the plugin
-    void *handle = p->handle();
-    Q_ASSERT(handle);
-    PluginDeleter *delete_later = new PluginDeleter(p, handle);
-    Q_ASSERT(delete_later);
-    if (delete_later) delete_later->deleteLater();
-
-//    qDebug("PluginManager::pluginClosed(): done");
+    p->deleteLater();
 }
 
 //***************************************************************************
@@ -700,10 +547,8 @@ void Kwave::PluginManager::connectPlugin(Kwave::Plugin *plugin)
     Q_ASSERT(plugin);
     if (!plugin) return;
 
-    if (!plugin->isUnique()) {
-	connect(this, SIGNAL(sigClosed()),
-	        plugin, SLOT(close()));
-    }
+    connect(this, SIGNAL(sigClosed()),
+	    plugin, SLOT(close()));
 
     connect(plugin, SIGNAL(sigClosed(Kwave::Plugin *)),
 	    this, SLOT(pluginClosed(Kwave::Plugin *)),
@@ -733,10 +578,9 @@ void Kwave::PluginManager::disconnectPlugin(Kwave::Plugin *plugin)
     disconnect(this, SIGNAL(sigClosed()),
 	       plugin, SLOT(close()));
 
-    if (!plugin->isUnique()) {
-	disconnect(plugin, SIGNAL(sigClosed(Kwave::Plugin *)),
-	           this, SLOT(pluginClosed(Kwave::Plugin *)));
-    }
+    disconnect(plugin, SIGNAL(sigClosed(Kwave::Plugin *)),
+	       this, SLOT(pluginClosed(Kwave::Plugin *)));
+
 }
 
 //***************************************************************************
@@ -746,80 +590,96 @@ void Kwave::PluginManager::setSignalName(const QString &name)
 }
 
 //***************************************************************************
-void Kwave::PluginManager::findPlugins()
+void Kwave::PluginManager::searchPluginModules()
 {
-    if (!m_found_plugins.isEmpty()) {
-	// this is not the first call -> bail out
+    // hardcoded, should always work when the
+    // symbols are declared as extern "C"
+    const char *sym_name        = "name";
+    const char *sym_version     = "version";
+    const char *sym_description = "description";
+    const char *sym_author      = "author";
+    const char *sym_loader      = "load";
+
+    if (!m_plugin_modules.isEmpty()) {
+	// this is not the first call -> increment module use count only
+	foreach (const QString &name, m_plugin_modules.keys()) {
+	    PluginModule &p = m_plugin_modules[name];
+	    p.m_use_count++;
+	}
 	return;
     }
 
     KStandardDirs dirs;
     QStringList files = dirs.findAllResources("module",
-	    "plugins/kwave/*", KStandardDirs::NoDuplicates);
+	    _("plugins/kwave/*"), KStandardDirs::NoDuplicates);
 
     /* fallback: search also in the old location (useful for developers) */
     files += dirs.findAllResources("data",
-	    "kwave/plugins/*", KStandardDirs::NoDuplicates);
+	    _("kwave/plugins/*"), KStandardDirs::NoDuplicates);
 
-    foreach (QString file, files) {
-	void *handle = dlopen(file.toLocal8Bit(), RTLD_NOW);
-	if (handle) {
-	    const char **name    =
-		static_cast<const char **>(dlsym(handle, "name"));
-	    const char **version =
-		static_cast<const char **>(dlsym(handle, "version"));
-	    const char **description =
-		static_cast<const char **>(dlsym(handle, "description"));
-	    const char **author  =
-		static_cast<const char **>(dlsym(handle, "author"));
+    foreach (const QString &file, files) {
+	QLibrary *module = new QLibrary(file);
+	if (!module) continue;
 
-	    // skip it if something is missing or null
-	    if (!name || !version || !author || !description) continue;
-	    if (!*name || !*version || !*author || !*description) continue;
-
-	    emit sigProgress(i18n("Loading plugin %1...", *name));
-	    QApplication::processEvents();
-
-	    PluginInfo info;
-	    info.m_filename    = file;
-	    info.m_author      = QString::fromUtf8(*author);
-	    info.m_description = i18n(*description);
-	    info.m_version     = QString::fromUtf8(*version);
-
-	    m_found_plugins.insert(*name, info);
-
-	    qDebug("%16s %5s written by %s",
-		*name, *version, *author);
-
-	    dlclose (handle);
-	} else {
+	module->setLoadHints(QLibrary::ResolveAllSymbolsHint);
+	if (!module->load()) {
 	    qWarning("error in '%s':\n\t %s",
-		file.toLocal8Bit().data(), dlerror());
+	             DBG(file), DBG(module->errorString()));
+	    delete module;
+	    continue;
 	}
+
+	// get all required symbols from the plugin
+	const char **p_name    =
+	    static_cast<const char **>(module->resolve(sym_name));
+	const char **p_version =
+	    static_cast<const char **>(module->resolve(sym_version));
+	const char **p_description =
+	    static_cast<const char **>(module->resolve(sym_description));
+	const char **p_author  =
+	    static_cast<const char **>(module->resolve(sym_author));
+
+	void *p = module->resolve(sym_loader);
+	plugin_ldr_func_t *p_loader = 0;
+	memcpy(&p_loader, &p, sizeof(p));
+
+	// skip the plugin if something is missing or null
+	if (!p_name || !p_version || !p_author ||
+	    !p_description || !p_loader ||
+	    !*p_name || !*p_version || !*p_author ||
+	    !*p_description || !*p_loader)
+	{
+	    qWarning("WARNING: plugin %s is broken", DBG(file));
+	    delete module;
+	    continue;
+	}
+
+	emit sigProgress(i18n("Loading plugin %1...", _(*p_name)));
+	QApplication::processEvents();
+
+	PluginModule info;
+	info.m_name        = QString::fromUtf8(*p_name);
+	info.m_author      = QString::fromUtf8(*p_author);
+	info.m_description = i18n(*p_description);
+	info.m_version     = QString::fromUtf8(*p_version);
+	info.m_loader      = p_loader;
+
+	info.m_module      = module;
+	info.m_use_count   = 1;
+
+	m_plugin_modules.insert(info.m_name, info);
+
+	qDebug("%16s %5s written by %s", *p_name, *p_version, *p_author);
     }
 
-    qDebug("--- \n found %d plugins\n", m_found_plugins.count());
+    qDebug("--- \n found %d plugins\n", m_plugin_modules.count());
 }
 
 //***************************************************************************
-const QList<Kwave::PluginManager::PluginInfo>
+const QList<Kwave::PluginManager::PluginModule>
     Kwave::PluginManager::pluginInfoList() const
 {
-    return m_found_plugins.values();
-}
-
-//***************************************************************************
-void Kwave::PluginManager::registerPlaybackDeviceFactory(
-    PlaybackDeviceFactory *factory)
-{
-    m_playback_factories.append(factory);
-}
-
-//***************************************************************************
-void Kwave::PluginManager::unregisterPlaybackDeviceFactory(
-    PlaybackDeviceFactory *factory)
-{
-    m_playback_factories.removeAll(factory);
+    return m_plugin_modules.values();
 }
 
 //***************************************************************************
