@@ -20,13 +20,13 @@
 
 #include "config.h"
 
-#include <QList>
-#include <QListIterator>
-#include <QMap>
-#include <QMutableListIterator>
-#include <QObject>
-#include <QPointer>
-#include <QVector>
+#include <QtCore/QList>
+#include <QtCore/QListIterator>
+#include <QtCore/QMap>
+#include <QtCore/QMutableListIterator>
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <QtCore/QVector>
 
 #include <kdemacros.h>
 
@@ -34,16 +34,21 @@
 #include "libkwave/Sample.h"
 #include "libkwave/ViewManager.h"
 
-class FileInfo;
-class PlaybackController;
-class PlaybackDeviceFactory;
+class QLibrary;
 class QString;
 class QStringList;
-class SignalManager;
 class QWidget;
-namespace Kwave { class Plugin; }
-namespace Kwave { class SampleSink; }
-namespace Kwave { class Writer; }
+
+namespace Kwave
+{
+    class PlaybackController;
+    class PlaybackDeviceFactory;
+    class PlayBackParam;
+    class Plugin;
+    class PluginContext;
+    class SampleSink;
+    class SignalManager;
+    class Writer;
 
     /**
      * Manages the loading, initializing, starting, running and closing
@@ -51,7 +56,6 @@ namespace Kwave { class Writer; }
      * new instance of the PluginManager to be independent from other
      * toplevel widgets.
      */
-namespace Kwave {
     class KDE_EXPORT PluginManager : public QObject
     {
 	Q_OBJECT
@@ -63,7 +67,7 @@ namespace Kwave {
 	 * @param parent reference to the toplevel widget (our parent)
 	 * @param signal_manager reference to a SignalManager
 	 */
-	PluginManager(QWidget *parent, SignalManager &signal_manager);
+	PluginManager(QWidget *parent, Kwave::SignalManager &signal_manager);
 
 	/**
 	 * Default destructor
@@ -150,18 +154,21 @@ namespace Kwave {
 	/**
 	 * Opens a Kwave::MultiTrackSink for playback purposes.
 	 * @param tracks number of tracks
-	 * @param name of the device, optional. If not given, the default
-	 *        playback device is used
+	 * @param playback_params points to a class that holds all playback
+	 *                        parameters. If null, the default parameters
+	 *                        of the current signal will be used
 	 * @return a multitrack sink that receives the playback stream
 	 */
-	Kwave::SampleSink *openMultiTrackPlayback(unsigned int tracks,
-	    const QString *name = 0);
+	Kwave::SampleSink *openMultiTrackPlayback(
+	    unsigned int tracks,
+	    const Kwave::PlayBackParam *playback_params = 0
+	);
 
 	/**
 	 * Returns a reference to the current playback controller. This is
 	 * only needed for plugins doing playback.
 	 */
-	PlaybackController &playbackController();
+	Kwave::PlaybackController &playbackController();
 
 	/** returns a pointer to the parent widget */
 	inline QPointer<QWidget> parentWidget()
@@ -170,7 +177,7 @@ namespace Kwave {
 	}
 
 	/** returns a reference to our signal manager */
-	inline SignalManager &signalManager()
+	inline Kwave::SignalManager &signalManager()
 	{
 	    return m_signal_manager;
 	}
@@ -200,28 +207,32 @@ namespace Kwave {
 	 * plugin names and file names. First it collects a list of
 	 * filenames and then filters it to sort out invalid entries.
 	 */
-	void findPlugins();
+	void searchPluginModules();
 
 	/**
-	 * Registers a PlaybackDeviceFactory
+	 * Signature of a loader function, must be provided by a plugin
+	 * to create an instance of a class derived from Kwave::Plugin
 	 */
-	void registerPlaybackDeviceFactory(PlaybackDeviceFactory *factory);
-
-	/**
-	 * Unregisters a PlaybackDeviceFactory
-	 */
-	void unregisterPlaybackDeviceFactory(PlaybackDeviceFactory *factory);
+	typedef Kwave::Plugin *(plugin_ldr_func_t)(
+	    Kwave::PluginManager &plugin_manager);
 
 	/** structure with information about a plugin */
 	typedef struct  {
-	    QString m_filename;    /**< name of the file           */
-	    QString m_author;      /**< name of the author         */
-	    QString m_description; /**< verbose name / description */
-	    QString m_version;     /**< plugin API version         */
-	} PluginInfo;
+	    QString            m_name;        /**< name of the plugin   */
+	    QString            m_author;      /**< name of the author   */
+	    QString            m_description; /**< short description    */
+	    QString            m_version;     /**< plugin API version   */
+	    plugin_ldr_func_t *m_loader;      /**< loader function      */
 
-	/** returns a list with info of all known plugins */
-	const QList<PluginInfo> pluginInfoList() const;
+	    QLibrary          *m_module;      /**< shared object        */
+	    int                m_use_count;   /**< usage counter        */
+	} PluginModule;
+
+	/**
+	 * returns a list with info of all known plugins
+	 * @todo rename to pluginModuleList
+	 */
+	const QList<PluginModule> pluginInfoList() const;
 
     signals:
 
@@ -294,30 +305,12 @@ namespace Kwave {
     private:
 
 	/**
-	 * Helper class for deferred deleting and unloading a plugin
-	 * @internal
-	 */
-	class PluginDeleter: public QObject
-	{
-	public:
-	    /** Constructor, stores data for later removal */
-	    PluginDeleter(Kwave::Plugin *plugin, void *handle);
-
-	    /** Destructor, deletes and unloads the plugin */
-	    virtual ~PluginDeleter();
-
-	private:
-	    KwavePluginPointer m_plugin; /**< Plugin to be deleted */
-	    void *m_handle;              /**< Handle of the shared object */
-	};
-
-	/**
-	 * Uses the dynamic linker to load a plugin into memory.
+	 * Creates an instance of a plugin.
 	 * @param name the name of the plugin (filename)
 	 * @return pointer to the loaded plugin or zero if the
 	 *         plugin was not found or invalid
 	 */
-	Kwave::Plugin *loadPlugin(const QString &name);
+	Kwave::Plugin *createPluginInstance(const QString &name);
 
 	/**
 	 * loads a plugin's default parameters from the user's
@@ -326,11 +319,9 @@ namespace Kwave {
 	 * the plugin does not match the version number in the config file,
 	 * the return value will also be 0.
 	 * @param name the name of the plugin
-	 * @param version the version number of the plugin
 	 * @return list of strings
 	 */
-	QStringList loadPluginDefaults(const QString &name,
-				    const QString &version);
+	QStringList loadPluginDefaults(const QString &name);
 
 	/**
 	 * Saves a plugin's default parameters to the user's configuration
@@ -338,11 +329,10 @@ namespace Kwave {
 	 * before saving the new settings in order to wipe out invalid
 	 * entries and settings that belong to an older version.
 	 * @param name the name of the plugin
-	 * @param version the version number of the plugin
 	 * @param params a list of configuration strings
 	 */
-	void savePluginDefaults(const QString &name, const QString &version,
-				QStringList &params);
+	void savePluginDefaults(const QString &name,
+	                        QStringList &params);
 
 	/** connects all signals of and for a plugin */
 	void connectPlugin(Kwave::Plugin *plugin);
@@ -356,13 +346,10 @@ namespace Kwave {
 	 * map with plugin information: key = short name of the plugin,
 	 * data = plugin info (description, author, version etc...)
 	 */
-	static QMap<QString, PluginInfo> m_found_plugins;
+	static QMap<QString, PluginModule> m_plugin_modules;
 
-	/** list of own loaded plugins */
-	PluginList m_loaded_plugins;
-
-	/** global list of loaded unique plugins */
-	static PluginList m_unique_plugins;
+	/** list of all plugins that were loaded by this instance */
+	PluginList m_plugin_instances;
 
 	/** list of currently running plugins */
 	PluginList m_running_plugins;
@@ -371,12 +358,14 @@ namespace Kwave {
 	QPointer<QWidget> m_parent_widget;
 
 	/** reference to our signal manager */
-	SignalManager &m_signal_manager;
+	Kwave::SignalManager &m_signal_manager;
 
 	/** interface for registering a SignalView */
 	ViewManager *m_view_manager;
-
     };
 }
 
 #endif /* _PLUGIN_MANAGER_H_ */
+
+//***************************************************************************
+//***************************************************************************
