@@ -20,24 +20,20 @@
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <dlfcn.h>
 
-#include <QReadLocker>
-#include <QWriteLocker>
+#include <QtCore/QReadLocker>
+#include <QtCore/QWriteLocker>
 
 #include <klocale.h>
 
+#include "libkwave/Curve.h"
+#include "libkwave/Filter.h"
+#include "libkwave/Interpolation.h"
 #include "libkwave/MessageBox.h"
-#include "libkwave/MultiTrackReader.h"
+#include "libkwave/Signal.h"
 #include "libkwave/Track.h"
 #include "libkwave/WindowFunction.h"
 
-#include "Signal.h"
-#include "Parser.h"
-#include "Interpolation.h"
-#include "Curve.h"
-#include "Filter.h"
-
 //***************************************************************************
 Kwave::Signal::Signal()
     :m_tracks(), m_lock_tracks()
@@ -144,7 +140,7 @@ void Kwave::Signal::deleteTrack(unsigned int index)
 
 //***************************************************************************
 Kwave::Writer *Kwave::Signal::openWriter(unsigned int track,
-	InsertMode mode, sample_index_t left, sample_index_t right)
+	Kwave::InsertMode mode, sample_index_t left, sample_index_t right)
 {
     QReadLocker lock(&m_lock_tracks);
 
@@ -159,7 +155,7 @@ Kwave::Writer *Kwave::Signal::openWriter(unsigned int track,
 }
 
 //***************************************************************************
-SampleReader *Kwave::Signal::openSampleReader(Kwave::ReaderMode mode,
+Kwave::SampleReader *Kwave::Signal::openSampleReader(Kwave::ReaderMode mode,
 	unsigned int track, sample_index_t left, sample_index_t right)
 {
     QReadLocker lock(&m_lock_tracks);
@@ -419,9 +415,10 @@ void Kwave::Signal::selectTrack(unsigned int track, bool select)
 ////    }
 //}
 ////*********************************************************
-//void Kwave::Signal::movingFilter (Filter *filter, int tap, Curve *points, int low, int high)
+//void Kwave::Signal::movingFilter (Kwave::Filter *filter, int tap,
+//                                  Kwave::Curve *points, int low, int high)
 //{
-//    Interpolation interpolation (0);
+//    Kwave::Interpolation interpolation (0);
 //
 //    QMemArray<double> *move = interpolation.interpolation (points, len);
 //    if (move) {
