@@ -21,13 +21,14 @@
 
 #include "config.h"
 
-#include <QObject>
+#include <QtCore/QObject>
 
 #include <kdemacros.h>
 
 #include "libkwave/Writer.h"
 
-namespace Kwave {
+namespace Kwave
+{
 
     class SampleArray;
     class Track;
@@ -78,3 +79,6 @@ namespace Kwave {
 }
 
 #endif /* _STREAM_WRITER_H_ */
+
+//***************************************************************************
+//***************************************************************************
