@@ -20,14 +20,15 @@
 
 #include "config.h"
 
-#include <QObject>
-#include <QTime>
+#include <QtCore/QObject>
+#include <QtCore/QTime>
 
 #include <kdemacros.h>
 
 #include "libkwave/Writer.h"
 
-namespace Kwave {
+namespace Kwave
+{
 
     class SampleArray;
     class Track;
@@ -53,7 +54,7 @@ namespace Kwave {
 	 * @param right end of the input (only useful with overwrite mode)
 	 * @see InsertMode
 	 */
-	TrackWriter(Kwave::Track &track, InsertMode mode,
+	TrackWriter(Kwave::Track &track, Kwave::InsertMode mode,
 	    sample_index_t left = 0, sample_index_t right = 0);
 
 	/**
@@ -87,3 +88,6 @@ namespace Kwave {
 }
 
 #endif /* _TRACK_WRITER_H_ */
+
+//***************************************************************************
+//***************************************************************************
