@@ -19,55 +19,44 @@
 #include <math.h>
 #include <klocale.h>
 
-#include "libkwave/TypesMap.h"
+#include "libkwave/String.h"
 #include "libkwave/WindowFunction.h"
 
 //***************************************************************************
 //***************************************************************************
 
-void WindowFunction::InitializedTypesMap::fill()
+void Kwave::WindowFunction::InitializedTypesMap::fill()
 {
     append(WINDOW_FUNC_NONE,       WINDOW_FUNC_NONE,
-           "none", "None");
+           _("none"),       _(I18N_NOOP("None")));
     append(WINDOW_FUNC_HAMMING,    WINDOW_FUNC_HAMMING,
-        "hamming", "Hamming");
+           _("hamming"),    _(I18N_NOOP("Hamming")));
     append(WINDOW_FUNC_HANNING,    WINDOW_FUNC_HANNING,
-        "hanning",  "Hanning");
+           _("hanning"),    _(I18N_NOOP("Hanning")));
     append(WINDOW_FUNC_BLACKMAN,   WINDOW_FUNC_BLACKMAN,
-        "blackman",  "Blackman");
+           _("blackman"),   _(I18N_NOOP("Blackman")));
     append(WINDOW_FUNC_TRIANGULAR, WINDOW_FUNC_TRIANGULAR,
-        "triangular", "Triangular");
-
-#undef NEVER_COMPILE_THIS
-#ifdef NEVER_COMPILE_THIS
-#error "this could produce problems in plugins and/or libs when \
-        loaded before the main application is up."
-    i18n("None");
-    i18n("Hamming");
-    i18n("Hanning");
-    i18n("Blackman");
-    i18n("Triangular");
-#endif
+           _("triangular"), _(I18N_NOOP("Triangular")));
 }
 
 //***************************************************************************
 // static initializer
-WindowFunction::InitializedTypesMap WindowFunction::m_types_map;
+Kwave::WindowFunction::InitializedTypesMap Kwave::WindowFunction::m_types_map;
 
 //***************************************************************************
 //***************************************************************************
-WindowFunction::WindowFunction(window_function_t type)
+Kwave::WindowFunction::WindowFunction(Kwave::window_function_t type)
     :m_type(type)
 {
 }
 
 //***************************************************************************
-WindowFunction::~WindowFunction()
+Kwave::WindowFunction::~WindowFunction()
 {
 }
 
 //***************************************************************************
-QVector<double> WindowFunction::points(unsigned int len) const
+QVector<double> Kwave::WindowFunction::points(unsigned int len) const
 {
     QVector<double> out(len);
     Q_ASSERT(out.count() == static_cast<int>(len));
