@@ -18,7 +18,7 @@
 
 #include "config.h"
 
-#include <QObject>
+#include <QtCore/QObject>
 
 #include "libkwave/memcpy.h"
 #include "libkwave/Writer.h"
@@ -33,13 +33,13 @@
 //***************************************************************************
 Kwave::Writer::Writer()
     :Kwave::SampleSink(0),
-     m_first(0), m_last(0), m_mode(Insert), m_position(0),
+     m_first(0), m_last(0), m_mode(Kwave::Insert), m_position(0),
      m_buffer(BUFFER_SIZE), m_buffer_size(BUFFER_SIZE), m_buffer_used(0)
 {
 }
 
 //***************************************************************************
-Kwave::Writer::Writer(InsertMode mode,
+Kwave::Writer::Writer(Kwave::InsertMode mode,
                       sample_index_t left, sample_index_t right)
     :Kwave::SampleSink(0),
      m_first(left), m_last(right), m_mode(mode), m_position(left),
@@ -57,7 +57,7 @@ Kwave::Writer::~Writer()
     Q_ASSERT(!m_buffer_used);
     if (m_buffer_used) qWarning("Writer was not flushed!?");
 
-    Q_ASSERT((m_mode != Overwrite) || (m_position <= m_last + 1));
+    Q_ASSERT((m_mode != Kwave::Overwrite) || (m_position <= m_last + 1));
 
     // inform others that we proceeded
     emit sigSamplesWritten(m_position - m_first);
@@ -72,7 +72,7 @@ Kwave::Writer &Kwave::Writer::operator << (const Kwave::SampleArray &samples)
 	 (m_buffer_used + count <= m_buffer_size) )
     {
 	// append to the internal buffer if it is already in use
-	// and if there is still some room, 
+	// and if there is still some room,
 	// or if the buffer so small that it would make too much overhead
 	// to process it by block operation
 	MEMCPY(&(m_buffer[m_buffer_used]), &(samples[0]),
@@ -100,7 +100,7 @@ Kwave::Writer &Kwave::Writer::operator << (const sample_t &sample)
 }
 
 //***************************************************************************
-Kwave::Writer &Kwave::Writer::operator << (SampleReader &reader)
+Kwave::Writer &Kwave::Writer::operator << (Kwave::SampleReader &reader)
 {
     if (m_buffer_used) flush();
 
@@ -109,7 +109,7 @@ Kwave::Writer &Kwave::Writer::operator << (SampleReader &reader)
     while (!reader.eof() && !eof()) {
 
 	// overwrite mode -> clip at right border
-	if (m_mode == Overwrite) {
+	if (m_mode == Kwave::Overwrite) {
 	    if (m_position + buflen - 1 > m_last)
 		buflen = (m_last - m_position) + 1;
 	}
@@ -122,7 +122,7 @@ Kwave::Writer &Kwave::Writer::operator << (SampleReader &reader)
     }
 
     // pad the rest with zeroes
-    if (m_mode == Overwrite) {
+    if (m_mode == Kwave::Overwrite) {
 	Q_ASSERT(m_position <= m_last + 1);
 	while (m_buffer_used + m_position <= m_last) {
 	    *this << static_cast<sample_t>(0);
@@ -137,7 +137,7 @@ Kwave::Writer &Kwave::Writer::operator << (SampleReader &reader)
 //***************************************************************************
 bool Kwave::Writer::eof() const
 {
-    return (m_mode == Overwrite) ? (m_position > m_last) : false;
+    return (m_mode == Kwave::Overwrite) ? (m_position > m_last) : false;
 }
 
 //***************************************************************************
