@@ -20,20 +20,21 @@
 
 #include "config.h"
 
-#include <QObject>
-#include <QString>
-#include <QVector>
-#include <QPointer>
-#include <QQueue>
+#include <QtCore/QObject>
+#include <QtCore/QString>
+#include <QtCore/QVector>
+#include <QtCore/QPointer>
+#include <QtCore/QQueue>
 
-#include "libkwave/KwaveConnect.h"
-#include "libkwave/KwaveSampleSink.h"
-#include "libkwave/KwaveSampleSource.h"
-#include "libkwave/modules/KwaveStreamObject.h"
+#include "libkwave/Connect.h"
+#include "libkwave/SampleSink.h"
+#include "libkwave/SampleSource.h"
+#include "libkwave/modules/StreamObject.h"
 #include "libkwave/modules/SampleBuffer.h"
 
 //***************************************************************************
-namespace Kwave {
+namespace Kwave
+{
 
     class MixerMatrix;
 
@@ -67,14 +68,14 @@ namespace Kwave {
 	     * @return number of tracks of a input or output, default is
 	     *         the same as tracks()
 	     */
-	    virtual unsigned int tracksOfPort(const QString &port) const;
+	    virtual unsigned int tracksOfPort(const char *port) const;
 
 	    /**
 	     * Returns an indexed port, identified by name
 	     * @param port name of the port (name of signal or slot)
 	     * @param track index of the track
 	     */
-	    virtual Kwave::StreamObject *port(const QString &port,
+	    virtual Kwave::StreamObject *port(const char *port,
 	                                      unsigned int track);
 
 	    /** does nothing, work is done automatically in mix() */
