@@ -19,20 +19,21 @@
 #define _RATE_CONVERTER_H_
 
 #include "config.h"
-#ifdef HAVE_SAMPLERATE_SUPPORT
 
-#include <QObject>
-#include <QVariant>
-#include <QVarLengthArray>
+#include <QtCore/QObject>
+#include <QtCore/QVariant>
+#include <QtCore/QVarLengthArray>
 
 #include <kdemacros.h>
 
 #include <samplerate.h>
 
-#include "libkwave/KwaveSampleArray.h"
-#include "libkwave/KwaveSampleSource.h"
+#include "libkwave/SampleArray.h"
+#include "libkwave/SampleSource.h"
+
+namespace Kwave
+{
 
-namespace Kwave {
     class KDE_EXPORT RateConverter: public Kwave::SampleSource
     {
 	Q_OBJECT
@@ -79,6 +80,7 @@ namespace Kwave {
     };
 }
 
-#endif /* HAVE_SAMPLERATE_SUPPORT */
-
 #endif /* _RATE_CONVERTER_H_ */
+
+//***************************************************************************
+//***************************************************************************
