@@ -18,8 +18,8 @@
 #include "config.h"
 #include <klocale.h>
 
-#include "libkwave/KwaveSampleArray.h"
 #include "libkwave/Sample.h"
+#include "libkwave/SampleArray.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/Writer.h"
@@ -29,39 +29,41 @@
 #define BUFFER_SIZE 65536
 
 //***************************************************************************
-UndoModifyAction::UndoModifyAction(unsigned int track, sample_index_t offset,
-                                   sample_index_t length)
+Kwave::UndoModifyAction::UndoModifyAction(unsigned int track,
+                                          sample_index_t offset,
+                                          sample_index_t length)
     :UndoAction(), m_track(track), m_offset(offset), m_length(length),
      m_buffer_track()
 {
 }
 
 //***************************************************************************
-UndoModifyAction::~UndoModifyAction()
+Kwave::UndoModifyAction::~UndoModifyAction()
 {
 }
 
 //***************************************************************************
-QString UndoModifyAction::description()
+QString Kwave::UndoModifyAction::description()
 {
     return i18n("Modify Samples");
 }
 
 //***************************************************************************
-unsigned int UndoModifyAction::undoSize()
+unsigned int Kwave::UndoModifyAction::undoSize()
 {
     return sizeof(*this) + (m_length * sizeof(sample_t));
 }
 
 //***************************************************************************
-bool UndoModifyAction::store(SignalManager &manager)
+bool Kwave::UndoModifyAction::store(Kwave::SignalManager &manager)
 {
-    SampleReader *reader = manager.openSampleReader(
+    Kwave::SampleReader *reader = manager.openSampleReader(
 	Kwave::SinglePassForward, m_track, m_offset, m_offset+m_length-1);
     Q_ASSERT(reader);
     if (!reader) return false;
 
-    Kwave::Writer *writer = m_buffer_track.openWriter(Append, 0, m_length - 1);
+    Kwave::Writer *writer =
+	m_buffer_track.openWriter(Kwave::Append, 0, m_length - 1);
     Q_ASSERT(writer);
     if (!writer) {
 	delete reader;
@@ -77,10 +79,11 @@ bool UndoModifyAction::store(SignalManager &manager)
 }
 
 //***************************************************************************
-UndoAction *UndoModifyAction::undo(SignalManager &manager, bool with_redo)
+Kwave::UndoAction *Kwave::UndoModifyAction::undo(
+    Kwave::SignalManager &manager, bool with_redo)
 {
     Kwave::Writer *writer = manager.openWriter(
-	m_track, Overwrite, m_offset, m_offset + m_length - 1);
+	m_track, Kwave::Overwrite, m_offset, m_offset + m_length - 1);
     Q_ASSERT(writer);
     if (!writer) return 0;
 
@@ -90,13 +93,13 @@ UndoAction *UndoModifyAction::undo(SignalManager &manager, bool with_redo)
 	Kwave::SampleArray buf_cur(BUFFER_SIZE);
 	Kwave::SampleArray buf_sav(BUFFER_SIZE);
 
-	SampleReader *reader_cur = manager.openSampleReader(
+	Kwave::SampleReader *reader_cur = manager.openSampleReader(
 	    Kwave::SinglePassForward, m_track, m_offset, m_offset+m_length-1);
 	Kwave::Writer *writer_cur = writer;
-	SampleReader *reader_sav = m_buffer_track.openSampleReader(
+	Kwave::SampleReader *reader_sav = m_buffer_track.openSampleReader(
 	    Kwave::SinglePassForward, 0, m_length-1);
 	Kwave::Writer *writer_sav = m_buffer_track.openWriter(
-	    Overwrite, 0, m_length - 1);
+	    Kwave::Overwrite, 0, m_length - 1);
 
 	// exchange content of the current signal with the content
 	// of the internal buffer
@@ -125,7 +128,7 @@ UndoAction *UndoModifyAction::undo(SignalManager &manager, bool with_redo)
 	if (reader_sav) delete reader_sav;
 	if (writer_sav) delete writer_sav;
     } else {
-	SampleReader *reader = m_buffer_track.openSampleReader(
+	Kwave::SampleReader *reader = m_buffer_track.openSampleReader(
 	    Kwave::SinglePassForward, 0, m_length-1);
 	Q_ASSERT(reader);
 
