@@ -17,43 +17,44 @@
 
 #include "config.h"
 
-#include <QStringList>
+#include <QtCore/QStringList>
 #include <klocale.h>
 
-#include "libkwave/KwaveConnect.h"
+#include "libkwave/Connect.h"
 #include "libkwave/MultiTrackReader.h"
+#include "libkwave/MultiTrackSource.h"
 #include "libkwave/MultiTrackWriter.h"
-#include "libkwave/KwaveMultiTrackSource.h"
 #include "libkwave/Parser.h"
 #include "libkwave/PluginManager.h"
+#include "libkwave/String.h"
 #include "libkwave/modules/CurveStreamAdapter.h"
-#include "libkwave/modules/KwaveMul.h"
+#include "libkwave/modules/Mul.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
 
 #include "AmplifyFreePlugin.h"
 #include "AmplifyFreeDialog.h"
 
-KWAVE_PLUGIN(AmplifyFreePlugin, "amplifyfree", "2.1",
+KWAVE_PLUGIN(Kwave::AmplifyFreePlugin, "amplifyfree", "2.3",
              I18N_NOOP("Amplify Free"), "Thomas Eschenbacher");
 
 //***************************************************************************
-AmplifyFreePlugin::AmplifyFreePlugin(const PluginContext &context)
-    :Kwave::Plugin(context), m_action_name(""), m_params(), m_curve()
+Kwave::AmplifyFreePlugin::AmplifyFreePlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager), m_action_name(), m_params(), m_curve()
 {
 }
 
 //***************************************************************************
-AmplifyFreePlugin::~AmplifyFreePlugin()
+Kwave::AmplifyFreePlugin::~AmplifyFreePlugin()
 {
 }
 
 //***************************************************************************
-int AmplifyFreePlugin::interpreteParameters(QStringList &params)
+int Kwave::AmplifyFreePlugin::interpreteParameters(QStringList &params)
 {
     // store last parameters
     m_params = params;
 
-    m_action_name = "";
+    m_action_name = _("");
     if (params.count() < 2) return -1;
     if (params.count() & 1) return -1; // no. of params must be even
 
@@ -61,13 +62,12 @@ int AmplifyFreePlugin::interpreteParameters(QStringList &params)
     if (params[0].length()) m_action_name = params[0];
 
     // convert string list into command again...
-    QString cmd;
-    cmd = "curve(";
+    QString cmd = _("curve(");
     for (int i = 1; i < params.count(); ++i) {
 	cmd += params[i];
-	if ((i + 1) < params.count()) cmd += ",";
+	if ((i + 1) < params.count()) cmd += _(",");
     }
-    cmd += ")";
+    cmd += _(")");
 
     // and initialize our curve with it
     m_curve.fromCommand(cmd);
@@ -76,13 +76,14 @@ int AmplifyFreePlugin::interpreteParameters(QStringList &params)
 }
 
 //***************************************************************************
-QStringList *AmplifyFreePlugin::setup(QStringList &previous_params)
+QStringList *Kwave::AmplifyFreePlugin::setup(QStringList &previous_params)
 {
     // try to interprete the previous parameters
     interpreteParameters(previous_params);
 
     // create the setup dialog
-    AmplifyFreeDialog *dialog = new AmplifyFreeDialog(parentWidget());
+    Kwave::AmplifyFreeDialog *dialog =
+	new Kwave::AmplifyFreeDialog(parentWidget());
     Q_ASSERT(dialog);
     if (!dialog) return 0;
 
@@ -97,12 +98,12 @@ QStringList *AmplifyFreePlugin::setup(QStringList &previous_params)
     Q_ASSERT(list);
     if (list && dialog->exec()) {
 	// user has pressed "OK"
-	*list << "amplify free";
+	*list << _("amplify free");
 	QString cmd = dialog->getCommand();
-	Parser p(cmd);
+	Kwave::Parser p(cmd);
 	while (!p.isDone()) *list << p.nextParam();
 
-	qDebug("setup -> emitCommand('%s')",cmd.toLocal8Bit().data());
+	qDebug("setup -> emitCommand('%s')", DBG(cmd));
 	emitCommand(cmd);
     } else {
 	// user pressed "Cancel"
@@ -115,37 +116,37 @@ QStringList *AmplifyFreePlugin::setup(QStringList &previous_params)
 }
 
 //***************************************************************************
-QString AmplifyFreePlugin::progressText()
+QString Kwave::AmplifyFreePlugin::progressText()
 {
     return m_action_name.length() ?
-	i18n(m_action_name.toLocal8Bit()) : i18n("Amplify Free");
+	i18n(__(m_action_name)) : i18n("Amplify Free");
 }
 
 //***************************************************************************
-int AmplifyFreePlugin::start(QStringList &params)
+int Kwave::AmplifyFreePlugin::start(QStringList &params)
 {
     interpreteParameters(params);
     return Kwave::Plugin::start(params);
 }
 
 //***************************************************************************
-void AmplifyFreePlugin::run(QStringList params)
+void Kwave::AmplifyFreePlugin::run(QStringList params)
 {
     sample_index_t first, last;
     QList<unsigned int> track_list;
 
     interpreteParameters(params);
 
-    UndoTransactionGuard undo_guard(*this, i18n(m_action_name.toLocal8Bit()));
+    Kwave::UndoTransactionGuard undo_guard(*this, i18n(__(m_action_name)));
 
     unsigned int input_length = selection(&track_list, &first, &last, true);
     unsigned int tracks = track_list.count();
 
     // create all objects
-    MultiTrackReader source(Kwave::SinglePassForward,
+    Kwave::MultiTrackReader source(Kwave::SinglePassForward,
 	signalManager(), selectedTracks(), first, last);
     Kwave::CurveStreamAdapter curve(m_curve, input_length);
-    Kwave::MultiTrackWriter sink(signalManager(), track_list, Overwrite,
+    Kwave::MultiTrackWriter sink(signalManager(), track_list, Kwave::Overwrite,
 	first, last);
     Kwave::MultiTrackSource<Kwave::Mul, true> mul(tracks, this);
 
