@@ -21,6 +21,7 @@
 #include "config.h"
 
 #include "libkwave/CodecPlugin.h"
+#include "libkwave/Compression.h"
 
 namespace Kwave
 {
@@ -56,6 +57,10 @@ namespace Kwave
     i18n("ASCII encoded audio"), "*.ascii; *.ASCII"); \
 }
 
+#define REGISTER_COMPRESSION_TYPES { \
+    addCompression(Kwave::Compression::NONE);   \
+}
+
 /** prefix used for encoding metadata / properties */
 #define META_PREFIX _("## ")
 
