@@ -16,32 +16,42 @@
  ***************************************************************************/
 
 #include "config.h"
+#include <klocale.h>
 
 #include "libkwave/CodecManager.h"
 
 #include "AudiofileCodecPlugin.h"
 #include "AudiofileDecoder.h"
 
-KWAVE_PLUGIN(AudiofileCodecPlugin, "codec_audiofile", "2.1",
+KWAVE_PLUGIN(Kwave::AudiofileCodecPlugin, "codec_audiofile", "2.3",
              I18N_NOOP("Audiofile Codec"), "Thomas Eschenbacher");
 
+// static instance of the codec container
+Kwave::CodecPlugin::Codec Kwave::AudiofileCodecPlugin::m_codec = {0, 0, 0};
+
 /***************************************************************************/
-AudiofileCodecPlugin::AudiofileCodecPlugin(const PluginContext &c)
-    :Kwave::Plugin(c), m_decoder(0)
+Kwave::AudiofileCodecPlugin::AudiofileCodecPlugin(
+    Kwave::PluginManager &plugin_manager
+)
+    :Kwave::CodecPlugin(plugin_manager, m_codec)
 {
 }
 
 /***************************************************************************/
-AudiofileCodecPlugin::~AudiofileCodecPlugin()
+Kwave::AudiofileCodecPlugin::~AudiofileCodecPlugin()
 {
 }
 
 /***************************************************************************/
-void AudiofileCodecPlugin::load(QStringList &/* params */)
+Kwave::Decoder *Kwave::AudiofileCodecPlugin::createDecoder()
 {
-    if (!m_decoder) m_decoder = new AudiofileDecoder();
-    Q_ASSERT(m_decoder);
-    if (m_decoder) CodecManager::registerDecoder(*m_decoder);
+    return new Kwave::AudiofileDecoder();
+}
+
+/***************************************************************************/
+Kwave::Encoder *Kwave::AudiofileCodecPlugin::createEncoder()
+{
+    return 0; /* not implemented */
 }
 
 /***************************************************************************/
