@@ -25,32 +25,33 @@
 #include "FlacEncoder.h"
 #include "FlacDecoder.h"
 
-KWAVE_PLUGIN(FlacCodecPlugin, "codec_flac", "2.1",
+KWAVE_PLUGIN(Kwave::FlacCodecPlugin, "codec_flac", "2.3",
              I18N_NOOP("FLAC Codec"), "Thomas Eschenbacher");
 
+// static instance of the codec container
+Kwave::CodecPlugin::Codec Kwave::FlacCodecPlugin::m_codec = {0, 0, 0};
+
 /***************************************************************************/
-FlacCodecPlugin::FlacCodecPlugin(const PluginContext &c)
-    :Kwave::Plugin(c), m_decoder(0), m_encoder(0)
+Kwave::FlacCodecPlugin::FlacCodecPlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::CodecPlugin(plugin_manager, m_codec)
 {
 }
 
 /***************************************************************************/
-FlacCodecPlugin::~FlacCodecPlugin()
+Kwave::FlacCodecPlugin::~FlacCodecPlugin()
 {
-    m_encoder = 0;
-    m_decoder = 0;
 }
 
 /***************************************************************************/
-void FlacCodecPlugin::load(QStringList &/* params */)
+Kwave::Decoder *Kwave::FlacCodecPlugin::createDecoder()
 {
-    if (!m_encoder) m_encoder = new FlacEncoder();
-    Q_ASSERT(m_encoder);
-    if (m_encoder) CodecManager::registerEncoder(*m_encoder);
+    return new Kwave::FlacDecoder();
+}
 
-    if (!m_decoder) m_decoder = new FlacDecoder();
-    Q_ASSERT(m_decoder);
-    if (m_decoder) CodecManager::registerDecoder(*m_decoder);
+/***************************************************************************/
+Kwave::Encoder *Kwave::FlacCodecPlugin::createEncoder()
+{
+    return new Kwave::FlacEncoder();
 }
 
 /***************************************************************************/
