@@ -19,11 +19,10 @@
 
 #include <math.h>
 #include <stdlib.h>
-#include <time.h>
 
-#include <QByteArray>
-#include <QList>
-#include <QVarLengthArray>
+#include <QtCore/QByteArray>
+#include <QtCore/QList>
+#include <QtCore/QVarLengthArray>
 
 #include <klocale.h>
 #include <kmimetype.h>
@@ -38,44 +37,41 @@
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/Sample.h"
 #include "libkwave/SampleReader.h"
+#include "libkwave/String.h"
 
 #include "FlacCodecPlugin.h"
 #include "FlacEncoder.h"
 
 /***************************************************************************/
-FlacEncoder::FlacEncoder()
-    :Encoder(), FLAC::Encoder::Stream(), m_vorbis_comment_map(), m_dst(0)
+Kwave::FlacEncoder::FlacEncoder()
+    :Kwave::Encoder(), FLAC::Encoder::Stream(),
+     m_vorbis_comment_map(), m_dst(0)
 {
-    LOAD_MIME_TYPES;
+    REGISTER_MIME_TYPES;
+    REGISTER_COMPRESSION_TYPES;
 }
 
 /***************************************************************************/
-FlacEncoder::~FlacEncoder()
+Kwave::FlacEncoder::~FlacEncoder()
 {
 }
 
 /***************************************************************************/
-Encoder *FlacEncoder::instance()
+Kwave::Encoder *Kwave::FlacEncoder::instance()
 {
-    return new FlacEncoder();
+    return new Kwave::FlacEncoder();
 }
 
 /***************************************************************************/
-QList<FileProperty> FlacEncoder::supportedProperties()
+QList<Kwave::FileProperty> Kwave::FlacEncoder::supportedProperties()
 {
     return m_vorbis_comment_map.values();
 }
 
 /***************************************************************************/
-#if defined(FLAC_API_VERSION_1_1_2)
-::FLAC__StreamEncoderWriteStatus FlacEncoder::write_callback(
-        const FLAC__byte buffer[], unsigned int bytes,
-        unsigned int /* samples */, unsigned int /* current_frame */)
-#else
-::FLAC__StreamEncoderWriteStatus FlacEncoder::write_callback(
+::FLAC__StreamEncoderWriteStatus Kwave::FlacEncoder::write_callback(
         const FLAC__byte buffer[], size_t bytes,
         unsigned /* samples */, unsigned /* current_frame */)
-#endif
 {
     Q_ASSERT(m_dst);
     if (!m_dst) return FLAC__STREAM_ENCODER_WRITE_STATUS_FATAL_ERROR;
@@ -91,13 +87,13 @@ QList<FileProperty> FlacEncoder::supportedProperties()
 }
 
 /***************************************************************************/
-void FlacEncoder::metadata_callback(const ::FLAC__StreamMetadata *)
+void Kwave::FlacEncoder::metadata_callback(const ::FLAC__StreamMetadata *)
 {
     /* we are not interested in the FLAC metadata */
 }
 
 /***************************************************************************/
-FlacEncoder::VorbisCommentContainer::VorbisCommentContainer()
+Kwave::FlacEncoder::VorbisCommentContainer::VorbisCommentContainer()
     :m_vc(0)
 {
     m_vc = FLAC__metadata_object_new(FLAC__METADATA_TYPE_VORBIS_COMMENT);
@@ -105,7 +101,7 @@ FlacEncoder::VorbisCommentContainer::VorbisCommentContainer()
 }
 
 /***************************************************************************/
-FlacEncoder::VorbisCommentContainer::~VorbisCommentContainer()
+Kwave::FlacEncoder::VorbisCommentContainer::~VorbisCommentContainer()
 {
     if (m_vc) {
         // clean up all vorbis comments
@@ -113,14 +109,14 @@ FlacEncoder::VorbisCommentContainer::~VorbisCommentContainer()
 }
 
 /***************************************************************************/
-void FlacEncoder::VorbisCommentContainer::add(const QString &tag,
-                                              const QString &value)
+void Kwave::FlacEncoder::VorbisCommentContainer::add(const QString &tag,
+                                                     const QString &value)
 {
     Q_ASSERT(m_vc);
     if (!m_vc) return;
 
     QString s;
-    s = tag+"="+value;
+    s = tag + _("=") + value;
 
     // make a plain C string out of it, containing UTF-8
     QByteArray val = s.toUtf8();
@@ -140,20 +136,20 @@ void FlacEncoder::VorbisCommentContainer::add(const QString &tag,
 }
 
 /***************************************************************************/
-FLAC__StreamMetadata *FlacEncoder::VorbisCommentContainer::data()
+FLAC__StreamMetadata *Kwave::FlacEncoder::VorbisCommentContainer::data()
 {
     return m_vc;
 }
 
 /***************************************************************************/
-void FlacEncoder::encodeMetaData(const FileInfo &info,
+void Kwave::FlacEncoder::encodeMetaData(const Kwave::FileInfo &info,
     QVector<FLAC__StreamMetadata *> &flac_metadata)
 {
     // encode all Vorbis comments
     VorbisCommentMap::ConstIterator it;
     VorbisCommentContainer vc;
-    for (it = m_vorbis_comment_map.begin();
-         it != m_vorbis_comment_map.end();
+    for (it = m_vorbis_comment_map.constBegin();
+         it != m_vorbis_comment_map.constEnd();
          ++it)
     {
 	if (!info.contains(it.value())) continue; // not present -> skip
@@ -168,14 +164,15 @@ void FlacEncoder::encodeMetaData(const FileInfo &info,
 }
 
 /***************************************************************************/
-bool FlacEncoder::encode(QWidget *widget, MultiTrackReader &src,
-                         QIODevice &dst,
-                         const Kwave::MetaDataList &meta_data)
+bool Kwave::FlacEncoder::encode(QWidget *widget,
+                                Kwave::MultiTrackReader &src,
+                                QIODevice &dst,
+                                const Kwave::MetaDataList &meta_data)
 {
     bool result = true;
 
     qDebug("FlacEncoder::encode()");
-    const FileInfo info(meta_data);
+    const Kwave::FileInfo info(meta_data);
     m_dst  = &dst;
 
     // get info: tracks, sample rate
@@ -183,9 +180,7 @@ bool FlacEncoder::encode(QWidget *widget, MultiTrackReader &src,
     unsigned int bits   = info.bits();
     unsigned int length = info.length();
 
-#if defined(FLAC_API_VERSION_1_1_3) /* or above */
     set_compression_level(5); // @todo make the FLAC compression configurable
-#endif
     set_channels(static_cast<unsigned>(tracks));
     set_bits_per_sample(static_cast<unsigned>(bits));
     set_sample_rate(static_cast<unsigned>(info.rate()));
@@ -220,7 +215,6 @@ bool FlacEncoder::encode(QWidget *widget, MultiTrackReader &src,
 	}
 
 	// initialize the FLAC stream, this already writes some meta info
-#if defined(FLAC_API_VERSION_1_1_3) /* or above */
         FLAC__StreamEncoderInitStatus init_state = init();
         if (init_state != FLAC__STREAM_ENCODER_INIT_STATUS_OK) {
             qWarning("state = %d", static_cast<int>(init_state));
@@ -229,17 +223,6 @@ bool FlacEncoder::encode(QWidget *widget, MultiTrackReader &src,
             result = false;
             break;
         }
-#else
-	FLAC::Encoder::Stream::State init_state = init();
-	if (init_state != FLAC__STREAM_ENCODER_OK) {
-            qWarning("state = %s", init_state.as_cstring());
-            Kwave::MessageBox::error(widget,
-                i18n("Unable to open the FLAC encoder."));
-            m_info = 0;
-            result = false;
-            break;
-        }
-#endif
 
 	// allocate output buffers, with FLAC 32 bit format
 	unsigned int len = src.blockSize(); // samples
@@ -280,7 +263,7 @@ bool FlacEncoder::encode(QWidget *widget, MultiTrackReader &src,
 
 	    // add all samples to one single buffer
 	    for (int track=0; track < tracks; track++) {
-		SampleReader *reader = src[track];
+		Kwave::SampleReader *reader = src[track];
 		Q_ASSERT(reader);
 		if (!reader) break;
 
