@@ -1,5 +1,5 @@
 /*************************************************************************
-     OggCodecPlugin.cpp  -  import/export of Ogg/Vorbis data
+     OggCodecPlugin.cpp  -  import/export of audio in an Ogg container
                              -------------------
     begin                : Tue Sep 10 2002
     copyright            : (C) 2002 by Thomas Eschenbacher
@@ -24,30 +24,33 @@
 #include "OggEncoder.h"
 #include "OggDecoder.h"
 
-KWAVE_PLUGIN(OggCodecPlugin, "codec_ogg", "2.1",
+KWAVE_PLUGIN(Kwave::OggCodecPlugin, "codec_ogg", "2.3",
              I18N_NOOP("Ogg Codec"), "Thomas Eschenbacher");
 
+// static instance of the codec container
+Kwave::CodecPlugin::Codec Kwave::OggCodecPlugin::m_codec = {0, 0, 0};
+
 /***************************************************************************/
-OggCodecPlugin::OggCodecPlugin(const PluginContext &c)
-    :Kwave::Plugin(c), m_decoder(0), m_encoder(0)
+Kwave::OggCodecPlugin::OggCodecPlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::CodecPlugin(plugin_manager, m_codec)
 {
 }
 
 /***************************************************************************/
-OggCodecPlugin::~OggCodecPlugin()
+Kwave::OggCodecPlugin::~OggCodecPlugin()
 {
 }
 
 /***************************************************************************/
-void OggCodecPlugin::load(QStringList &/* params */)
+Kwave::Decoder *Kwave::OggCodecPlugin::createDecoder()
 {
-    if (!m_encoder) m_encoder = new OggEncoder();
-    Q_ASSERT(m_encoder);
-    if (m_encoder) CodecManager::registerEncoder(*m_encoder);
+    return new Kwave::OggDecoder();
+}
 
-    if (!m_decoder) m_decoder = new OggDecoder();
-    Q_ASSERT(m_decoder);
-    if (m_decoder) CodecManager::registerDecoder(*m_decoder);
+/***************************************************************************/
+Kwave::Encoder *Kwave::OggCodecPlugin::createEncoder()
+{
+    return new Kwave::OggEncoder();
 }
 
 //***************************************************************************
