@@ -18,26 +18,26 @@
 #include "config.h"
 #include <stdlib.h>
 
-extern "C" {
 #include <audiofile.h>
-}
 
-#include <QApplication>
-#include <QList>
-#include <QProgressDialog>
-#include <QtGlobal>
+#include <QtCore/QtEndian>
+#include <QtCore/QtGlobal>
+#include <QtCore/QList>
+#include <QtGui/QApplication>
+#include <QtGui/QProgressDialog>
 
 #include <klocale.h>
 #include <kmimetype.h>
 
-#include "libkwave/byteswap.h"
 #include "libkwave/ConfirmCancelProxy.h"
-#include "libkwave/MultiWriter.h"
 #include "libkwave/Label.h"
+#include "libkwave/LabelList.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/MetaData.h"
 #include "libkwave/MetaDataList.h"
+#include "libkwave/MultiWriter.h"
 #include "libkwave/Sample.h"
+#include "libkwave/String.h"
 #include "libkwave/VirtualAudioFile.h"
 #include "libkwave/Writer.h"
 
@@ -51,70 +51,62 @@ extern "C" {
 #include "WavFileFormat.h"
 #include "WavFormatMap.h"
 
-// some byteswapping helper macros
-#if Q_BYTE_ORDER == Q_BIG_ENDIAN
-#define CPU_TO_LE32(x) (bswap_32(x))
-#define LE32_TO_CPU(x) (bswap_32(x))
-#else
-#define CPU_TO_LE32(x) (x)
-#define LE32_TO_CPU(x) (x)
-#endif
-
 #define CHECK(cond) Q_ASSERT(cond); if (!(cond)) { src.close(); return false; }
 
 //***************************************************************************
-WavDecoder::WavDecoder()
-    :Decoder(), m_source(0), m_src_adapter(0), m_known_chunks(),
+Kwave::WavDecoder::WavDecoder()
+    :Kwave::Decoder(), m_source(0), m_src_adapter(0), m_known_chunks(),
      m_property_map()
 {
-    LOAD_MIME_TYPES;
+    REGISTER_MIME_TYPES;
+    REGISTER_COMPRESSION_TYPES;
 
     // native WAVE chunk names
-    m_known_chunks.append("cue "); /* Markers */
-    m_known_chunks.append("data"); /* Sound Data */
-    m_known_chunks.append("fact"); /* Fact (length in samples) */
-    m_known_chunks.append("fmt "); /* Format */
-    m_known_chunks.append("inst"); /* Instrument */
-    m_known_chunks.append("labl"); /* label */
-    m_known_chunks.append("ltxt"); /* labeled text */
-    m_known_chunks.append("note"); /* note chunk */
-    m_known_chunks.append("plst"); /* Play List */
-    m_known_chunks.append("smpl"); /* Sampler */
+    m_known_chunks.append(_("cue ")); /* Markers */
+    m_known_chunks.append(_("data")); /* Sound Data */
+    m_known_chunks.append(_("fact")); /* Fact (length in samples) */
+    m_known_chunks.append(_("fmt ")); /* Format */
+    m_known_chunks.append(_("inst")); /* Instrument */
+    m_known_chunks.append(_("labl")); /* label */
+    m_known_chunks.append(_("ltxt")); /* labeled text */
+    m_known_chunks.append(_("note")); /* note chunk */
+    m_known_chunks.append(_("plst")); /* Play List */
+    m_known_chunks.append(_("smpl")); /* Sampler */
 
     // add all sub-chunks of the LIST chunk (properties)
     foreach (QByteArray name, m_property_map.chunks())
-	m_known_chunks.append( name );
+	m_known_chunks.append(QLatin1String(name));
 
     // some chunks known from AIFF format
-    m_known_chunks.append("FVER");
-    m_known_chunks.append("COMM");
-    m_known_chunks.append("wave");
-    m_known_chunks.append("SSND");
+    m_known_chunks.append(_("FVER"));
+    m_known_chunks.append(_("COMM"));
+    m_known_chunks.append(_("wave"));
+    m_known_chunks.append(_("SSND"));
 
     // chunks of .lbm image files, IFF format
-    m_known_chunks.append("BMHD");
-    m_known_chunks.append("CMAP");
-    m_known_chunks.append("BODY");
+    m_known_chunks.append(_("BMHD"));
+    m_known_chunks.append(_("CMAP"));
+    m_known_chunks.append(_("BODY"));
 }
 
 //***************************************************************************
-WavDecoder::~WavDecoder()
+Kwave::WavDecoder::~WavDecoder()
 {
     if (m_source) close();
     if (m_src_adapter) delete m_src_adapter;
 }
 
 //***************************************************************************
-Decoder *WavDecoder::instance()
+Kwave::Decoder *Kwave::WavDecoder::instance()
 {
-    return new WavDecoder();
+    return new Kwave::WavDecoder();
 }
 
 //***************************************************************************
-bool WavDecoder::open(QWidget *widget, QIODevice &src)
+bool Kwave::WavDecoder::open(QWidget *widget, QIODevice &src)
 {
-    FileInfo info;
-    LabelList labels;
+    Kwave::FileInfo info;
+    Kwave::LabelList labels;
     metaData().clear();
 
     Q_ASSERT(!m_source);
@@ -128,13 +120,13 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     }
 
     QStringList main_chunks;
-    main_chunks.append("RIFF"); /* RIFF, little-endian */
-    main_chunks.append("RIFX"); /* RIFF, big-endian */
-    main_chunks.append("FORM"); /* used in AIFF, big-endian or IFF/.lbm */
-    main_chunks.append("LIST"); /* additional information */
-    main_chunks.append("adtl"); /* Associated Data */
+    main_chunks.append(_("RIFF")); /* RIFF, little-endian */
+    main_chunks.append(_("RIFX")); /* RIFF, big-endian */
+    main_chunks.append(_("FORM")); /* used in AIFF, BE or IFF/.lbm */
+    main_chunks.append(_("LIST")); /* additional information */
+    main_chunks.append(_("adtl")); /* Associated Data */
 
-    RIFFParser parser(src, main_chunks, m_known_chunks);
+    Kwave::RIFFParser parser(src, main_chunks, m_known_chunks);
 
     // prepare a progress dialog
     QProgressDialog progress(widget);
@@ -149,7 +141,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
             &progress, SLOT(setValue(int)));
     connect(&parser,   SIGNAL(action(const QString &)),
             &progress, SLOT(setLabelText(const QString &)));
-    ConfirmCancelProxy confirm_cancel(widget,
+    Kwave::ConfirmCancelProxy confirm_cancel(widget,
                        &progress, SIGNAL(canceled()),
                        &parser,   SLOT(cancel()));
 
@@ -162,9 +154,9 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 //     parser.dumpStructure();
 
     // check if there is a RIFF chunk at all...
-    RIFFChunk *riff_chunk = parser.findChunk("/RIFF:WAVE");
-    RIFFChunk *fmt_chunk  = parser.findChunk("/RIFF:WAVE/fmt ");
-    RIFFChunk *data_chunk = parser.findChunk("/RIFF:WAVE/data");
+    Kwave::RIFFChunk *riff_chunk = parser.findChunk("/RIFF:WAVE");
+    Kwave::RIFFChunk *fmt_chunk  = parser.findChunk("/RIFF:WAVE/fmt ");
+    Kwave::RIFFChunk *data_chunk = parser.findChunk("/RIFF:WAVE/data");
 
     if (!riff_chunk || !fmt_chunk || !data_chunk || !parser.isSane()) {
 	if (Kwave::MessageBox::warningContinueCancel(widget,
@@ -218,12 +210,12 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	need_repair = true;
     }
 
-    u_int32_t fmt_offset = 0;
+    quint32 fmt_offset = 0;
     if (fmt_chunk) fmt_offset = fmt_chunk->dataStart();
 //     qDebug("fmt chunk starts at 0x%08X", fmt_offset);
 
-//     u_int32_t data_offset = 0;
-    u_int32_t data_size = 0;
+//     quint32 data_offset = 0;
+    quint32 data_size = 0;
     if (data_chunk) {
 // 	data_offset = data_chunk->dataStart();
 	data_size   = data_chunk->physLength();
@@ -278,7 +270,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     m_source = &src;
 
     // read the wave header
-    wav_fmt_header_t header;
+    Kwave::wav_fmt_header_t header;
 
     unsigned int rate = 0;
     unsigned int bits = 0;
@@ -287,29 +279,28 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
     // get the encoded block of data from the mime source
     CHECK(static_cast<unsigned int>(src.size()) >
-          sizeof(wav_header_t) + 8);
+          sizeof(Kwave::wav_header_t) + 8);
 
     // get the header
-    src.read(reinterpret_cast<char *>(&header), sizeof(wav_fmt_header_t));
-#if Q_BYTE_ORDER == Q_BIG_ENDIAN
-    header.min.format      = bswap_16(header.min.format);
-    header.min.channels    = bswap_16(header.min.channels);
-    header.min.samplerate  = bswap_32(header.min.samplerate);
-    header.min.bytespersec = bswap_32(header.min.bytespersec);
-    header.min.blockalign  = bswap_16(header.min.blockalign);
-    header.min.bitwidth    = bswap_16(header.min.bitwidth);
-#endif
+    src.read(reinterpret_cast<char *>(&header), sizeof(Kwave::wav_fmt_header_t));
+    header.min.format      = qFromLittleEndian<quint16>(header.min.format);
+    header.min.channels    = qFromLittleEndian<quint16>(header.min.channels);
+    header.min.samplerate  = qFromLittleEndian<quint32>(header.min.samplerate);
+    header.min.bytespersec = qFromLittleEndian<quint32>(header.min.bytespersec);
+    header.min.blockalign  = qFromLittleEndian<quint16>(header.min.blockalign);
+    header.min.bitwidth    = qFromLittleEndian<quint16>(header.min.bitwidth);
+
     unsigned int tracks = header.min.channels;
     rate = header.min.samplerate;
     bits = header.min.bitwidth;
 
-    WavFormatMap known_formats;
+    Kwave::WavFormatMap known_formats;
     QString format_name = known_formats.findName(header.min.format);
 
 //     qDebug("-------------------------");
 //     qDebug("wav header:");
 //     qDebug("format      = 0x%04X, (%s)", header.min.format,
-//                                          format_name.toLocal8Bit().data());
+//                                          DBG(format_name));
 //     qDebug("channels    = %d", header.min.channels);
 //     qDebug("rate        = %u", header.min.samplerate);
 //     qDebug("bytes/s     = %u", header.min.bytespersec);
@@ -319,18 +310,19 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
     // open the file through libaudiofile :)
     if (need_repair) {
-	QList<RecoverySource *> *repair_list = new QList<RecoverySource *>();
+	QList<Kwave::RecoverySource *> *repair_list =
+	    new QList<Kwave::RecoverySource *>();
 	Q_ASSERT(repair_list);
 	if (!repair_list) return false;
 
-	RIFFChunk *root = (riff_chunk) ? riff_chunk : parser.findChunk("");
+	Kwave::RIFFChunk *root = (riff_chunk) ? riff_chunk : parser.findChunk("");
 // 	parser.dumpStructure();
 //	qDebug("riff chunk = %p, parser.findChunk('')=%p", riff_chunk,
 //	    parser.findChunk(""));
 	repair(repair_list, root, fmt_chunk, data_chunk);
-	m_src_adapter = new RepairVirtualAudioFile(*m_source, repair_list);
+	m_src_adapter = new Kwave::RepairVirtualAudioFile(*m_source, repair_list);
     } else {
-	m_src_adapter = new VirtualAudioFile(*m_source);
+	m_src_adapter = new Kwave::VirtualAudioFile(*m_source);
     }
 
     Q_ASSERT(m_src_adapter);
@@ -345,7 +337,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	switch (m_src_adapter->lastError()) {
 	    case AF_BAD_NOT_IMPLEMENTED:
 	        reason = i18n("Format or function is not implemented") +
-		         "\n("+format_name+")";
+		         _("\n(") + format_name + _(")");
 	        break;
 	    case AF_BAD_MALLOC:
 	        reason = i18n("Out of memory");
@@ -355,7 +347,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	        break;
 	    case AF_BAD_CODEC_TYPE:
 	        reason = i18n("Invalid codec type") +
-		         "\n("+format_name+")";
+		         _("\n(") + format_name + _(")");
 	        break;
 	    case AF_BAD_OPEN:
 	        reason = i18n("Opening the file failed");
@@ -394,20 +386,20 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     info.setBits(bits);
     info.setTracks(tracks);
     info.setLength(length);
-    info.set(INF_SAMPLE_FORMAT, sample_format);
-    info.set(INF_COMPRESSION, compression);
+    info.set(Kwave::INF_SAMPLE_FORMAT, sample_format);
+    info.set(Kwave::INF_COMPRESSION, compression);
 
     // read in all info from the LIST (INFO) chunk
-    RIFFChunk *info_chunk = parser.findChunk("/RIFF:WAVE/LIST:INFO");
+    Kwave::RIFFChunk *info_chunk = parser.findChunk("/RIFF:WAVE/LIST:INFO");
     if (info_chunk) {
 	// found info chunk !
-	RIFFChunkList &list = info_chunk->subChunks();
-	foreach (RIFFChunk *chunk, list) {
+	Kwave::RIFFChunkList &list = info_chunk->subChunks();
+	foreach (Kwave::RIFFChunk *chunk, list) {
 	    if (!chunk) continue;
 	    if (!m_property_map.containsChunk(chunk->name())) continue;
 
 	    // read the content into a QString
-	    FileProperty prop = m_property_map.property(chunk->name());
+	    Kwave::FileProperty prop = m_property_map.property(chunk->name());
 	    unsigned int offset = chunk->dataStart();
 	    unsigned int length = chunk->dataLength();
 	    QByteArray buffer(length+1, 0x00);
@@ -421,35 +413,35 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     }
 
     // read in the Labels (cue list)
-    RIFFChunk *cue_chunk = parser.findChunk("/RIFF:WAVE/cue ");
+    Kwave::RIFFChunk *cue_chunk = parser.findChunk("/RIFF:WAVE/cue ");
     if (cue_chunk) {
 	// found a cue list chunk !
-	u_int32_t count;
+	quint32 count;
 
 	src.seek(cue_chunk->dataStart());
 	src.read(reinterpret_cast<char *>(&count), 4);
-	count = LE32_TO_CPU(count);
+	count = qFromLittleEndian<quint32>(count);
 // 	unsigned int length = cue_chunk->dataLength();
 // 	qDebug("cue list found: %u entries, %u bytes (should be: %u)",
 // 	    count, length, count * (6 * 4) + 4);
 
 	for (unsigned int i = 0; i < count; i++) {
-	    u_int32_t data, index, position;
+	    quint32 data, index, position;
 	    src.seek(cue_chunk->dataStart() + 4 + ((6 * 4) * i));
 	    /*
 	     * typedef struct {
-	     *     u_int32_t dwIdentifier; <- index
-	     *     u_int32_t dwPosition;   <- 0
-	     *     u_int32_t fccChunk;     <- 'data'
-	     *     u_int32_t dwChunkStart; <- 0
-	     *     u_int32_t dwBlockStart; <- 0
-	     *     u_int32_t dwSampleOffset; <- label.pos()
+	     *     quint32 dwIdentifier; <- index
+	     *     quint32 dwPosition;   <- 0
+	     *     quint32 fccChunk;     <- 'data'
+	     *     quint32 dwChunkStart; <- 0
+	     *     quint32 dwBlockStart; <- 0
+	     *     quint32 dwSampleOffset; <- label.pos()
 	     * } cue_list_entry_t;
 	     */
 
 	    /* dwIdentifier */
 	    src.read(reinterpret_cast<char *>(&data), 4);
-	    index = LE32_TO_CPU(data);
+	    index = qFromLittleEndian<quint32>(data);
 
 	    /* dwPosition (ignored) */
 	    src.read(reinterpret_cast<char *>(&data), 4);
@@ -480,23 +472,24 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	    }
 
 	    src.read(reinterpret_cast<char *>(&data), 4); /* dwSampleOffset */
-	    position = LE32_TO_CPU(data);
+	    position = qFromLittleEndian<quint32>(data);
 
 	    // as we now have index and position, find out the name
 	    QByteArray name = "";
-	    RIFFChunk *adtl_chunk = parser.findChunk("/RIFF:WAVE/LIST:adtl");
+	    Kwave::RIFFChunk *adtl_chunk =
+		parser.findChunk("/RIFF:WAVE/LIST:adtl");
 	    if (adtl_chunk) {
-		RIFFChunk *labl_chunk = 0;
+		Kwave::RIFFChunk *labl_chunk = 0;
 		bool found = false;
-		QListIterator<RIFFChunk *> it(adtl_chunk->subChunks());
+		QListIterator<Kwave::RIFFChunk *> it(adtl_chunk->subChunks());
 		while (it.hasNext()) {
-		    u_int32_t data, labl_index;
+		    quint32 data, labl_index;
 		    labl_chunk = it.next();
 		    /*
 		     * typedef struct {
-		     *     u_int32_t dwChunkID;    <- 'labl'
-		     *     u_int32_t dwChunkSize;  (without padding !)
-		     *     u_int32_t dwIdentifier; <- index
+		     *     quint32 dwChunkID;    <- 'labl'
+		     *     quint32 dwChunkSize;  (without padding !)
+		     *     quint32 dwIdentifier; <- index
 		     *     char    dwText[];       <- label->name()
 		     * } label_list_entry_t;
 		     */
@@ -505,7 +498,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 		    data = 0;
 		    src.seek(labl_chunk->dataStart());
 		    src.read(reinterpret_cast<char *>(&data), 4); /* dwIdentifier */
-		    labl_index = LE32_TO_CPU(data);
+		    labl_index = qFromLittleEndian<quint32>(data);
 		    if (labl_index == index) {
 			found = true;
 			break; /* found it! */
@@ -532,7 +525,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
 	    // put a new label into the list
 	    QString str = QString::fromUtf8(name);
-	    labels.append(Label(position, str));
+	    labels.append(Kwave::Label(position, str));
 	}
     }
     labels.sort();
@@ -552,7 +545,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 }
 
 //***************************************************************************
-bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
+bool Kwave::WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 {
     Q_ASSERT(m_src_adapter);
     Q_ASSERT(m_source);
@@ -579,14 +572,14 @@ bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 
     // allocate a buffer for input data
     const unsigned int buffer_frames = (8*1024);
-    int32_t *buffer = static_cast<int32_t *>(
+    qint32 *buffer = static_cast<qint32 *>(
 	malloc(buffer_frames * frame_size));
     Q_ASSERT(buffer);
     if (!buffer) return false;
 
     // read in from the audiofile source
-    Q_ASSERT(tracks == FileInfo(metaData()).tracks());
-    sample_index_t rest = FileInfo(metaData()).length();
+    Q_ASSERT(tracks == Kwave::FileInfo(metaData()).tracks());
+    sample_index_t rest = Kwave::FileInfo(metaData()).length();
     while (rest) {
 	unsigned int frames = buffer_frames;
 	if (frames > rest) frames = rest;
@@ -598,11 +591,11 @@ bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 	rest -= buffer_used;
 
 	// split into the tracks
-	int32_t *p = buffer;
+	qint32 *p = buffer;
 	unsigned int count = buffer_used;
 	while (count--) {
 	    for (unsigned int track = 0; track < tracks; track++) {
-		int32_t s = *p++;
+		qint32 s = *p++;
 
 		// adjust precision
 		if (SAMPLE_STORAGE_BITS != SAMPLE_BITS) {
@@ -610,7 +603,7 @@ bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 		}
 
 		// the following cast is only necessary if
-		// sample_t is not equal to a u_int32_t
+		// sample_t is not equal to a quint32
 		Q_ASSERT(writer_fast[track]);
 		*(writer_fast[track]) << static_cast<sample_t>(s);
 	    }
@@ -626,8 +619,9 @@ bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 }
 
 //***************************************************************************
-bool WavDecoder::repairChunk(QList<RecoverySource *> *repair_list,
-    RIFFChunk *chunk, u_int32_t &offset)
+bool Kwave::WavDecoder::repairChunk(
+    QList<Kwave::RecoverySource *> *repair_list,
+    Kwave::RIFFChunk *chunk, quint32 &offset)
 {
     Q_ASSERT(chunk);
     Q_ASSERT(m_source);
@@ -637,26 +631,26 @@ bool WavDecoder::repairChunk(QList<RecoverySource *> *repair_list,
     if (!repair_list) return false;
 
     char buffer[16];
-    u_int32_t length;
-    RecoverySource *repair = 0;
+    quint32 length;
+    Kwave::RecoverySource *repair = 0;
 
     // create buffer with header
     strncpy(buffer, chunk->name().data(), 4);
-    length = (chunk->type() == RIFFChunk::Main) ? chunk->physLength() :
-                                                  chunk->dataLength();
+    length = (chunk->type() == Kwave::RIFFChunk::Main) ? chunk->physLength() :
+                                                         chunk->dataLength();
     buffer[4] = (length      ) & 0xFF;
     buffer[5] = (length >>  8) & 0xFF;
     buffer[6] = (length >> 16) & 0xFF;
     buffer[7] = (length >> 24) & 0xFF;
-    if (chunk->type() == RIFFChunk::Main) {
+    if (chunk->type() == Kwave::RIFFChunk::Main) {
 	strncpy(&(buffer[8]), chunk->format().data(), 4);
-	repair = new RecoveryBuffer(offset, 12, buffer);
+	repair = new Kwave::RecoveryBuffer(offset, 12, buffer);
 	qDebug("[0x%08X-0x%08X] - main header '%s' (%s), len=%u",
 	      offset, offset+11, chunk->name().data(),
 	      chunk->format().data(), length);
 	offset += 12;
     } else {
-	repair = new RecoveryBuffer(offset, 8, buffer);
+	repair = new Kwave::RecoveryBuffer(offset, 8, buffer);
 	qDebug("[0x%08X-0x%08X] - sub header '%s', len=%u",
 	      offset, offset+7, chunk->name().data(), length);
 	offset += 8;
@@ -666,11 +660,11 @@ bool WavDecoder::repairChunk(QList<RecoverySource *> *repair_list,
     repair_list->append(repair);
 
     // map the chunk's data if not main or root
-    if ((chunk->type() != RIFFChunk::Root) &&
-        (chunk->type() != RIFFChunk::Main))
+    if ((chunk->type() != Kwave::RIFFChunk::Root) &&
+        (chunk->type() != Kwave::RIFFChunk::Main))
     {
-	repair = new RecoveryMapping(offset, chunk->physLength(),
-	                             *m_source, chunk->dataStart());
+	repair = new Kwave::RecoveryMapping(offset, chunk->physLength(),
+	                                    *m_source, chunk->dataStart());
 	qDebug("[0x%08X-0x%08X] - restoring from offset 0x%08X (%u)",
 	      offset, offset+chunk->physLength()-1, chunk->dataStart(),
 	      chunk->physLength());
@@ -682,8 +676,8 @@ bool WavDecoder::repairChunk(QList<RecoverySource *> *repair_list,
     }
 
     // recursively go over all sub-chunks
-    RIFFChunkList &list = chunk->subChunks();
-    foreach (RIFFChunk *chunk, list) {
+    Kwave::RIFFChunkList &list = chunk->subChunks();
+    foreach (Kwave::RIFFChunk *chunk, list) {
 	if (!chunk) continue;
 	if (!repairChunk(repair_list, chunk, offset))
 	    return false;
@@ -693,8 +687,10 @@ bool WavDecoder::repairChunk(QList<RecoverySource *> *repair_list,
 }
 
 //***************************************************************************
-bool WavDecoder::repair(QList<RecoverySource *> *repair_list,
-    RIFFChunk *riff_chunk, RIFFChunk *fmt_chunk, RIFFChunk *data_chunk)
+bool Kwave::WavDecoder::repair(QList<Kwave::RecoverySource *> *repair_list,
+    Kwave::RIFFChunk *riff_chunk,
+    Kwave::RIFFChunk *fmt_chunk,
+    Kwave::RIFFChunk *data_chunk)
 {
     Q_ASSERT(fmt_chunk);
     Q_ASSERT(data_chunk);
@@ -703,18 +699,18 @@ bool WavDecoder::repair(QList<RecoverySource *> *repair_list,
     // --- first create a chunk tree for the structure ---
 
     // make a new "RIFF" chunk as root
-    RIFFChunk new_root(0, "RIFF", "WAVE", 0,0,0);
-    new_root.setType(RIFFChunk::Main);
+    Kwave::RIFFChunk new_root(0, "RIFF", "WAVE", 0,0,0);
+    new_root.setType(Kwave::RIFFChunk::Main);
 
     // create a new "fmt " chunk
-    RIFFChunk *new_fmt = new RIFFChunk(&new_root, "fmt ",0,0,
+    Kwave::RIFFChunk *new_fmt = new Kwave::RIFFChunk(&new_root, "fmt ",0,0,
 	fmt_chunk->physStart(), fmt_chunk->physLength());
     Q_ASSERT(new_fmt);
     if (!new_fmt) return false;
     new_root.subChunks().append(new_fmt);
 
     // create a new "data" chunk
-    RIFFChunk *new_data = new RIFFChunk(&new_root, "data",0,0,
+    Kwave::RIFFChunk *new_data = new Kwave::RIFFChunk(&new_root, "data",0,0,
 	data_chunk->physStart(), data_chunk->physLength());
     Q_ASSERT(new_data);
     if (!new_data) return false;
@@ -725,14 +721,14 @@ bool WavDecoder::repair(QList<RecoverySource *> *repair_list,
     // sizes and start positions.
     // NOTE: The sizes might be re-assigned and get invalid afterwards!!!
     if (riff_chunk) {
-	RIFFChunkList &list = riff_chunk->subChunks();
-	foreach (RIFFChunk *chunk, list) {
+	Kwave::RIFFChunkList &list = riff_chunk->subChunks();
+	foreach (Kwave::RIFFChunk *chunk, list) {
 	    if (!chunk) continue;
 	    if (chunk->name() == "fmt ") continue;
 	    if (chunk->name() == "data") continue;
 	    if (chunk->name() == "RIFF") continue;
-	    if (chunk->type() == RIFFChunk::Empty) continue;
-	    if (chunk->type() == RIFFChunk::Garbage) continue;
+	    if (chunk->type() == Kwave::RIFFChunk::Empty) continue;
+	    if (chunk->type() == Kwave::RIFFChunk::Garbage) continue;
 
 	    new_root.subChunks().append(chunk);
 	}
@@ -748,7 +744,7 @@ bool WavDecoder::repair(QList<RecoverySource *> *repair_list,
     // --- set up the repair list ---
 
     // RIFF chunk length
-    u_int32_t offset = 0;
+    quint32 offset = 0;
     bool repaired = repairChunk(repair_list, &new_root, offset);
 
     // clean up...
@@ -760,7 +756,7 @@ bool WavDecoder::repair(QList<RecoverySource *> *repair_list,
 }
 
 //***************************************************************************
-void WavDecoder::close()
+void Kwave::WavDecoder::close()
 {
     if (m_src_adapter) delete m_src_adapter;
     m_src_adapter = 0;
