@@ -24,11 +24,13 @@
 #include <kmimetype.h>
 #include <kglobal.h>
 
-#include <QByteArray>
-#include <QtGlobal>
+#include <QtCore/QByteArray>
+#include <QtCore/QtEndian>
+#include <QtCore/QtGlobal>
 
-#include "libkwave/byteswap.h"
+#include "libkwave/Compression.h"
 #include "libkwave/FileInfo.h"
+#include "libkwave/LabelList.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/Sample.h"
@@ -39,49 +41,42 @@
 #include "WavEncoder.h"
 #include "WavFileFormat.h"
 
-// some byteswapping helper macros
-#if Q_BYTE_ORDER == Q_BIG_ENDIAN
-#define CPU_TO_LE32(x) (bswap_32(x))
-#define LE32_TO_CPU(x) (bswap_32(x))
-#else
-#define CPU_TO_LE32(x) (x)
-#define LE32_TO_CPU(x) (x)
-#endif
-
 /***************************************************************************/
-WavEncoder::WavEncoder()
-    :Encoder(), m_property_map()
+Kwave::WavEncoder::WavEncoder()
+    :Kwave::Encoder(), m_property_map()
 {
-    LOAD_MIME_TYPES;
+    REGISTER_MIME_TYPES;
+    REGISTER_COMPRESSION_TYPES;
 }
 
 /***************************************************************************/
-WavEncoder::~WavEncoder()
+Kwave::WavEncoder::~WavEncoder()
 {
 }
 
 /***************************************************************************/
-Encoder *WavEncoder::instance()
+Kwave::Encoder *Kwave::WavEncoder::instance()
 {
-    return new WavEncoder();
+    return new Kwave::WavEncoder();
 }
 
 /***************************************************************************/
-QList<FileProperty> WavEncoder::supportedProperties()
+QList<Kwave::FileProperty> Kwave::WavEncoder::supportedProperties()
 {
     return m_property_map.properties();
 }
 
 /***************************************************************************/
-void WavEncoder::fixAudiofileBrokenHeaderBug(QIODevice &dst, FileInfo &info,
-                                             unsigned int frame_size)
+void Kwave::WavEncoder::fixAudiofileBrokenHeaderBug(QIODevice &dst,
+                                                    Kwave::FileInfo &info,
+                                                    unsigned int frame_size)
 {
     const unsigned int length = info.length();
-    u_int32_t correct_size = length * frame_size;
-    const int compression = info.contains(INF_COMPRESSION) ?
-                      info.get(INF_COMPRESSION).toInt() :
-	    AF_COMPRESSION_NONE;
-    if (compression != AF_COMPRESSION_NONE) {
+    quint32 correct_size = length * frame_size;
+    const int compression = info.contains(Kwave::INF_COMPRESSION) ?
+                      info.get(Kwave::INF_COMPRESSION).toInt() :
+	    Kwave::Compression::NONE;
+    if (compression != Kwave::Compression::NONE) {
 	qWarning("WARNING: libaudiofile might have produced a broken header!");
 	return;
     }
@@ -97,10 +92,10 @@ void WavEncoder::fixAudiofileBrokenHeaderBug(QIODevice &dst, FileInfo &info,
     }
 
     // read the data chunk size that libaudiofile has written
-    u_int32_t data_size;
+    quint32 data_size;
     dst.seek(40);
     dst.read(reinterpret_cast<char *>(&data_size), 4);
-    data_size = LE32_TO_CPU(data_size);
+    data_size = qFromLittleEndian<quint32>(data_size);
     if (data_size == length * frame_size) {
 // 	qDebug("(data size written by libaudiofile is correct)");
 	return;
@@ -111,31 +106,33 @@ void WavEncoder::fixAudiofileBrokenHeaderBug(QIODevice &dst, FileInfo &info,
 
     // write the fixed size of the "data" chunk
     dst.seek(40);
-    data_size = CPU_TO_LE32(correct_size);
+    data_size = qToLittleEndian<quint32>(correct_size);
     dst.write(reinterpret_cast<char *>(&data_size), 4);
 
     // also fix the "RIFF" size
     dst.seek(4);
-    u_int32_t riff_size = dst.size() - 4 - 4;
-    riff_size = CPU_TO_LE32(riff_size);
+    quint32 riff_size = dst.size() - 4 - 4;
+    riff_size = qToLittleEndian<quint32>(riff_size);
     dst.write(reinterpret_cast<char *>(&riff_size), 4);
 
 }
 
 /***************************************************************************/
-void WavEncoder::writeInfoChunk(QIODevice &dst, FileInfo &info)
+void Kwave::WavEncoder::writeInfoChunk(QIODevice &dst, Kwave::FileInfo &info)
 {
     // create a list of chunk names and properties for the INFO chunk
-    QMap<FileProperty, QVariant> properties(info.properties());
+    QMap<Kwave::FileProperty, QVariant> properties(info.properties());
     QMap<QByteArray, QByteArray> info_chunks;
     unsigned int info_size = 0;
 
-    QMap<FileProperty, QVariant>::Iterator it;
+    QMap<Kwave::FileProperty, QVariant>::Iterator it;
     for (it = properties.begin(); it != properties.end(); ++it) {
-	FileProperty property = it.key();
+	Kwave::FileProperty property = it.key();
 	if (!m_property_map.containsProperty(property)) continue;
 
 	QByteArray chunk_id = m_property_map.findProperty(property);
+	if (info_chunks.contains(chunk_id)) continue; // already encoded
+
 	QByteArray value = QVariant(properties[property]).toString().toUtf8();
 	info_chunks.insert(chunk_id, value);
 	info_size += 4 + 4 + value.length();
@@ -144,13 +141,14 @@ void WavEncoder::writeInfoChunk(QIODevice &dst, FileInfo &info)
 
     // if there are properties to save, create a LIST chunk
     if (!info_chunks.isEmpty()) {
-	u_int32_t size;
+	quint32 size;
 
 	// enlarge the main RIFF chunk by the size of the LIST chunk
 	info_size += 4 + 4 + 4; // add the size of LIST(INFO)
 	dst.seek(4);
 	dst.read(reinterpret_cast<char *>(&size), 4);
-	size = CPU_TO_LE32(LE32_TO_CPU(size) + info_size);
+	size = qToLittleEndian<quint32>(
+	    qFromLittleEndian<quint32>(size) + info_size);
 	dst.seek(4);
 	dst.write(reinterpret_cast<char *>(&size), 4);
 
@@ -158,7 +156,7 @@ void WavEncoder::writeInfoChunk(QIODevice &dst, FileInfo &info)
 	dst.seek(dst.size());
 	if (dst.pos() & 1) dst.write("\000", 1); // padding
 	dst.write("LIST", 4);
-	size = CPU_TO_LE32(info_size - 8);
+	size = qToLittleEndian<quint32>(info_size - 8);
 	dst.write(reinterpret_cast<char *>(&size), 4);
 	dst.write("INFO", 4);
 
@@ -169,9 +167,9 @@ void WavEncoder::writeInfoChunk(QIODevice &dst, FileInfo &info)
 	    QByteArray value = it.value();
 
 	    dst.write(name.data(), 4); // chunk name
-	    u_int32_t size = value.length(); // length of the chunk
+	    quint32 size = value.length(); // length of the chunk
 	    if (size & 0x01) size++;
-	    size = CPU_TO_LE32(size);
+	    size = qToLittleEndian<quint32>(size);
 	    dst.write(reinterpret_cast<char *>(&size), 4);
 	    dst.write(value.data(), value.length());
 	    if (value.length() & 0x01) {
@@ -183,10 +181,11 @@ void WavEncoder::writeInfoChunk(QIODevice &dst, FileInfo &info)
 }
 
 /***************************************************************************/
-void WavEncoder::writeLabels(QIODevice &dst, const LabelList &labels)
+void Kwave::WavEncoder::writeLabels(QIODevice &dst,
+                                    const Kwave::LabelList &labels)
 {
     const unsigned int labels_count = labels.count();
-    u_int32_t size, additional_size = 0, index, data;
+    quint32 size, additional_size = 0, index, data;
 
     // shortcut: nothing to do if no labels present
     if (!labels_count) return;
@@ -199,7 +198,7 @@ void WavEncoder::writeLabels(QIODevice &dst, const LabelList &labels)
 
     // now the size of the labels
     unsigned int size_of_labels = 0;
-    foreach (const Label &label, labels) {
+    foreach (const Kwave::Label &label, labels) {
 	if (label.isNull()) continue;
 	unsigned int name_len = label.name().toUtf8().size();
 	if (!name_len) continue; // skip zero-length names
@@ -219,7 +218,8 @@ void WavEncoder::writeLabels(QIODevice &dst, const LabelList &labels)
 
     dst.seek(4);
     dst.read(reinterpret_cast<char *>(&size), 4);
-    size = CPU_TO_LE32(LE32_TO_CPU(size) + additional_size);
+    size = qToLittleEndian<quint32>(
+	qFromLittleEndian<quint32>(size) + additional_size);
     dst.seek(4);
     dst.write(reinterpret_cast<char *>(&size), 4);
 
@@ -229,34 +229,34 @@ void WavEncoder::writeLabels(QIODevice &dst, const LabelList &labels)
 
     // add the 'cue ' list
     dst.write("cue ", 4);
-    size = CPU_TO_LE32(size_of_cue_list);
+    size = qToLittleEndian<quint32>(size_of_cue_list);
     dst.write(reinterpret_cast<char *>(&size), 4);
 
     // number of entries
-    size = CPU_TO_LE32(labels_count);
+    size = qToLittleEndian<quint32>(labels_count);
     dst.write(reinterpret_cast<char *>(&size), 4);
 
     index = 0;
-    foreach (const Label &label, labels) {
+    foreach (const Kwave::Label &label, labels) {
 	if (label.isNull()) continue;
 	/*
 	 * typedef struct {
-	 *     u_int32_t dwIdentifier; <- index
-	 *     u_int32_t dwPosition;   <- 0
-	 *     u_int32_t fccChunk;     <- 'data'
-	 *     u_int32_t dwChunkStart; <- 0
-	 *     u_int32_t dwBlockStart; <- 0
-	 *     u_int32_t dwSampleOffset; <- label.pos()
+	 *     quint32 dwIdentifier; <- index
+	 *     quint32 dwPosition;   <- 0
+	 *     quint32 fccChunk;     <- 'data'
+	 *     quint32 dwChunkStart; <- 0
+	 *     quint32 dwBlockStart; <- 0
+	 *     quint32 dwSampleOffset; <- label.pos()
 	 * } cue_list_entry_t;
 	 */
-	data = CPU_TO_LE32(index);
+	data = qToLittleEndian<quint32>(index);
 	dst.write(reinterpret_cast<char *>(&data), 4); // dwIdentifier
 	data = 0;
 	dst.write(reinterpret_cast<char *>(&data), 4); // dwPosition
 	dst.write("data", 4);        // fccChunk
 	dst.write(reinterpret_cast<char *>(&data), 4); // dwChunkStart
 	dst.write(reinterpret_cast<char *>(&data), 4); // dwBlockStart
-	data = CPU_TO_LE32(label.pos());
+	data = qToLittleEndian<quint32>(label.pos());
 	dst.write(reinterpret_cast<char *>(&data), 4); // dwSampleOffset
 	index++;
     }
@@ -264,29 +264,29 @@ void WavEncoder::writeLabels(QIODevice &dst, const LabelList &labels)
     // add the LIST(adtl) chunk
     if (size_of_labels) {
 	dst.write("LIST", 4);
-	size = CPU_TO_LE32(size_of_labels);
+	size = qToLittleEndian<quint32>(size_of_labels);
 	dst.write(reinterpret_cast<char *>(&size), 4);
 	dst.write("adtl", 4);
 	index = 0;
-	foreach (const Label &label, labels) {
+	foreach (const Kwave::Label &label, labels) {
 	    if (label.isNull()) continue;
 	    QByteArray name = label.name().toUtf8();
 
 	    /*
 	     * typedef struct {
-	     *     u_int32_t dwChunkID;    <- 'labl'
-	     *     u_int32_t dwChunkSize;  (without padding !)
-	     *     u_int32_t dwIdentifier; <- index
+	     *     quint32 dwChunkID;    <- 'labl'
+	     *     quint32 dwChunkSize;  (without padding !)
+	     *     quint32 dwIdentifier; <- index
 	     *     char    dwText[];       <- label->name()
 	     * } label_list_entry_t;
 	     */
 	    if (name.size()) {
 		dst.write("labl", 4);                // dwChunkID
-		data = CPU_TO_LE32(name.size() + 4);
+		data = qToLittleEndian<quint32>(name.size() + 4);
 
 		// dwChunkSize
 		dst.write(reinterpret_cast<char *>(&data), 4);
-		data = CPU_TO_LE32(index);
+		data = qToLittleEndian<quint32>(index);
 
 		// dwIdentifier
 		dst.write(reinterpret_cast<char *>(&data), 4);
@@ -303,22 +303,23 @@ void WavEncoder::writeLabels(QIODevice &dst, const LabelList &labels)
 }
 
 /***************************************************************************/
-bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
-                        QIODevice &dst, const Kwave::MetaDataList &meta_data)
+bool Kwave::WavEncoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
+                               QIODevice &dst,
+                               const Kwave::MetaDataList &meta_data)
 {
-    FileInfo info(meta_data);
+    Kwave::FileInfo info(meta_data);
 
     /* first get and check some header information */
     const unsigned int tracks = info.tracks();
     const unsigned int length = info.length();
     unsigned int bits = info.bits();
     const double rate = info.rate();
-    int sample_format = info.contains(INF_SAMPLE_FORMAT) ?
-                        info.get(INF_SAMPLE_FORMAT).toInt() :
+    int sample_format = info.contains(Kwave::INF_SAMPLE_FORMAT) ?
+                        info.get(Kwave::INF_SAMPLE_FORMAT).toInt() :
                         AF_SAMPFMT_TWOSCOMP;
-    int compression = info.contains(INF_COMPRESSION) ?
-                      info.get(INF_COMPRESSION).toInt() :
-                      AF_COMPRESSION_NONE;
+    int compression = info.contains(Kwave::INF_COMPRESSION) ?
+                      info.get(Kwave::INF_COMPRESSION).toInt() :
+                      Kwave::Compression::NONE;
 
     // use default bit resolution if missing
     Q_ASSERT(bits);
@@ -330,9 +331,9 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     if (src.tracks() != tracks) return false;
 
     // check if the chosen compression mode is supported for saving
-    if ((compression != AF_COMPRESSION_NONE) &&
-        (compression != AF_COMPRESSION_G711_ULAW) &&
-        (compression != AF_COMPRESSION_G711_ALAW))
+    if ((compression != Kwave::Compression::NONE) &&
+        (compression != Kwave::Compression::G711_ULAW) &&
+        (compression != Kwave::Compression::G711_ALAW))
     {
 	qWarning("compression mode %d not supported!", compression);
 	int what_now = Kwave::MessageBox::warningYesNoCancel(widget,
@@ -344,12 +345,14 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
 	);
 	switch (what_now) {
 	    case (KMessageBox::Yes):
-		compression = AF_COMPRESSION_G711_ULAW;
-		info.set(INF_COMPRESSION, AF_COMPRESSION_G711_ULAW);
+		info.set(Kwave::INF_COMPRESSION,
+			 Kwave::Compression::G711_ULAW);
+		compression = Kwave::Compression::G711_ULAW;
 		break;
 	    case (KMessageBox::No):
-		info.set(INF_COMPRESSION, AF_COMPRESSION_NONE);
-		compression = AF_COMPRESSION_NONE;
+		info.set(Kwave::INF_COMPRESSION,
+			 Kwave::Compression::NONE);
+		compression = Kwave::Compression::NONE;
 		break;
 	    default:
 		return false; // bye bye, save later...
@@ -358,28 +361,28 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
 
     // check for unsupported compression/bits/sample format combinations
     // G.711 and MSADPCM support only 16 bit signed as input format!
-    if ((compression == AF_COMPRESSION_G711_ULAW) ||
-        (compression == AF_COMPRESSION_G711_ALAW))
+    if ((compression == Kwave::Compression::G711_ULAW) ||
+        (compression == Kwave::Compression::G711_ALAW))
     {
 	if ((sample_format != AF_SAMPFMT_TWOSCOMP) ||
 	    (bits          != 16))
 	{
-	    const SampleFormat format(SampleFormat::Signed);
-	    info.set(INF_SAMPLE_FORMAT, QVariant(format.toInt()));
+	    const Kwave::SampleFormat format(Kwave::SampleFormat::Signed);
+	    info.set(Kwave::INF_SAMPLE_FORMAT, QVariant(format.toInt()));
 	    info.setBits(16);
 	    sample_format = AF_SAMPFMT_TWOSCOMP;
 	    bits          = 16;
 	    qDebug("auto-switching to 16 bit signed format");
 	}
     } else if ((bits <= 8) && (sample_format != AF_SAMPFMT_UNSIGNED)) {
-	const SampleFormat format(SampleFormat::Unsigned);
-	info.set(INF_SAMPLE_FORMAT, QVariant(format.toInt()));
+	const Kwave::SampleFormat format(Kwave::SampleFormat::Unsigned);
+	info.set(Kwave::INF_SAMPLE_FORMAT, QVariant(format.toInt()));
 
 	sample_format = AF_SAMPFMT_UNSIGNED;
 	qDebug("auto-switching to unsigned format");
     } else if ((bits > 8) && (sample_format != AF_SAMPFMT_TWOSCOMP)) {
-	const SampleFormat format(SampleFormat::Signed);
-	info.set(INF_SAMPLE_FORMAT, QVariant(format.toInt()));
+	const Kwave::SampleFormat format(Kwave::SampleFormat::Signed);
+	info.set(Kwave::INF_SAMPLE_FORMAT, QVariant(format.toInt()));
 
 	sample_format = AF_SAMPFMT_TWOSCOMP;
 	qDebug("auto-switching to signed format");
@@ -399,7 +402,7 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     afInitCompression(setup, AF_DEFAULT_TRACK, compression);
     afInitRate (setup, AF_DEFAULT_TRACK, rate);
 
-    VirtualAudioFile outfile(dst);
+    Kwave::VirtualAudioFile outfile(dst);
     outfile.open(&outfile, setup);
 
     AFfilehandle fh = outfile.handle();
@@ -454,7 +457,7 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     const unsigned int virtual_frame_size = static_cast<const unsigned int>(
 	    afGetVirtualFrameSize(fh, AF_DEFAULT_TRACK, 1));
     const unsigned int buffer_frames = (8*1024);
-    int32_t *buffer = static_cast<int32_t *>(
+    qint32 *buffer = static_cast<qint32 *>(
 	malloc(buffer_frames * virtual_frame_size));
     Q_ASSERT(buffer);
     if (!buffer) return false;
@@ -463,19 +466,19 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     unsigned int rest = length;
     while (rest) {
 	// merge the tracks into the sample buffer
-	int32_t *p = buffer;
+	qint32 *p = buffer;
 	unsigned int count = buffer_frames;
 	if (rest < count) count = rest;
 
 	for (unsigned int pos = 0; pos < count; pos++) {
 	    for (unsigned int track = 0; track < tracks; track++) {
-		SampleReader *stream = src[track];
+		Kwave::SampleReader *stream = src[track];
 		sample_t sample = 0;
 		if (!stream->eof()) (*stream) >> sample;
 
 		// the following cast is only necessary if
 		// sample_t is not equal to a 32bit int
-		register __uint32_t act = static_cast<__uint32_t>(sample);
+		register quint32 act = static_cast<quint32>(sample);
 		act *= (1 << (SAMPLE_STORAGE_BITS - SAMPLE_BITS));
 		*p = act;
 		p++;
@@ -513,7 +516,7 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     writeInfoChunk(dst, info);
 
     // write the labels list
-    writeLabels(dst, LabelList(meta_data));
+    writeLabels(dst, Kwave::LabelList(meta_data));
 
     return true;
 }
