@@ -21,31 +21,33 @@
 #include "libkwave/MessageBox.h"
 #include "libkwave/PluginManager.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 
 #include "FileInfoDialog.h"
 #include "FileInfoPlugin.h"
 
-KWAVE_PLUGIN(FileInfoPlugin, "fileinfo", "2.1",
+KWAVE_PLUGIN(Kwave::FileInfoPlugin, "fileinfo", "2.3",
              I18N_NOOP("File Info"), "Thomas Eschenbacher");
 
 //***************************************************************************
-FileInfoPlugin::FileInfoPlugin(const PluginContext &context)
-    :Kwave::Plugin(context)
+Kwave::FileInfoPlugin::FileInfoPlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager)
 {
 }
 
 //***************************************************************************
-FileInfoPlugin::~FileInfoPlugin()
+Kwave::FileInfoPlugin::~FileInfoPlugin()
 {
 }
 
 //***************************************************************************
-QStringList *FileInfoPlugin::setup(QStringList &)
+QStringList *Kwave::FileInfoPlugin::setup(QStringList &)
 {
-    FileInfo oldInfo(signalManager().metaData());
+    Kwave::FileInfo oldInfo(signalManager().metaData());
 
     // create the setup dialog
-    FileInfoDialog *dialog = new FileInfoDialog(parentWidget(), oldInfo);
+    Kwave::FileInfoDialog *dialog =
+	new Kwave::FileInfoDialog(parentWidget(), oldInfo);
     Q_ASSERT(dialog);
     if (!dialog) return 0;
 
@@ -65,9 +67,9 @@ QStringList *FileInfoPlugin::setup(QStringList &)
 }
 
 //***************************************************************************
-void FileInfoPlugin::apply(FileInfo &new_info)
+void Kwave::FileInfoPlugin::apply(Kwave::FileInfo &new_info)
 {
-    FileInfo old_info(signalManager().metaData());
+    Kwave::FileInfo old_info(signalManager().metaData());
     if (old_info == new_info) return; // nothing to do
 
     /* sample rate */
@@ -81,12 +83,12 @@ void FileInfoPlugin::apply(FileInfo &new_info)
 		 "you only want to set the rate information in order "
 		 "to repair a damaged file? Note: changing only the sample "
 		 "rate can cause \"mickey mouse\" effects."),
-	    0,
+	    QString(),
 	    i18n("&Convert"),
 	    i18n("&Set Rate"));
 	if (res == KMessageBox::Yes) {
 	    // Yes -> resample
-	    
+
 	    // take over all properties except the new sample rate, this will
 	    // be detected and changed in the sample rate plugin
 	    new_info.setRate(old_info.rate());
@@ -96,8 +98,7 @@ void FileInfoPlugin::apply(FileInfo &new_info)
 
 	    // NOTE: this command could be executed asynchronously, thus
 	    //       we cannot change the sample rate afterwards
-	    emitCommand(QString(
-		"plugin:execute(samplerate,%1,all)").arg(new_rate)
+	    emitCommand(_("plugin:execute(samplerate,%1,all)").arg(new_rate)
 	    );
 
 	    return;
