@@ -17,11 +17,13 @@
 
 #include "config.h"
 
+#include <QtGui/QPushButton>
+
 #include "GotoDialog.h"
 
 //***************************************************************************
-GotoDialog::GotoDialog(QWidget *widget, Mode mode, sample_index_t pos,
-                       double sample_rate, sample_index_t signal_length)
+Kwave::GotoDialog::GotoDialog(QWidget *widget, Mode mode, sample_index_t pos,
+                              double sample_rate, sample_index_t signal_length)
     :QDialog(widget), Ui::GotoDlg()
 {
     setupUi(this);
@@ -34,15 +36,18 @@ GotoDialog::GotoDialog(QWidget *widget, Mode mode, sample_index_t pos,
 
     setMinimumSize(sizeHint());
     setFixedSize(sizeHint());
+
+    // set the focus onto the "OK" button
+    buttonBox->button(QDialogButtonBox::Ok)->setFocus();
 }
 
 //***************************************************************************
-GotoDialog::~GotoDialog()
+Kwave::GotoDialog::~GotoDialog()
 {
 }
 
 //***************************************************************************
-void GotoDialog::setMode(SelectTimeWidget::Mode new_mode)
+void Kwave::GotoDialog::setMode(Kwave::SelectTimeWidget::Mode new_mode)
 {
     if (select_pos) select_pos->setMode(new_mode);
 }
