@@ -17,34 +17,36 @@
 
 #include "config.h"
 
-#include <QString>
+#include <QtCore/QString>
 #include <klocale.h>
 
-#include "libkwave/KwavePlugin.h"
+#include "libkwave/Plugin.h"
+#include "libkwave/String.h"
+
 #include "GotoPlugin.h"
 
-KWAVE_PLUGIN(GotoPlugin, "goto", "2.1",
+KWAVE_PLUGIN(Kwave::GotoPlugin, "goto", "2.3",
              I18N_NOOP("Goto Position"), "Thomas Eschenbacher");
 
 //***************************************************************************
-GotoPlugin::GotoPlugin(const PluginContext &c)
-    :GotoPluginBase(c)
+Kwave::GotoPlugin::GotoPlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::GotoPluginBase(plugin_manager)
 {
 }
 
 //***************************************************************************
-GotoPlugin::~GotoPlugin()
+Kwave::GotoPlugin::~GotoPlugin()
 {
 }
 
 //***************************************************************************
-QString GotoPlugin::command() const
-{ 
-    return "goto";
+QString Kwave::GotoPlugin::command() const
+{
+    return _("goto");
 }
-    
+
 //***************************************************************************
-QString GotoPlugin::title() const 
+QString Kwave::GotoPlugin::title() const
 {
     return i18n("Goto...");
 }
