@@ -22,10 +22,10 @@
 
 #include <math.h>
 
-#include <QList>
-#include <QStringList>
-#include <QThread>
-#include <QVector>
+#include <QtCore/QList>
+#include <QtCore/QStringList>
+#include <QtCore/QThread>
+#include <QtCore/QVector>
 
 #include <klocale.h> // for the i18n macro
 #include <threadweaver/Job.h>
@@ -33,7 +33,7 @@
 #include <threadweaver/DebuggingAids.h>
 
 #include "libkwave/FileInfo.h"
-#include "libkwave/KwaveConnect.h"
+#include "libkwave/Connect.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/MultiTrackWriter.h"
 #include "libkwave/PluginManager.h"
@@ -51,62 +51,66 @@
 /** target volume level [dB] */
 #define TARGET_LEVEL -12
 
-KWAVE_PLUGIN(NormalizePlugin, "normalize", "2.1",
+KWAVE_PLUGIN(Kwave::NormalizePlugin, "normalize", "2.3",
              I18N_NOOP("Normalizer"), "Thomas Eschenbacher");
 
 //***************************************************************************
-class GetMaxPowerJob: public ThreadWeaver::Job
+namespace Kwave
 {
-public:
-    typedef struct {
-	QVector<double> fifo; /**< FIFO for power values */
-	unsigned int    wp;   /**< FIFO write pointer */
-	unsigned int    n;    /**< number of elements in the FIFO */
-	double          sum;  /**< sum of queued power values */
-	double          max;  /**< maximum power value */
-    } average_t;
+    class GetMaxPowerJob: public ThreadWeaver::Job
+    {
+    public:
+	typedef struct {
+	    QVector<double> fifo; /**< FIFO for power values */
+	    unsigned int    wp;   /**< FIFO write pointer */
+	    unsigned int    n;    /**< number of elements in the FIFO */
+	    double          sum;  /**< sum of queued power values */
+	    double          max;  /**< maximum power value */
+	} average_t;
 
-    /**
-     * Constructor
-     * @param reader reference to a SampleReader to read from
-     * @param average reference to smoothing information
-     * @param window_size length of the sliding window for volume detection
-     */
-    GetMaxPowerJob(SampleReader &reader, average_t &average,
-                   unsigned int window_size);
-
-    /** Destructor */
-    virtual ~GetMaxPowerJob();
-
-    /**
-	* overloaded 'run' function that runns goOn() in the context
-	* of the worker thread.
+	/**
+	* Constructor
+	* @param reader reference to a SampleReader to read from
+	* @param average reference to smoothing information
+	* @param window_size length of the sliding window for volume detection
 	*/
-    virtual void run();
+	GetMaxPowerJob(Kwave::SampleReader &reader, average_t &average,
+		    unsigned int window_size);
 
-private:
+	/** Destructor */
+	virtual ~GetMaxPowerJob();
 
-    /** reference to the SampleReader */
-    SampleReader &m_reader;
+	/**
+	    * overloaded 'run' function that runns goOn() in the context
+	    * of the worker thread.
+	    */
+	virtual void run();
 
-    /** reference to the smoothing information */
-    average_t &m_average;
+    private:
 
-    /** size of a processing window */
-    unsigned int m_window_size;
+	/** reference to the SampleReader */
+	Kwave::SampleReader &m_reader;
 
-};
+	/** reference to the smoothing information */
+	average_t &m_average;
+
+	/** size of a processing window */
+	unsigned int m_window_size;
+
+    };
+}
 
 //***************************************************************************
-GetMaxPowerJob::GetMaxPowerJob(SampleReader &reader, average_t &average,
-                               unsigned int window_size)
+Kwave::GetMaxPowerJob::GetMaxPowerJob(Kwave::SampleReader &reader,
+                                      average_t &average,
+                                      unsigned int window_size)
     :ThreadWeaver::Job(), m_reader(reader), m_average(average),
      m_window_size(window_size)
 {
 }
 
 //***************************************************************************
-GetMaxPowerJob::~GetMaxPowerJob()
+Kwave::GetMaxPowerJob::~GetMaxPowerJob()
 {
     int i = 0;
     while (!isFinished()) {
@@ -117,7 +121,7 @@ GetMaxPowerJob::~GetMaxPowerJob()
 }
 
 //***************************************************************************
-void GetMaxPowerJob::run()
+void Kwave::GetMaxPowerJob::run()
 {
     Kwave::SampleArray data(m_window_size);
     unsigned int round = 0;
@@ -158,21 +162,21 @@ void GetMaxPowerJob::run()
 //***************************************************************************
 //***************************************************************************
 
-NormalizePlugin::NormalizePlugin(const PluginContext &context)
-    :Kwave::Plugin(context)
+Kwave::NormalizePlugin::NormalizePlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager)
 {
 }
 
 //***************************************************************************
-NormalizePlugin::~NormalizePlugin()
+Kwave::NormalizePlugin::~NormalizePlugin()
 {
 }
 
 //***************************************************************************
-void NormalizePlugin::run(QStringList params)
+void Kwave::NormalizePlugin::run(QStringList params)
 {
     Q_UNUSED(params);
-    UndoTransactionGuard undo_guard(*this, i18n("Normalize"));
+    Kwave::UndoTransactionGuard undo_guard(*this, i18n("Normalize"));
 
     // get the current selection
     QList<unsigned int> tracks;
@@ -182,7 +186,7 @@ void NormalizePlugin::run(QStringList params)
     if (!length || tracks.isEmpty()) return;
 
     // get the list of affected tracks
-    MultiTrackReader source(Kwave::SinglePassForward,
+    Kwave::MultiTrackReader source(Kwave::SinglePassForward,
 	signalManager(), tracks, first, last);
 
     // connect the progress dialog
@@ -196,7 +200,7 @@ void NormalizePlugin::run(QStringList params)
     double level = getMaxPower(source);
 //     qDebug("NormalizePlugin: level is %g", level);
 
-    Kwave::MultiTrackWriter sink(signalManager(), tracks, Overwrite,
+    Kwave::MultiTrackWriter sink(signalManager(), tracks, Kwave::Overwrite,
 	first, last);
     Kwave::MultiTrackSource<Kwave::Normalizer, true> normalizer(
 	tracks.count(), this);
@@ -234,16 +238,16 @@ void NormalizePlugin::run(QStringList params)
 }
 
 //***************************************************************************
-double NormalizePlugin::getMaxPower(MultiTrackReader &source)
+double Kwave::NormalizePlugin::getMaxPower(Kwave::MultiTrackReader &source)
 {
     double maxpow = 0.0;
     const unsigned int tracks = source.tracks();
-    const double rate = FileInfo(signalManager().metaData()).rate();
+    const double rate = Kwave::FileInfo(signalManager().metaData()).rate();
     const unsigned int window_size = static_cast<unsigned int>(rate / 100);
     if (!window_size) return 0;
 
     // set up smoothing window buffer
-    QVector<GetMaxPowerJob::average_t> average(tracks);
+    QVector<Kwave::GetMaxPowerJob::average_t> average(tracks);
     for (unsigned int t = 0; t < tracks; t++) {
 	average[t].fifo.resize(SMOOTHLEN);
 	average[t].fifo.fill(0.0);
@@ -260,11 +264,11 @@ double NormalizePlugin::getMaxPower(MultiTrackReader &source)
 
 	weaver.suspend();
 	for (unsigned int t = 0; t < tracks; t++) {
-	    SampleReader *reader = source[t];
+	    Kwave::SampleReader *reader = source[t];
 	    if (!reader) continue;
 	    if (reader->eof()) continue;
 
-	    GetMaxPowerJob *job = new GetMaxPowerJob(
+	    Kwave::GetMaxPowerJob *job = new Kwave::GetMaxPowerJob(
 		*reader, average[t], window_size
 	    );
 	    if (!job) continue;
