@@ -28,17 +28,19 @@
 #include <math.h>
 #include <errno.h>
 
-#include <QDir>
-#include <QFile>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QLatin1Char>
 
 #include <klocale.h>
 
 #include "libkwave/memcpy.h"
 #include "libkwave/ByteOrder.h"
-#include "libkwave/CompressionType.h"
+#include "libkwave/Compression.h"
+#include "libkwave/SampleEncoderLinear.h"
+#include "libkwave/String.h"
 
 #include "PlayBack-OSS.h"
-#include "SampleEncoderLinear.h"
 
 /** use at least 2^8 = 256 bytes for playback buffer !!! */
 #define MIN_PLAYBACK_BUFFER 8
@@ -81,8 +83,8 @@
 #endif
 
 //***************************************************************************
-PlayBackOSS::PlayBackOSS()
-    :PlayBackDevice(),
+Kwave::PlayBackOSS::PlayBackOSS()
+    :Kwave::PlayBackDevice(),
     m_device_name(),
     m_handle(-1),
     m_rate(0),
@@ -99,19 +101,19 @@ PlayBackOSS::PlayBackOSS()
 }
 
 //***************************************************************************
-PlayBackOSS::~PlayBackOSS()
+Kwave::PlayBackOSS::~PlayBackOSS()
 {
     close();
 }
 
 //***************************************************************************
-QString PlayBackOSS::open(const QString &device, double rate,
+QString Kwave::PlayBackOSS::open(const QString &device, double rate,
                           unsigned int channels, unsigned int bits,
                           unsigned int bufbase)
 {
-    qDebug("PlayBackOSS::open(device=%s,rate=%0.1f,channels=%u,"\
-	"bits=%u, bufbase=%u)", device.toLocal8Bit().data(), rate, channels,
-	bits, bufbase);
+    qDebug("PlayBackOSS::open(device=%s,rate=%0.1f,channels=%u,"
+	   "bits=%u, bufbase=%u)", DBG(device.split(_("|")).at(0)),
+	   rate, channels, bits, bufbase);
 
     m_device_name = device;
     m_rate        = rate;
@@ -143,10 +145,10 @@ QString PlayBackOSS::open(const QString &device, double rate,
 		"(Hint: you might find out the name and process ID of\n"\
 		"the program by calling: \"fuser -v %1\"\n"\
 		"on the command line.)",
-		m_device_name.section('|',0,0));
+		m_device_name.section(QLatin1Char('|'), 0, 0));
 		break;
 	    default:
-		reason = strerror(errno);
+		reason = _(strerror(errno));
 	}
 	return reason;
     }
@@ -158,7 +160,7 @@ QString PlayBackOSS::open(const QString &device, double rate,
 	// resetting O:NONBLOCK failed
 	return i18n("The device '%1' cannot be opened "\
 	            "in the correct mode.",
-	            m_device_name.section('|',0,0));
+	            m_device_name.section(QLatin1Char('|'), 0, 0));
     }
 
     // query OSS driver version
@@ -167,11 +169,6 @@ QString PlayBackOSS::open(const QString &device, double rate,
     ioctl(m_handle, OSS_GETVERSION, &m_oss_version);
 #endif
 
-    // query OSS driver version for debugging purposes
-    m_oss_version = -1;
-#ifdef OSS_GETVERSION
-    ioctl(m_handle, OSS_GETVERSION, &m_oss_version);
-#endif
     int format;
     switch (m_bits) {
 	case  8: format = AFMT_U8;     break;
@@ -219,24 +216,27 @@ QString PlayBackOSS::open(const QString &device, double rate,
 
     switch (m_bits) {
 	case 8:
-	    m_encoder = new SampleEncoderLinear(
-		SampleFormat::Unsigned, 8, LittleEndian);
+	    m_encoder = new Kwave::SampleEncoderLinear(
+		Kwave::SampleFormat::Unsigned, 8, Kwave::LittleEndian);
 	    break;
 	case 24:
 	    if (m_oss_version >= 0x040000) {
-		m_encoder = new SampleEncoderLinear(
-		SampleFormat::Signed, 24, LittleEndian);
+		m_encoder = new Kwave::SampleEncoderLinear(
+		Kwave::SampleFormat::Signed, 24, Kwave::LittleEndian);
 		break;
-	    }
+	    } // else:
+	    /* FALLTHROUGH */
 	case 32:
 	    if (m_oss_version >= 0x040000) {
-		m_encoder = new SampleEncoderLinear(
-		    SampleFormat::Signed, 32, LittleEndian);
+		m_encoder = new Kwave::SampleEncoderLinear(
+		    Kwave::SampleFormat::Signed, 32, Kwave::LittleEndian);
 		break;
 	    }
+	    // else:
+	    /* FALLTHROUGH */
 	default:
-	    m_encoder = new SampleEncoderLinear(
-		SampleFormat::Signed, 16, LittleEndian);
+	    m_encoder = new Kwave::SampleEncoderLinear(
+		Kwave::SampleFormat::Signed, 16, Kwave::LittleEndian);
 	    break;
     }
 
@@ -250,11 +250,11 @@ QString PlayBackOSS::open(const QString &device, double rate,
     m_buffer_size /= m_encoder->rawBytesPerSample();
     m_buffer.resize(m_buffer_size);
 
-    return 0;
+    return QString();
 }
 
 //***************************************************************************
-int PlayBackOSS::write(const Kwave::SampleArray &samples)
+int Kwave::PlayBackOSS::write(const Kwave::SampleArray &samples)
 {
     Q_ASSERT (m_buffer_used <= m_buffer_size);
     if (m_buffer_used > m_buffer_size) {
@@ -288,7 +288,7 @@ int PlayBackOSS::write(const Kwave::SampleArray &samples)
 }
 
 //***************************************************************************
-void PlayBackOSS::flush()
+void Kwave::PlayBackOSS::flush()
 {
     if (!m_buffer_used || !m_encoder) return; // nothing to do
 
@@ -305,7 +305,7 @@ void PlayBackOSS::flush()
 }
 
 //***************************************************************************
-int PlayBackOSS::close()
+int Kwave::PlayBackOSS::close()
 {
     flush();
 
@@ -324,9 +324,9 @@ static bool addIfExists(QStringList &list, const QString &name)
 {
     QFile file;
 
-    if (name.contains("%1")) {
+    if (name.contains(_("%1"))) {
 	// test for the name without suffix first
-	addIfExists(list, name.arg(""));
+	addIfExists(list, name.arg(_("")));
 
 	// loop over the list and try until a suffix does not exist
 	for (unsigned int index=0; index < 64; index++)
@@ -352,7 +352,7 @@ static void scanFiles(QStringList &list, const QString &dirname,
     QDir dir;
 
     dir.setPath(dirname);
-    dir.setNameFilters(mask.split(' '));
+    dir.setNameFilters(mask.split(QLatin1Char(' ')));
     dir.setFilter(QDir::Files | QDir::Writable | QDir::System);
     dir.setSorting(QDir::Name);
     files = dir.entryList();
@@ -366,97 +366,99 @@ static void scanFiles(QStringList &list, const QString &dirname,
 //***************************************************************************
 static void scanDirectory(QStringList &list, const QString &dir)
 {
-    scanFiles(list, dir, "dsp*");
-    scanFiles(list, dir, "*audio*");
-    scanFiles(list, dir, "adsp*");
-    scanFiles(list, dir, "dio*");
-    scanFiles(list, dir, "pcm*");
+    scanFiles(list, dir, _("dsp*"));
+    scanFiles(list, dir, _("*audio*"));
+    scanFiles(list, dir, _("adsp*"));
+    scanFiles(list, dir, _("dio*"));
+    scanFiles(list, dir, _("pcm*"));
 }
 
 //***************************************************************************
-QStringList PlayBackOSS::supportedDevices()
+QStringList Kwave::PlayBackOSS::supportedDevices()
 {
     QStringList list, dirlist;
 
-    scanDirectory(list, "/dev");
-    scanDirectory(list, "/dev/snd");
-    scanDirectory(list, "/dev/sound");
-    scanFiles(dirlist, "/dev/oss", "[^.]*");
+    scanDirectory(list, _("/dev"));
+    scanDirectory(list, _("/dev/snd"));
+    scanDirectory(list, _("/dev/sound"));
+    scanFiles(dirlist, _("/dev/oss"), _("[^.]*"));
     foreach (QString dir, dirlist)
 	scanDirectory(list, dir);
-    list.append("#EDIT#");
-    list.append("#SELECT#");
+    list.append(_("#EDIT#"));
+    list.append(_("#SELECT#"));
 
     return list;
 }
 
 //***************************************************************************
-QString PlayBackOSS::fileFilter()
+QString Kwave::PlayBackOSS::fileFilter()
 {
     QString filter;
 
-    if (filter.length()) filter += "\n";
-    filter += QString("dsp*|") + i18n("OSS playback device (dsp*)");
+    if (filter.length()) filter += _("\n");
+    filter += _("dsp*|") + i18n("OSS playback device (dsp*)");
 
-    if (filter.length()) filter += "\n";
-    filter += QString("adsp*|") + i18n("ALSA playback device (adsp*)");
+    if (filter.length()) filter += _("\n");
+    filter += _("adsp*|") + i18n("ALSA playback device (adsp*)");
 
-    if (filter.length()) filter += "\n";
-    filter += QString("*|") + i18n("Any device (*)");
+    if (filter.length()) filter += _("\n");
+    filter += _("*|") + i18n("Any device (*)");
 
     return filter;
 }
 
 //***************************************************************************
-void PlayBackOSS::format2mode(int format, int &compression,
-                              int &bits, SampleFormat &sample_format)
+void Kwave::PlayBackOSS::format2mode(int format, int &compression,
+                                     int &bits,
+                                     Kwave::SampleFormat &sample_format) const
 {
     switch (format) {
 	case AFMT_MU_LAW:
-	    compression   = AF_COMPRESSION_G711_ULAW;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::G711_ULAW;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 	case AFMT_A_LAW:
-	    compression   = AF_COMPRESSION_G711_ALAW;
-	    sample_format = SampleFormat::Unsigned;
+	    compression   = Kwave::Compression::G711_ALAW;
+	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 16;
 	    break;
 	case AFMT_IMA_ADPCM:
-	    compression   = AF_COMPRESSION_MS_ADPCM;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::MS_ADPCM;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 	case AFMT_U8:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Unsigned;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 8;
 	    break;
 	case AFMT_S16_LE:
 	case AFMT_S16_BE:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 	case AFMT_S8:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 8;
 	    break;
 	case AFMT_U16_LE:
 	case AFMT_U16_BE:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Unsigned;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 16;
 	    break;
 	case AFMT_MPEG:
-	    compression   = static_cast<int>(CompressionType::MPEG_LAYER_II);
-	    sample_format = SampleFormat::Signed;
+	    compression   = static_cast<int>(
+	                    Kwave::Compression::MPEG_LAYER_II);
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 #if 0
 	case AFMT_AC3: /* Dolby Digital AC3 */
-	    compression   = SampleFormat::Unknown;
+	    compression   = Kwave::SampleFormat::Unknown;
 	    sample_format = 0;
 	    bits          = 16;
 	    break;
@@ -464,29 +466,29 @@ void PlayBackOSS::format2mode(int format, int &compression,
 	case AFMT_S24_LE:
 	case AFMT_S24_BE:
 	    if (m_oss_version >= 0x040000) {
-		compression   = AF_COMPRESSION_NONE;
-		sample_format = SampleFormat::Signed;
+		compression   = Kwave::Compression::NONE;
+		sample_format = Kwave::SampleFormat::Signed;
 		bits          = 24;
 		break;
 	    }
 	case AFMT_S32_LE:
 	case AFMT_S32_BE:
 	    if (m_oss_version >= 0x040000) {
-		compression   = AF_COMPRESSION_NONE;
-		sample_format = SampleFormat::Signed;
+		compression   = Kwave::Compression::NONE;
+		sample_format = Kwave::SampleFormat::Signed;
 		bits          = 32;
 		break;
 	    }
 	default:
 	    compression   = -1;
-	    sample_format = SampleFormat::Unknown;
+	    sample_format = Kwave::SampleFormat::Unknown;
 	    bits          = -1;
     }
 
 }
 
 //***************************************************************************
-int PlayBackOSS::openDevice(const QString &device)
+int Kwave::PlayBackOSS::openDevice(const QString &device)
 {
     int fd = m_handle;
 
@@ -497,9 +499,8 @@ int PlayBackOSS::openDevice(const QString &device)
 	// open the device in case it's not already open
 	fd = ::open(device.toLocal8Bit(), O_WRONLY | O_NONBLOCK);
 	if (fd <= 0) {
-	    qWarning("PlayBackOSS::openDevice('%s') - "\
-		 "failed, errno=%d (%s)",
-		 device.toLocal8Bit().data(),
+	    qWarning("PlayBackOSS::openDevice('%s') - failed, errno=%d (%s)",
+		 DBG(device),
 		 errno, strerror(errno));
 	} else {
 	    // we use blocking mode
@@ -512,17 +513,15 @@ int PlayBackOSS::openDevice(const QString &device)
 	}
     }
     if (fd <= 0) {
-	qWarning("PlayBackOSS::openDevice('%s') - "\
-	         "failed, errno=%d (%s)",
-	         device.toLocal8Bit().data(),
-	         errno, strerror(errno));
+	qWarning("PlayBackOSS::openDevice('%s') - failed, errno=%d (%s)",
+	         DBG(device), errno, strerror(errno));
     }
 
     return fd;
 }
 
 //***************************************************************************
-QList<unsigned int> PlayBackOSS::supportedBits(const QString &device)
+QList<unsigned int> Kwave::PlayBackOSS::supportedBits(const QString &device)
 {
     QList<unsigned int> bits;
     bits.clear();
@@ -549,13 +548,13 @@ QList<unsigned int> PlayBackOSS::supportedBits(const QString &device)
     if (err < 0) return bits;
 
     // mask out all modes that do not match the current compression
-    const int compression = AF_COMPRESSION_NONE;
+    const int compression = Kwave::Compression::NONE;
     for (unsigned int bit=0; bit < (sizeof(mask) << 3); bit++) {
-	if (!mask & (1 << bit)) continue;
+	if (!(mask & (1 << bit))) continue;
 
 	// format is supported, split into compression, bits, sample format
 	int c, b;
-	SampleFormat s;
+	Kwave::SampleFormat s;
 	format2mode(1 << bit, c, b, s);
 	if (b < 0) continue; // unknown -> skip
 
@@ -569,8 +568,8 @@ QList<unsigned int> PlayBackOSS::supportedBits(const QString &device)
 }
 
 //***************************************************************************
-int PlayBackOSS::detectChannels(const QString &device,
-                                unsigned int &min, unsigned int &max)
+int Kwave::PlayBackOSS::detectChannels(const QString &device,
+                                       unsigned int &min, unsigned int &max)
 {
     int fd, t, err;
 
