@@ -21,13 +21,14 @@
 #include <errno.h>
 
 #include "libkwave/memcpy.h"
+#include "libkwave/SampleEncoderLinear.h"
+#include "libkwave/String.h"
 
 #include "PlayBack-Phonon.h"
-#include "SampleEncoderLinear.h"
 
 //***************************************************************************
-PlayBackPhonon::PlayBackPhonon()
-    :PlayBackDevice(), m_buffer(), m_raw_buffer(), m_buffer_size(0),
+Kwave::PlayBackPhonon::PlayBackPhonon()
+    :Kwave::PlayBackDevice(), m_buffer(), m_raw_buffer(), m_buffer_size(0),
      m_buffer_used(0), m_encoder(0),
      m_sem(0), m_output(0), m_path(), m_media_object(),
      m_media_source(this), m_first_write(true)
@@ -35,12 +36,12 @@ PlayBackPhonon::PlayBackPhonon()
 }
 
 //***************************************************************************
-PlayBackPhonon::~PlayBackPhonon()
+Kwave::PlayBackPhonon::~PlayBackPhonon()
 {
 }
 
 //***************************************************************************
-void PlayBackPhonon::createEncoder(unsigned int bits)
+void Kwave::PlayBackPhonon::createEncoder(unsigned int bits)
 {
     // create the sample encoder
     // we assume that OSS is always little endian
@@ -48,28 +49,28 @@ void PlayBackPhonon::createEncoder(unsigned int bits)
 
     switch (bits) {
 	case 8:
-	    m_encoder = new SampleEncoderLinear(
-		SampleFormat::Unsigned, 8, LittleEndian);
+	    m_encoder = new Kwave::SampleEncoderLinear(
+		Kwave::SampleFormat::Unsigned, 8, Kwave::LittleEndian);
 	    break;
 	case 24:
-	    m_encoder = new SampleEncoderLinear(
-	    SampleFormat::Signed, 24, LittleEndian);
+	    m_encoder = new Kwave::SampleEncoderLinear(
+	    Kwave::SampleFormat::Signed, 24, Kwave::LittleEndian);
 	    break;
 	case 32:
-	    m_encoder = new SampleEncoderLinear(
-		SampleFormat::Signed, 32, LittleEndian);
+	    m_encoder = new Kwave::SampleEncoderLinear(
+		Kwave::SampleFormat::Signed, 32, Kwave::LittleEndian);
 	    break;
 	default:
-	    m_encoder = new SampleEncoderLinear(
-		SampleFormat::Signed, 16, LittleEndian);
+	    m_encoder = new Kwave::SampleEncoderLinear(
+		Kwave::SampleFormat::Signed, 16, Kwave::LittleEndian);
 	    break;
     }
 }
 
 //***************************************************************************
-void PlayBackPhonon::createHeader(double rate,
-                                  unsigned int channels,
-                                  unsigned int bits)
+void Kwave::PlayBackPhonon::createHeader(double rate,
+                                         unsigned int channels,
+                                         unsigned int bits)
 {
     m_header.resize(44);
 
@@ -134,9 +135,9 @@ void PlayBackPhonon::createHeader(double rate,
 }
 
 //***************************************************************************
-QString PlayBackPhonon::open(const QString &device, double rate,
-                             unsigned int channels, unsigned int bits,
-                             unsigned int bufbase)
+QString Kwave::PlayBackPhonon::open(const QString &device, double rate,
+                                    unsigned int channels, unsigned int bits,
+                                    unsigned int bufbase)
 {
     // close the previous device
     if (m_output) delete m_output;
@@ -159,8 +160,7 @@ QString PlayBackPhonon::open(const QString &device, double rate,
 	}
     }
     if (!dev.isValid()) {
-	return i18n("Opening the device '%1' failed.",
-	    device.toLocal8Bit().data());
+	return i18n("Opening the device '%1' failed.", device);
     }
 
     // set the output device name
@@ -197,11 +197,11 @@ QString PlayBackPhonon::open(const QString &device, double rate,
     m_media_object.play();
     setStreamSize(44);
 
-    return 0;
+    return QString();
 }
 
 //***************************************************************************
-int PlayBackPhonon::write(const Kwave::SampleArray &samples)
+int Kwave::PlayBackPhonon::write(const Kwave::SampleArray &samples)
 {
     Q_ASSERT (m_buffer_used <= m_buffer_size);
     if (m_buffer_used > m_buffer_size) {
@@ -237,7 +237,7 @@ int PlayBackPhonon::write(const Kwave::SampleArray &samples)
 }
 
 //***************************************************************************
-int PlayBackPhonon::flush()
+int Kwave::PlayBackPhonon::flush()
 {
     if (!m_buffer_used || !m_encoder) return 0; // nothing to do
 
@@ -258,7 +258,7 @@ int PlayBackPhonon::flush()
 }
 
 //***************************************************************************
-int PlayBackPhonon::close()
+int Kwave::PlayBackPhonon::close()
 {
     m_media_object.stop();
     m_media_object.clearQueue();
@@ -273,51 +273,67 @@ int PlayBackPhonon::close()
 }
 
 //***************************************************************************
-QStringList PlayBackPhonon::supportedDevices()
+QStringList Kwave::PlayBackPhonon::supportedDevices()
 {
     QStringList list;
+    bool retry;
+    unsigned int retry_count = 3; // we try three times
 
-    // get the list of available audio output devices from Phonon
-    QList<Phonon::AudioOutputDevice> devices =
-	Phonon::BackendCapabilities::availableAudioOutputDevices();
+    do {
+	retry = false;
+	list.clear();
 
-    // get and use the device name(s) from the object description(s)
-    foreach(Phonon::AudioOutputDevice device, devices) {
-// 	qDebug("name='%s'", device.name().toLocal8Bit().data());
-	list << device.name();
+	// get the list of available audio output devices from Phonon
+	QList<Phonon::AudioOutputDevice> devices =
+	    Phonon::BackendCapabilities::availableAudioOutputDevices();
 
-	// for debugging: list all properties
-// 	foreach (const char *property, device.propertyNames()) {
-// 	    qDebug("    '%s' = '%s'", property,
-// 		device.property(property).toString().toLocal8Bit().data());
-// 	}
-    }
+	// get and use the device name(s) from the object description(s)
+	foreach(const Phonon::AudioOutputDevice &device, devices) {
+	    QString name = device.name();
+
+// 	    // for debugging: list all properties
+// 	    qDebug("name='%s'", DBG(name));
+// 	    foreach (const char *property, device.propertyNames()) {
+// 		qDebug("    '%s' = '%s'", property,
+// 		    DBG(device.property(property).toString()));
+// 	    }
+
+	    // device names not yet available ?
+	    if (!name.length()) {
+		qWarning("PlayBackPhonon::supportedDevices() "
+		         "=> BUG in Phonon: no device name?");
+		retry = true;
+		break;
+	    }
+	    list << name;
+
+	}
+    } while (retry && retry_count--);
 
     return list;
 }
 
 //***************************************************************************
-QString PlayBackPhonon::fileFilter()
+QString Kwave::PlayBackPhonon::fileFilter()
 {
-    return "";
+    return _("");
 }
 
 //***************************************************************************
-QList<unsigned int> PlayBackPhonon::supportedBits(const QString &device)
+QList<unsigned int> Kwave::PlayBackPhonon::supportedBits(const QString &device)
 {
-    qDebug("%s", __FUNCTION__);
     Q_UNUSED(device);
 
     QList<unsigned int> list;
-    list << 8;
+    list <<  8;
     list << 16;
 
     return list;
 }
 
 //***************************************************************************
-int PlayBackPhonon::detectChannels(const QString &device,
-                                   unsigned int &min, unsigned int &max)
+int Kwave::PlayBackPhonon::detectChannels(const QString &device,
+                                          unsigned int &min, unsigned int &max)
 {
     Q_UNUSED(device);
 
@@ -328,12 +344,12 @@ int PlayBackPhonon::detectChannels(const QString &device,
 }
 
 //***************************************************************************
-void PlayBackPhonon::reset()
+void Kwave::PlayBackPhonon::reset()
 {
 }
 
 //***************************************************************************
-void PlayBackPhonon::needData()
+void Kwave::PlayBackPhonon::needData()
 {
     if (m_first_write) {
 	m_first_write = false;
