@@ -25,27 +25,59 @@
 #include <errno.h>
 #include <signal.h>
 
-#include <QApplication>
-#include <QCursor>
-#include <QFileInfo>
-#include <QLocale>
-#include <QString>
-#include <QtGlobal>
+#include <QtGui/QApplication>
+#include <QtGui/QCursor>
+#include <QtCore/QFileInfo>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QLocale>
+#include <QtCore/QString>
+#include <QtCore/QtGlobal>
 
 #include <klocale.h>
 #include <kuser.h>
 
-#include "libkwave/CompressionType.h"
 #include "libkwave/FileInfo.h"
 #include "libkwave/memcpy.h"
-#include "libkwave/SampleFormat.h"
+#include "libkwave/SampleEncoderLinear.h"
+#include "libkwave/String.h"
 
 #include "PlayBack-PulseAudio.h"
-#include "SampleEncoderLinear.h"
+
+/**
+ * timeout for the device scan [ms]
+ * @see scanDevices()
+ */
+#define TIMEOUT_WAIT_DEVICE_SCAN 10000
+
+/**
+ * timeout to wait for the connection to the server [ms]
+ * @see connectToServer()
+ */
+#define TIMEOUT_CONNECT_TO_SERVER 20000
+
+/**
+ * timeout to wait for playback [ms]
+ * @see open()
+ */
+#define TIMEOUT_CONNECT_PLAYBACK 10000
+
+/**
+ * minimum timeout for flush() [ms]
+ * @see flush()
+ */
+#define TIMEOUT_MIN_FLUSH 1000
+
+/**
+ * minimum timeout for drain() [ms]
+ * @see close()
+ */
+#define TIMEOUT_MIN_DRAIN 3000
 
 //***************************************************************************
-PlayBackPulseAudio::PlayBackPulseAudio(const FileInfo &info)
-    :PlayBackDevice(), m_info(info), m_rate(0), m_channels(0),
+Kwave::PlayBackPulseAudio::PlayBackPulseAudio(const Kwave::FileInfo &info)
+    :Kwave::PlayBackDevice(), m_mainloop_thread(this, QVariant()),
+     m_mainloop_lock(), m_mainloop_signal(),
+     m_info(info), m_rate(0), m_channels(0),
      m_bytes_per_sample(0), m_buffer(0), m_buffer_size(0), m_buffer_used(0),
      m_bufbase(10), m_pa_proplist(0), m_pa_mainloop(0), m_pa_context(0),
      m_pa_stream(0), m_device_list()
@@ -53,71 +85,63 @@ PlayBackPulseAudio::PlayBackPulseAudio(const FileInfo &info)
 }
 
 //***************************************************************************
-PlayBackPulseAudio::~PlayBackPulseAudio()
+Kwave::PlayBackPulseAudio::~PlayBackPulseAudio()
 {
     close();
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::pa_context_notify_cb(pa_context *c, void *data)
+void Kwave::PlayBackPulseAudio::pa_context_notify_cb(pa_context *c, void *data)
 {
-    PlayBackPulseAudio *playback_plugin =
-	reinterpret_cast<PlayBackPulseAudio *>(data);
+    Kwave::PlayBackPulseAudio *playback_plugin =
+	reinterpret_cast<Kwave::PlayBackPulseAudio *>(data);
     Q_ASSERT(playback_plugin);
     if (playback_plugin) playback_plugin->notifyContext(c);
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::pa_sink_info_cb(pa_context *c,
-                                         const pa_sink_info *info,
-                                         int eol, void *userdata)
+void Kwave::PlayBackPulseAudio::pa_sink_info_cb(pa_context *c,
+                                                const pa_sink_info *info,
+                                                int eol, void *userdata)
 {
-    PlayBackPulseAudio *playback_plugin =
-	reinterpret_cast<PlayBackPulseAudio *>(userdata);
+    Kwave::PlayBackPulseAudio *playback_plugin =
+	reinterpret_cast<Kwave::PlayBackPulseAudio *>(userdata);
     Q_ASSERT(playback_plugin);
     if (playback_plugin) playback_plugin->notifySinkInfo(c, info, eol);
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::pa_stream_state_cb(pa_stream *p, void *userdata)
+void Kwave::PlayBackPulseAudio::pa_stream_state_cb(pa_stream *p, void *userdata)
 {
-    PlayBackPulseAudio *playback_plugin =
-	reinterpret_cast<PlayBackPulseAudio *>(userdata);
+    Kwave::PlayBackPulseAudio *playback_plugin =
+	reinterpret_cast<Kwave::PlayBackPulseAudio *>(userdata);
     Q_ASSERT(playback_plugin);
     if (playback_plugin) playback_plugin->notifyStreamState(p);
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::pa_write_cb(pa_stream *p, size_t nbytes,
-                                     void *userdata)
+void Kwave::PlayBackPulseAudio::pa_write_cb(pa_stream *p, size_t nbytes,
+                                            void *userdata)
 {
-    PlayBackPulseAudio *playback_plugin =
-	reinterpret_cast<PlayBackPulseAudio *>(userdata);
+    Kwave::PlayBackPulseAudio *playback_plugin =
+	reinterpret_cast<Kwave::PlayBackPulseAudio *>(userdata);
     Q_ASSERT(playback_plugin);
     if (playback_plugin) playback_plugin->notifyWrite(p, nbytes);
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::pa_stream_success_cb(pa_stream *s, int success,
-                                              void *userdata)
+void Kwave::PlayBackPulseAudio::pa_stream_success_cb(pa_stream *s,
+                                                     int success,
+                                                     void *userdata)
 {
-    PlayBackPulseAudio *playback_plugin =
-	reinterpret_cast<PlayBackPulseAudio *>(userdata);
+    Kwave::PlayBackPulseAudio *playback_plugin =
+	reinterpret_cast<Kwave::PlayBackPulseAudio *>(userdata);
     Q_ASSERT(playback_plugin);
     if (playback_plugin) playback_plugin->notifySuccess(s, success);
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::pa_stream_latency_cb(pa_stream *p, void *userdata)
-{
-    PlayBackPulseAudio *playback_plugin =
-	reinterpret_cast<PlayBackPulseAudio *>(userdata);
-    Q_ASSERT(playback_plugin);
-    if (playback_plugin) playback_plugin->notifyLatency(p);
-}
-
-//***************************************************************************
-void PlayBackPulseAudio::notifyContext(pa_context *c)
+void Kwave::PlayBackPulseAudio::notifyContext(pa_context *c)
 {
     Q_ASSERT(c == m_pa_context);
     switch (pa_context_get_state(c))
@@ -136,22 +160,23 @@ void PlayBackPulseAudio::notifyContext(pa_context *c)
 	    break;
 	case PA_CONTEXT_READY:
 // 	    qDebug("PlayBackPulseAudio: PA_CONTEXT_READY.");
-	    pa_threaded_mainloop_signal(m_pa_mainloop, 0);
+	    m_mainloop_signal.wakeAll();
 	    break;
 	case PA_CONTEXT_TERMINATED:
 	    qWarning("PlayBackPulseAudio: PA_CONTEXT_TERMINATED");
-	    pa_threaded_mainloop_signal(m_pa_mainloop, 0);
+	    m_mainloop_signal.wakeAll();
 	    break;
 	case PA_CONTEXT_FAILED:
 	    qWarning("PlayBackPulseAudio: PA_CONTEXT_FAILED");
-	    pa_threaded_mainloop_signal(m_pa_mainloop, 0);
+	    m_mainloop_signal.wakeAll();
 	    break;
     }
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::notifySinkInfo(pa_context *c,
-                                        const pa_sink_info *info, int eol)
+void Kwave::PlayBackPulseAudio::notifySinkInfo(pa_context *c,
+                                               const pa_sink_info *info,
+                                               int eol)
 {
     Q_UNUSED(c);
     Q_ASSERT(c == m_pa_context);
@@ -187,67 +212,98 @@ void PlayBackPulseAudio::notifySinkInfo(pa_context *c,
 	m_device_list[name] = i;
 
     } else {
-	pa_threaded_mainloop_signal(m_pa_mainloop, 0);
+	m_mainloop_signal.wakeAll();
     }
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::notifyStreamState(pa_stream* stream)
+void Kwave::PlayBackPulseAudio::notifyStreamState(pa_stream* stream)
 {
     Q_ASSERT(stream);
     if (!stream || (stream != m_pa_stream)) return;
 
-    switch (pa_stream_get_state(stream)) {
+    pa_stream_state_t state = pa_stream_get_state(stream);
+//     switch (state) {
+// 	case PA_STREAM_UNCONNECTED:
+// 	    qDebug("    -> UNCONNECTED"); break;
+// 	case PA_STREAM_CREATING:
+// 	    qDebug("    -> CREATING"); break;
+// 	case PA_STREAM_READY:
+// 	    qDebug("    -> READY"); break;
+// 	case PA_STREAM_FAILED:
+// 	    qDebug("    -> FAILED"); break;
+// 	case PA_STREAM_TERMINATED:
+// 	    qDebug("    -> TERMINATED"); break;
+// 	default:
+// 	    Q_ASSERT(0 && "?");
+// 	    qDebug("    -> ???"); break;
+//     }
+    switch (state) {
 	case PA_STREAM_UNCONNECTED:
 	case PA_STREAM_CREATING:
 	    break;
 	case PA_STREAM_READY:
 	case PA_STREAM_FAILED:
 	case PA_STREAM_TERMINATED:
-	    pa_threaded_mainloop_signal(m_pa_mainloop, 0);
+	    m_mainloop_signal.wakeAll();
 	    break;
     }
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::notifyWrite(pa_stream *stream, size_t nbytes)
+void Kwave::PlayBackPulseAudio::notifyWrite(pa_stream *stream, size_t nbytes)
 {
-    Q_UNUSED(nbytes);
-    Q_ASSERT(stream);
-    Q_ASSERT(stream = m_pa_stream);
-    if (!stream || (stream != m_pa_stream)) return;
-
 //     qDebug("PlayBackPulseAudio::notifyWrite(stream=%p, nbytes=%u)",
 // 	   static_cast<void *>(stream), nbytes);
-    pa_threaded_mainloop_signal(m_pa_mainloop, 0);
-}
+    Q_UNUSED(nbytes);
 
-//***************************************************************************
-void PlayBackPulseAudio::notifyLatency(pa_stream *stream)
-{
     Q_ASSERT(stream);
-    Q_ASSERT(stream = m_pa_stream);
+    Q_ASSERT(stream == m_pa_stream);
     if (!stream || (stream != m_pa_stream)) return;
 
-//     qDebug("PlayBackPulseAudio::notifyLatency(stream=%p)",
-// 	   static_cast<void *>(stream));
-//     pa_threaded_mainloop_signal(m_pa_mainloop, 0);
+    m_mainloop_signal.wakeAll();
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::notifySuccess(pa_stream* stream, int success)
+void Kwave::PlayBackPulseAudio::notifySuccess(pa_stream* stream, int success)
 {
+//     qDebug("PlayBackPulseAudio::notifySuccess(stream=%p, success=%d)",
+// 	   static_cast<void *>(stream), success);
+    Q_UNUSED(success);
+
     Q_ASSERT(stream);
-    Q_ASSERT(stream = m_pa_stream);
+    Q_ASSERT(stream == m_pa_stream);
     if (!stream || (stream != m_pa_stream)) return;
 
-    qDebug("PlayBackPulseAudio::notifySuccess(stream=%p, success=%d)",
-	   static_cast<void *>(stream), success);
-    pa_threaded_mainloop_signal(m_pa_mainloop, 0);
+    m_mainloop_signal.wakeAll();
 }
 
 //***************************************************************************
-bool PlayBackPulseAudio::connectToServer()
+static int poll_func(struct pollfd *ufds, unsigned long nfds,
+                     int timeout, void *userdata)
+{
+    Kwave::PlayBackPulseAudio *dev =
+	static_cast<Kwave::PlayBackPulseAudio *>(userdata);
+    Q_ASSERT(dev);
+    if (!dev) return -1;
+
+    return dev->mainloopPoll(ufds, nfds, timeout);
+}
+
+//***************************************************************************
+int Kwave::PlayBackPulseAudio::mainloopPoll(struct pollfd *ufds,
+                                            unsigned long int nfds,
+                                            int timeout)
+{
+    m_mainloop_lock.unlock();
+    int retval = poll(ufds, nfds, timeout);
+    m_mainloop_lock.lock();
+
+    return retval;
+}
+
+//***************************************************************************
+bool Kwave::PlayBackPulseAudio::connectToServer()
 {
     if (m_pa_context) return true; // already connected
 
@@ -259,9 +315,9 @@ bool PlayBackPulseAudio::connectToServer()
     Q_ASSERT(m_pa_proplist);
 
     pa_proplist_sets(m_pa_proplist, PA_PROP_APPLICATION_LANGUAGE,
-                     QLocale::system().name ().toUtf8().data());
+                     __(QLocale::system().name()));
     pa_proplist_sets(m_pa_proplist, PA_PROP_APPLICATION_NAME,
-                     qApp->applicationName().toUtf8().data());
+                     __(qApp->applicationName()));
     pa_proplist_sets(m_pa_proplist, PA_PROP_APPLICATION_ICON_NAME,
                      "kwave");
     pa_proplist_sets(m_pa_proplist, PA_PROP_APPLICATION_PROCESS_BINARY,
@@ -270,9 +326,9 @@ bool PlayBackPulseAudio::connectToServer()
                     "%ld", static_cast<long int>(qApp->applicationPid()));
     KUser user;
     pa_proplist_sets(m_pa_proplist, PA_PROP_APPLICATION_PROCESS_USER,
-                     user.loginName().toUtf8().data());
+                     __(user.loginName()));
     pa_proplist_sets(m_pa_proplist, PA_PROP_APPLICATION_VERSION,
-                     qApp->applicationVersion().toUtf8().data());
+                     __(qApp->applicationVersion()));
 
     pa_proplist_sets(m_pa_proplist, PA_PROP_MEDIA_ROLE, "production");
 
@@ -281,11 +337,12 @@ bool PlayBackPulseAudio::connectToServer()
     signal(SIGPIPE, SIG_IGN);
 #endif
 
-    m_pa_mainloop = pa_threaded_mainloop_new();
+    m_pa_mainloop = pa_mainloop_new();
     Q_ASSERT(m_pa_mainloop);
+    pa_mainloop_set_poll_func(m_pa_mainloop, poll_func, this);
 
     m_pa_context = pa_context_new_with_proplist(
-	pa_threaded_mainloop_get_api(m_pa_mainloop),
+	pa_mainloop_get_api(m_pa_mainloop),
 	"Kwave",
 	m_pa_proplist
     );
@@ -294,7 +351,7 @@ bool PlayBackPulseAudio::connectToServer()
     pa_context_set_state_callback(m_pa_context, pa_context_notify_cb, this);
 
     // connect to the pulse audio server server
-    bool context_connected = false;
+    bool failed = false;
     int error = pa_context_connect(
 	m_pa_context,                       // context
 	0,                                  // server
@@ -305,52 +362,34 @@ bool PlayBackPulseAudio::connectToServer()
     {
 	qWarning("PlayBackPulseAudio: pa_contect_connect failed (%s)",
 	         pa_strerror(pa_context_errno(m_pa_context)));
-    } else context_connected = true;
-
-    bool mainloop_started = false;
-    if (context_connected) {
-	pa_threaded_mainloop_lock(m_pa_mainloop);
-	error = pa_threaded_mainloop_start(m_pa_mainloop);
-	if (error < 0) {
-	    qWarning("PlayBackPulseAudio: pa_threaded_mainloop_start failed (%s)",
-		    pa_strerror(pa_context_errno(m_pa_context)));
-	} else {
-	    mainloop_started = true;
-	    qDebug("PlayBackPulseAudio: mainloop started");
-	}
+	failed = true;
     }
-    bool failed = !mainloop_started;
 
-    // wait until the context state is either connected or failed
-    if (mainloop_started) {
-	pa_threaded_mainloop_wait(m_pa_mainloop);
-	if (pa_context_get_state(m_pa_context) != PA_CONTEXT_READY) {
+    if (!failed) {
+	m_mainloop_lock.lock();
+	m_mainloop_thread.start();
+
+	// wait until the context state is either connected or failed
+	failed = true;
+	if ( m_mainloop_signal.wait(&m_mainloop_lock,
+	                            TIMEOUT_CONNECT_TO_SERVER) )
+	{
+	    if (pa_context_get_state(m_pa_context) == PA_CONTEXT_READY) {
+		qDebug("PlayBackPulseAudio: context is ready :-)");
+		failed = false;
+	    }
+	}
+	m_mainloop_lock.unlock();
+
+	if (failed) {
 	    qWarning("PlayBackPulseAudio: context FAILED (%s):-(",
-		pa_strerror(pa_context_errno(m_pa_context)));
-	    failed = true;
-	} else {
-	    qDebug("PlayBackPulseAudio: context is ready :-)");
+	             pa_strerror(pa_context_errno(m_pa_context)));
 	}
     }
-    if (context_connected) pa_threaded_mainloop_unlock(m_pa_mainloop);
 
     // if the connection failed, clean up...
     if (failed) {
-	// release the property list
-	pa_proplist_free(m_pa_proplist);
-
-	// disconnect the pulse context
-	if (context_connected) pa_context_disconnect(m_pa_context);
-	pa_context_unref(m_pa_context);
-
-	// stop and free the main loop
-	if (mainloop_started) pa_threaded_mainloop_stop(m_pa_mainloop);
-	pa_threaded_mainloop_free(m_pa_mainloop);
-	qDebug("PlayBackPulseAudio: mainloop freed");
-
-	m_pa_proplist = 0;
-	m_pa_context  = 0;
-	m_pa_mainloop = 0;
+	disconnectFromServer();
     }
 
     QApplication::restoreOverrideCursor();
@@ -359,10 +398,16 @@ bool PlayBackPulseAudio::connectToServer()
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::disconnectFromServer()
+void Kwave::PlayBackPulseAudio::disconnectFromServer()
 {
     // stop the main loop
-    if (m_pa_mainloop) pa_threaded_mainloop_stop(m_pa_mainloop);
+    m_mainloop_thread.cancel();
+    if (m_pa_mainloop) {
+	m_mainloop_lock.lock();
+	pa_mainloop_quit(m_pa_mainloop, 0);
+	m_mainloop_lock.unlock();
+    }
+    m_mainloop_thread.stop();
 
     // disconnect the pulse context
     if (m_pa_context) {
@@ -373,7 +418,7 @@ void PlayBackPulseAudio::disconnectFromServer()
 
     // stop and free the main loop
     if (m_pa_mainloop) {
-	pa_threaded_mainloop_free(m_pa_mainloop);
+	pa_mainloop_free(m_pa_mainloop);
 	m_pa_mainloop = 0;
 	qDebug("PlayBackPulseAudio: mainloop freed");
     }
@@ -387,9 +432,10 @@ void PlayBackPulseAudio::disconnectFromServer()
 }
 
 //***************************************************************************
-QString PlayBackPulseAudio::open(const QString &device, double rate,
-                                 unsigned int channels, unsigned int bits,
-                                 unsigned int bufbase)
+QString Kwave::PlayBackPulseAudio::open(const QString &device, double rate,
+                                        unsigned int channels,
+                                        unsigned int bits,
+                                        unsigned int bufbase)
 {
     #define SET_PROPERTY(__property__,__info__)              \
 	if (m_info.contains(__info__))                       \
@@ -397,7 +443,8 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
 	    m_info.get(__info__).toString().toUtf8().data())
 
     qDebug("PlayBackPulseAudio::open(device=%s,rate=%0.1f,channels=%u,"\
-	"bits=%u, bufbase=%u)", device.toLocal8Bit().data(), rate, channels,
+	"bits=%u, bufbase=%u)",
+	DBG(device.split(_("|")).at(0)), rate, channels,
 	bits, bufbase);
 
     // close the previous device
@@ -412,7 +459,7 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
     if (!m_device_list.contains(device)) {
 	return i18n(
 	    "The PulseAudio device '%1' is unknown or no longer connected",
-	    device.section('|',0,0).toLocal8Bit().data());
+	    device.section(QLatin1Char('|'), 0, 0));
     }
     QString pa_device = m_device_list[device].m_name;
 
@@ -425,17 +472,17 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
     // build a property list for the stream
     pa_proplist *_proplist = pa_proplist_copy(m_pa_proplist);
     Q_ASSERT(_proplist);
-    SET_PROPERTY(PA_PROP_MEDIA_TITLE,     INF_NAME);
-    SET_PROPERTY(PA_PROP_MEDIA_ARTIST,    INF_AUTHOR);
+    SET_PROPERTY(PA_PROP_MEDIA_TITLE,     Kwave::INF_NAME);
+    SET_PROPERTY(PA_PROP_MEDIA_ARTIST,    Kwave::INF_AUTHOR);
 #ifdef PA_PROP_MEDIA_COPYRIGHT
-    SET_PROPERTY(PA_PROP_MEDIA_COPYRIGHT, INF_COPYRIGHT);
+    SET_PROPERTY(PA_PROP_MEDIA_COPYRIGHT, Kwave::INF_COPYRIGHT);
 #endif
 #ifdef PA_PROP_MEDIA_SOFTWARE
-    SET_PROPERTY(PA_PROP_MEDIA_SOFTWARE,  INF_SOFTWARE);
+    SET_PROPERTY(PA_PROP_MEDIA_SOFTWARE,  Kwave::INF_SOFTWARE);
 #endif
-//  SET_PROPERTY(PA_PROP_MEDIA_LANGUAGE,  INF_...);
-    SET_PROPERTY(PA_PROP_MEDIA_FILENAME,  INF_FILENAME);
-//  SET_PROPERTY(PA_PROP_MEDIA_ICON_NAME, INF_...);
+//  SET_PROPERTY(PA_PROP_MEDIA_LANGUAGE,  Kwave::INF_...);
+    SET_PROPERTY(PA_PROP_MEDIA_FILENAME,  Kwave::INF_FILENAME);
+//  SET_PROPERTY(PA_PROP_MEDIA_ICON_NAME, Kwave::INF_...);
 
     // use Kwave's internal sample format as output
     pa_sample_spec sample_spec;
@@ -445,19 +492,20 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
     sample_spec.format = PA_SAMPLE_S24_32LE;
 #endif
     sample_spec.channels = channels;
-    sample_spec.rate     = static_cast<uint32_t>(rate);
+    sample_spec.rate     = static_cast<quint32>(rate);
 
     // use the current title / filename or fixed string as stream name
     QString name;
-    if (m_info.contains(INF_NAME)) // first choice: title
-	name = m_info.get(INF_NAME).toString();
-    if (!name.length() && m_info.contains(INF_FILENAME)) // fallback: filename
-	name = m_info.get(INF_FILENAME).toString();
+    if (m_info.contains(Kwave::INF_NAME)) // first choice: title
+	name = m_info.get(Kwave::INF_NAME).toString();
+    // fallback: filename
+    if (!name.length() && m_info.contains(Kwave::INF_FILENAME))
+	name = m_info.get(Kwave::INF_FILENAME).toString();
     if (!name.length()) // last resort: fixed string
 	name = i18n("playback...");
 
     // run with mainloop locked from here on...
-    pa_threaded_mainloop_lock(m_pa_mainloop);
+    m_mainloop_lock.lock();
 
     // create a new stream
     m_pa_stream = pa_stream_new_with_proplist(
@@ -469,17 +517,16 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
     pa_proplist_free(_proplist);
 
     if (!m_pa_stream) {
-	pa_threaded_mainloop_unlock(m_pa_mainloop);
+	m_mainloop_lock.unlock();
 	return i18n("Failed to create a PulseAudio stream (%1).",
-	             pa_strerror(pa_context_errno(m_pa_context)));
+	            _(pa_strerror(pa_context_errno(m_pa_context))));
     }
     qDebug("PlayBackPulseAudio::open(...) - stream created as %p",
-	   static_cast<void *>(m_pa_stream));
+           static_cast<void *>(m_pa_stream));
 
     // register callbacks for changes in stream state and write events
     pa_stream_set_state_callback(m_pa_stream, pa_stream_state_cb, this);
     pa_stream_set_write_callback(m_pa_stream, pa_write_cb, this);
-    pa_stream_set_latency_update_callback(m_pa_stream, pa_stream_latency_cb, this);
 
     // set buffer attributes
     if (m_bufbase < 10) m_bufbase = 10;
@@ -503,24 +550,24 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
 	0 /* sync stream */ );
 
     if (result >= 0) {
-	pa_threaded_mainloop_wait(m_pa_mainloop);
+	m_mainloop_signal.wait(&m_mainloop_lock, TIMEOUT_CONNECT_PLAYBACK);
 	if (pa_stream_get_state(m_pa_stream) != PA_STREAM_READY)
 	    result = -1;
     }
-    pa_threaded_mainloop_unlock(m_pa_mainloop);
+    m_mainloop_lock.unlock();
 
     if (result < 0) {
 	pa_stream_unref(m_pa_stream);
 	m_pa_stream = 0;
 	return i18n("Failed to open a PulseAudio stream for playback (%1).",
-	             pa_strerror(pa_context_errno(m_pa_context)));
+	            _(pa_strerror(pa_context_errno(m_pa_context))));
     }
 
-    return 0;
+    return QString();
 }
 
 //***************************************************************************
-int PlayBackPulseAudio::write(const Kwave::SampleArray &samples)
+int Kwave::PlayBackPulseAudio::write(const Kwave::SampleArray &samples)
 {
     unsigned int bytes = m_bytes_per_sample;
 
@@ -532,7 +579,7 @@ int PlayBackPulseAudio::write(const Kwave::SampleArray &samples)
 
     // start with a new/empty buffer from PulseAudio
     if (!m_buffer) {
-	pa_threaded_mainloop_lock(m_pa_mainloop);
+	m_mainloop_lock.lock();
 
 	// estimate buffer size and round to whole samples
 	size_t size = -1;
@@ -540,7 +587,6 @@ int PlayBackPulseAudio::write(const Kwave::SampleArray &samples)
 
 	// get a buffer from PulseAudio
 	int result = pa_stream_begin_write(m_pa_stream, &m_buffer, &size);
-// 	qDebug("PlayBackPulseAudio::write(): max buffer size=%u", size);
 	size /= m_bytes_per_sample;
 	size *= m_bytes_per_sample;
 
@@ -549,10 +595,10 @@ int PlayBackPulseAudio::write(const Kwave::SampleArray &samples)
 	if (size < m_buffer_size)
 	    m_buffer_size = size;
 
-	pa_threaded_mainloop_unlock(m_pa_mainloop);
+	m_mainloop_lock.unlock();
 
 	if (result < 0) {
-	    qWarning("PlayBackPulseAudio::write(): pa_stream_begin_write failed");
+	    qWarning("PlayBackPulseAudio: pa_stream_begin_write failed");
 	    return -EIO;
 	}
 
@@ -575,7 +621,7 @@ int PlayBackPulseAudio::write(const Kwave::SampleArray &samples)
     }
 
     // copy the samples
-    MEMCPY(reinterpret_cast<u_int8_t *>(m_buffer) + m_buffer_used,
+    MEMCPY(reinterpret_cast<quint8 *>(m_buffer) + m_buffer_used,
 	   samples.data(), bytes);
     m_buffer_used += bytes;
 
@@ -585,34 +631,50 @@ int PlayBackPulseAudio::write(const Kwave::SampleArray &samples)
 }
 
 //***************************************************************************
-int PlayBackPulseAudio::flush()
+int Kwave::PlayBackPulseAudio::flush()
 {
     if (!m_buffer_used || !m_pa_mainloop || !m_buffer || !m_buffer_size)
 	return 0;
-//     qWarning("PlayBackPulseAudio::flush(): using buffer %p (%u bytes)",
-// 	     m_buffer, m_buffer_size);
+//     qDebug("PlayBackPulseAudio::flush(): using buffer %p (%u bytes)",
+//             m_buffer, m_buffer_size);
 
-    pa_threaded_mainloop_lock(m_pa_mainloop);
+    // calculate a reasonable time for the timeout (16 buffers)
+    int samples_per_buffer = (m_buffer_size / m_bytes_per_sample);
+    int ms = (samples_per_buffer * 1000) / m_info.rate();
+    int timeout = (ms + 1) * 16;
+    if (timeout < TIMEOUT_MIN_FLUSH)
+	timeout = TIMEOUT_MIN_FLUSH;
 
     // write out the buffer allocated before in "write"
     int result = 0;
+
     while (m_buffer_used) {
 	size_t len;
 
-        while (!(len = pa_stream_writable_size(m_pa_stream))) {
+	m_mainloop_lock.lock();
+	while (!(len = pa_stream_writable_size(m_pa_stream))) {
 	    if (!PA_CONTEXT_IS_GOOD(pa_context_get_state(m_pa_context)) ||
-		!PA_STREAM_IS_GOOD(pa_stream_get_state(m_pa_stream))) {
+		!PA_STREAM_IS_GOOD(pa_stream_get_state(m_pa_stream)) ||
+		(static_cast<ssize_t>(len) == -1) )
+	    {
 		qWarning("PlayBackPulseAudio::flush(): bad stream state");
 		result = -1;
 		break;
 	    }
-            pa_threaded_mainloop_wait(m_pa_mainloop);
+	    if (!m_mainloop_signal.wait(&m_mainloop_lock, timeout)) {
+		qWarning("PlayBackPulseAudio::flush(): timed out after %u ms",
+		         timeout);
+		result = -1;
+		break;
+	    }
         }
-        if (result < 0) break;
+	m_mainloop_lock.unlock();
+	if (result < 0) break;
 
 	if (len > m_buffer_used) len = m_buffer_used;
 
 // 	qDebug("PlayBackPulseAudio::flush(): writing %u bytes...", len);
+	m_mainloop_lock.lock();
 	result = pa_stream_write(
 		m_pa_stream,
 		m_buffer,
@@ -621,13 +683,14 @@ int PlayBackPulseAudio::flush()
 		0,
 		PA_SEEK_RELATIVE
 	);
+	m_mainloop_lock.unlock();
+
 	if (result < 0) {
 	    qWarning("PlayBackPulseAudio::flush(): pa_stream_write failed");
-	    pa_threaded_mainloop_unlock(m_pa_mainloop);
 	    return -EIO;
 	}
 
-	m_buffer       = reinterpret_cast<u_int8_t *>(m_buffer) + len;
+	m_buffer       = reinterpret_cast<quint8 *>(m_buffer) + len;
 	m_buffer_used -= len;
     }
 
@@ -636,14 +699,20 @@ int PlayBackPulseAudio::flush()
     // buffer is written out now
     m_buffer_used = 0;
     m_buffer      = 0;
-
-    pa_threaded_mainloop_unlock(m_pa_mainloop);
-
     return result;
 }
 
 //***************************************************************************
-int PlayBackPulseAudio::close()
+void Kwave::PlayBackPulseAudio::run_wrapper(const QVariant &params)
+{
+    Q_UNUSED(params);
+    m_mainloop_lock.lock();
+    pa_mainloop_run(m_pa_mainloop, 0);
+    m_mainloop_lock.unlock();
+}
+
+//***************************************************************************
+int Kwave::PlayBackPulseAudio::close()
 {
     // set hourglass cursor, we are waiting...
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -653,12 +722,19 @@ int PlayBackPulseAudio::close()
     if (m_pa_mainloop && m_pa_stream) {
 
 	pa_operation *op = 0;
-	pa_threaded_mainloop_lock(m_pa_mainloop);
+	m_mainloop_lock.lock();
 	op = pa_stream_drain(m_pa_stream, pa_stream_success_cb, this);
 	Q_ASSERT(op);
 	if (!op) qWarning("pa_stream_drain() failed: '%s'", pa_strerror(
 	    pa_context_errno(m_pa_context)));
 
+	// calculate a reasonable time for the timeout (16 buffers)
+	int samples_per_buffer = (m_buffer_size / m_bytes_per_sample);
+	int ms = (samples_per_buffer * 1000) / m_info.rate();
+	int timeout = (ms + 1) * 4;
+	if (timeout < TIMEOUT_MIN_DRAIN)
+	    timeout = TIMEOUT_MIN_DRAIN;
+
 	qDebug("PlayBackPulseAudio::flush(): waiting for drain to finish...");
 	while (op && (pa_operation_get_state(op) != PA_OPERATION_DONE)) {
 	    if (!PA_CONTEXT_IS_GOOD(pa_context_get_state(m_pa_context)) ||
@@ -666,10 +742,13 @@ int PlayBackPulseAudio::close()
 		qWarning("PlayBackPulseAudio::close(): bad stream state");
 		break;
 	    }
-	    pa_threaded_mainloop_wait(m_pa_mainloop);
+	    if (!m_mainloop_signal.wait(&m_mainloop_lock, timeout)) {
+		qWarning("PlayBackPulseAudio::flush(): timed out after %u ms",
+		         timeout);
+		break;
+	    }
 	}
-	pa_threaded_mainloop_unlock(m_pa_mainloop);
-
+	m_mainloop_lock.unlock();
 
 	if (m_pa_stream) {
 	    pa_stream_disconnect(m_pa_stream);
@@ -686,20 +765,25 @@ int PlayBackPulseAudio::close()
 }
 
 //***************************************************************************
-void PlayBackPulseAudio::scanDevices()
+void Kwave::PlayBackPulseAudio::scanDevices()
 {
     if (!m_pa_context) connectToServer();
     if (!m_pa_context) return;
 
     // fetch the device list from the PulseAudio server
-    pa_threaded_mainloop_lock(m_pa_mainloop);
+    m_mainloop_lock.lock();
     m_device_list.clear();
     pa_operation *op_sink_info = pa_context_get_sink_info_list(
 	m_pa_context,
 	pa_sink_info_cb,
 	this
     );
-    if (op_sink_info) pa_threaded_mainloop_wait(m_pa_mainloop);
+    if (op_sink_info) {
+	// set hourglass cursor, we have a long timeout...
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	m_mainloop_signal.wait(&m_mainloop_lock, TIMEOUT_WAIT_DEVICE_SCAN);
+	QApplication::restoreOverrideCursor();
+    }
 
     // create a list with final names
 //     qDebug("----------------------------------------");
@@ -712,11 +796,11 @@ void PlayBackPulseAudio::scanDevices()
     s.rate     = 0;
     s.channels = 0;
     i.m_name        = QString();
-    i.m_description = "(server default)";
+    i.m_description = _("(server default)");
     i.m_driver      = QString();
     i.m_card        = -1;
     i.m_sample_spec = s;
-    list[i18n("(Use server default)") + "|sound_note"] = i;
+    list[i18n("(Use server default)") + _("|sound_note")] = i;
 
     foreach (QString sink, m_device_list.keys()) {
 	QString name        = m_device_list[sink].m_name;
@@ -734,34 +818,35 @@ void PlayBackPulseAudio::scanDevices()
 		break;
 	    }
 	}
-	if (!unique) description += " [" + name + "]";
+	if (!unique) description += _(" [") + name + _("]");
 
 	// mangle the driver name, e.g.
 	// "module-alsa-sink.c" -> "alsa sink"
 	QFileInfo f(driver);
 	driver = f.baseName();
-	driver.replace("-", " ");
-	driver.replace("_", " ");
-	if (driver.toLower().startsWith("module ")) driver.remove(0, 7);
-	description.prepend(driver + "|sound_card||");
+	driver.replace(_("-"), _(" "));
+	driver.replace(_("_"), _(" "));
+	if (driver.toLower().startsWith(_("module ")))
+	    driver.remove(0, 7);
+	description.prepend(driver + _("|sound_card||"));
 
 	// add the leaf node
 	if (m_device_list[sink].m_card != PA_INVALID_INDEX)
-	    description.append(QString("|sound_device"));
+	    description.append(_("|sound_device"));
 	else
-	    description.append(QString("|sound_note"));
+	    description.append(_("|sound_note"));
 
-// 	qDebug("supported device: '%s'", description.toLocal8Bit().data());
+// 	qDebug("supported device: '%s'", DBG(description));
 	list.insert(description, m_device_list[sink]);
     }
 //     qDebug("----------------------------------------");
 
     m_device_list = list;
-    pa_threaded_mainloop_unlock(m_pa_mainloop);
+    m_mainloop_lock.unlock();
 }
 
 //***************************************************************************
-QStringList PlayBackPulseAudio::supportedDevices()
+QStringList Kwave::PlayBackPulseAudio::supportedDevices()
 {
     QStringList list;
 
@@ -771,19 +856,22 @@ QStringList PlayBackPulseAudio::supportedDevices()
     if (!m_pa_mainloop || !m_pa_context) return list;
 
     list = m_device_list.keys();
-    if (!list.isEmpty()) list.prepend("#TREE#");
+    if (!list.isEmpty()) list.prepend(_("#TREE#"));
 
     return list;
 }
 
 //***************************************************************************
-QString PlayBackPulseAudio::fileFilter()
+QString Kwave::PlayBackPulseAudio::fileFilter()
 {
-    return "";
+    return _("");
 }
 
 //***************************************************************************
-QList<unsigned int> PlayBackPulseAudio::supportedBits(const QString &device)
+QList<unsigned int> Kwave::PlayBackPulseAudio::supportedBits
+(
+    const QString &device
+)
 {
     QList<unsigned int> list;
 
@@ -796,8 +884,9 @@ QList<unsigned int> PlayBackPulseAudio::supportedBits(const QString &device)
 }
 
 //***************************************************************************
-int PlayBackPulseAudio::detectChannels(const QString &device,
-                                       unsigned int &min, unsigned int &max)
+int Kwave::PlayBackPulseAudio::detectChannels(const QString &device,
+                                              unsigned int &min,
+                                              unsigned int &max)
 {
     min = max = 0;
 
