@@ -19,14 +19,18 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <QIcon>
-#include <QLabel>
-#include <QTreeWidget>
-#include <QTreeWidgetItem>
-#include <QSlider>
-#include <QStringList>
+#include <QtGui/QIcon>
+#include <QtGui/QLabel>
+#include <QtGui/QPushButton>
+#include <QtGui/QTreeWidget>
+#include <QtGui/QTreeWidgetItem>
+#include <QtGui/QSlider>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QStringList>
 
+#include <kapplication.h>
 #include <kcombobox.h>
+#include <kconfig.h>
 #include <kfiledialog.h>
 #include <kiconloader.h>
 #include <kicontheme.h>
@@ -35,27 +39,41 @@
 #include <kpushbutton.h>
 #include <ktoolinvocation.h>
 
-#include "libgui/KwaveFileDialog.h"
-#include "libkwave/KwavePlugin.h"
+#include "libkwave/PlaybackController.h"
+#include "libkwave/PlayBackDevice.h"
+#include "libkwave/PlayBackTypesMap.h"
+#include "libkwave/Plugin.h"
+#include "libkwave/String.h"
+
+#include "libgui/FileDialog.h"
+
 #include "PlayBackDialog.h"
 #include "PlayBackPlugin.h"
 
 //***************************************************************************
-PlayBackDialog::PlayBackDialog(Kwave::Plugin &p, const PlayBackParam &params)
+Kwave::PlayBackDialog::PlayBackDialog(
+    Kwave::Plugin &p,
+    Kwave::PlaybackController &playback_controller,
+    const Kwave::PlayBackParam &params
+)
     :QDialog(p.parentWidget()), PlayBackDlg(),
-    m_playback_params(params), m_file_filter(""), m_devices_list_map(),
-    m_enable_setDevice(true)
+     m_playback_controller(playback_controller),
+     m_device(0),
+     m_playback_params(params),
+     m_methods_map(),
+     m_file_filter(_("")),
+     m_devices_list_map(),
+     m_enable_setDevice(true)
 {
     setupUi(this);
     setModal(true);
 
-    // button for "test settings"
-    // (not implemented yet)
-
     // fill the combo box with playback methods
     unsigned int index=0;
-    for (index=0; index < m_methods_map.count(); index++) {
-	cbMethod->addItem(m_methods_map.description(index, true));
+    for (index = 0; index < m_methods_map.count(); index++) {
+	cbMethod->addItem(
+	    m_methods_map.description(index, true),
+	    static_cast<int>(m_methods_map.data(index)) );
     }
     cbMethod->setEnabled(cbMethod->count() > 1);
 
@@ -86,7 +104,7 @@ PlayBackDialog::PlayBackDialog(Kwave::Plugin &p, const PlayBackParam &params)
 
     connect(btTest, SIGNAL(clicked()),
             SIGNAL(sigTestPlayback()));
-    connect(btHelp, SIGNAL(clicked()),
+    connect(btHelp->button(QDialogButtonBox::Help), SIGNAL(clicked()),
             this,   SLOT(invokeHelp()));
 
     // remove the header of the tree view
@@ -105,38 +123,127 @@ PlayBackDialog::PlayBackDialog(Kwave::Plugin &p, const PlayBackParam &params)
 
     // buffer size is independend
     setBufferSize(params.bufbase);
+
+    // set the focus onto the "OK" button
+    buttonBox->button(QDialogButtonBox::Ok)->setFocus();
 }
 
 //***************************************************************************
-PlayBackDialog::~PlayBackDialog()
+Kwave::PlayBackDialog::~PlayBackDialog()
 {
 }
 
 //***************************************************************************
-void PlayBackDialog::setMethod(playback_method_t method)
+void Kwave::PlayBackDialog::setMethod(Kwave::playback_method_t method)
 {
+    Kwave::playback_method_t old_method = m_playback_params.method;
+
     m_playback_params.method = method;
-    cbMethod->setCurrentIndex(m_methods_map.findFromData(
-        m_playback_params.method));
-}
 
-//***************************************************************************
-void PlayBackDialog::methodSelected(int index)
-{
-    playback_method_t method = m_methods_map.data(index);
-    Q_ASSERT(method > PLAYBACK_NONE);
-    Q_ASSERT(method < PLAYBACK_INVALID);
-    if (method <= PLAYBACK_NONE) return;
-    if (method >= PLAYBACK_INVALID) return;
-
-    if (method != m_playback_params.method) {
-	setMethod(method);
-	emit sigMethodChanged(method);
+    // update the selection in the combo box if necessary
+    int index = cbMethod->findData(static_cast<int>(method));
+    if (cbMethod->currentIndex() != index) {
+	cbMethod->setCurrentIndex(index);
+	return; // we will get called again, through "methodSelected(...)"
     }
+
+    qDebug("PlayBackDialog::setMethod('%s' [%d])",
+           DBG(m_methods_map.name(m_methods_map.findFromData(method))),
+	   static_cast<int>(method) );
+
+    // set hourglass cursor
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
+    // change the playback method (class PlayBackDevice)
+    if (m_device) delete m_device;
+    m_device = 0;
+
+    // remember the device selection, just for the GUI
+    // for the next time this method gets selected
+    // change in method -> save the current device and use
+    // the previous one
+    QString device = _("");
+    QString section = _("plugin playback");
+    KConfigGroup cfg = KGlobal::config()->group(section);
+
+    // save the current device
+    cfg.writeEntry(
+	QString(_("last_device_%1")).arg(static_cast<int>(old_method)),
+	m_playback_params.device);
+    qDebug("SAVE:    '%s' (%d) -> '%s'",
+	    DBG(m_methods_map.name(m_methods_map.findFromData(old_method))),
+	    static_cast<int>(old_method),
+	    DBG(m_playback_params.device.split(_("|")).at(0)));
+    cfg.sync();
+
+    // NOTE: the "method" may get modified here if not supported!
+    m_playback_controller.checkMethod(method);
+    if (method != m_playback_params.method) {
+	// method has been modified to some fallback -> start through
+	qDebug("    method has changed: %d -> %d",
+	       static_cast<int>(m_playback_params.method),
+	       static_cast<int>(method));
+	setMethod(method); // -> recursion
+	return;
+    }
+
+    // if we found no playback method
+    if (method == Kwave::PLAYBACK_INVALID) {
+	qWarning("found no valid playback method");
+    }
+
+    // create a new playback device (will fail if method is unsupported)
+    m_device = m_playback_controller.createDevice(method);
+    if (!m_device) {
+	// oops, something has failed :-(
+	setSupportedDevices(QStringList());
+	setDevice(QString());
+	return;
+    }
+
+    // restore the previous settings of the new method
+    device = cfg.readEntry(
+	_("last_device_%1").arg(static_cast<int>(method)));
+    qDebug("RESTORE: '%s' (%d) -> '%s'",
+	    DBG(m_methods_map.name(m_methods_map.findFromData(method))),
+	    static_cast<int>(method),
+	   DBG(device.split(_("|")).at(0)));
+
+    m_playback_params.device = device;
+
+    // set list of supported devices
+    setSupportedDevices(m_device->supportedDevices());
+
+    // set current device, no matter if supported or not,
+    // the dialog will take care of this.
+    setDevice(m_playback_params.device);
+
+    // check the filter for the "select..." dialog. If it is
+    // empty, the "select" dialog will be disabled
+    setFileFilter(m_device->fileFilter());
+
+    // remove hourglass
+    QApplication::restoreOverrideCursor();
 }
 
 //***************************************************************************
-void PlayBackDialog::setSupportedDevices(QStringList devices)
+void Kwave::PlayBackDialog::methodSelected(int index)
+{
+    Kwave::playback_method_t method = static_cast<Kwave::playback_method_t>(
+	cbMethod->itemData(index).toInt());
+
+    qDebug("PlayBackDialog::methodSelected(%d) -> %s [%d]", index,
+	DBG(m_methods_map.name(m_methods_map.findFromData(method))),
+	static_cast<int>(method) );
+
+    if (method <= Kwave::PLAYBACK_NONE) return;
+    if (method >= Kwave::PLAYBACK_INVALID) return;
+
+    setMethod(method);
+}
+
+//***************************************************************************
+void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 {
     Q_ASSERT(cbDevice);
     Q_ASSERT(listDevices);
@@ -147,21 +254,23 @@ void PlayBackDialog::setSupportedDevices(QStringList devices)
     // device controls...
     m_enable_setDevice = false;
 
-    KIconLoader icon_loader;
+//     qDebug("PlayBackDialog::setSupportedDevices():");
+//     foreach (const QString &d, devices)
+// 	qDebug("    '%s'", DBG(d));
 
     cbDevice->clearEditText();
     cbDevice->clear();
     listDevices->clear();
 
-    if (devices.contains("#EDIT#")) {
-	devices.removeAll("#EDIT#");
+    if (devices.contains(_("#EDIT#"))) {
+	devices.removeAll(_("#EDIT#"));
 	cbDevice->setEditable(true);
     } else {
 	cbDevice->setEditable(false);
     }
 
-    if (devices.contains("#SELECT#")) {
-	devices.removeAll("#SELECT#");
+    if (devices.contains(_("#SELECT#"))) {
+	devices.removeAll(_("#SELECT#"));
 	btSelectDevice->setEnabled(true);
 	btSelectDevice->show();
     } else {
@@ -169,9 +278,11 @@ void PlayBackDialog::setSupportedDevices(QStringList devices)
 	btSelectDevice->hide();
     }
 
-    if (devices.contains("#TREE#")) {
+    if (devices.contains(_("#TREE#"))) {
 	// treeview mode
-	devices.removeAll("#TREE#");
+	KIconLoader icon_loader;
+
+	devices.removeAll((_("#TREE#")));
 	listDevices->setEnabled(true);
 	cbDevice->setEnabled(false);
 	cbDevice->hide();
@@ -181,13 +292,13 @@ void PlayBackDialog::setSupportedDevices(QStringList devices)
 	foreach (QString dev_id, devices) {
 	    QTreeWidgetItem *parent = 0;
 
-	    QStringList list = dev_id.split("||", QString::KeepEmptyParts);
+	    QStringList list = dev_id.split(_("||"), QString::KeepEmptyParts);
 	    foreach (QString token, list) {
 		QTreeWidgetItem *item = 0;
 
 		// split the icon name from the token
 		QString icon_name;
-		int pos = token.indexOf('|');
+		int pos = token.indexOf(QLatin1Char('|'));
 		if (pos > 0) {
 		    icon_name = token.mid(pos+1);
 		    token     = token.left(pos);
@@ -196,7 +307,7 @@ void PlayBackDialog::setSupportedDevices(QStringList devices)
 		// find the first item with the same text
 		// and the same root
 		if (parent) {
-		    for (int i=0; i < parent->childCount(); i++) {
+		    for (int i = 0; i < parent->childCount(); i++) {
 			QTreeWidgetItem *node = parent->child(i);
 			if (node && node->text(0) == token) {
 			    item = node;
@@ -239,7 +350,7 @@ void PlayBackDialog::setSupportedDevices(QStringList devices)
 		    }
 		}
 
-		if (icon_name.length()) {
+		if (item && icon_name.length()) {
 		    QIcon icon = icon_loader.loadIcon(
 			icon_name, KIconLoader::User);
 		    item->setIcon(0, icon);
@@ -279,8 +390,8 @@ void PlayBackDialog::setSupportedDevices(QStringList devices)
 }
 
 //***************************************************************************
-void PlayBackDialog::listEntrySelected(QTreeWidgetItem *current,
-                                       QTreeWidgetItem *previous)
+void Kwave::PlayBackDialog::listEntrySelected(QTreeWidgetItem *current,
+                                              QTreeWidgetItem *previous)
 {
     Q_ASSERT(listDevices);
     Q_UNUSED(previous);
@@ -291,28 +402,31 @@ void PlayBackDialog::listEntrySelected(QTreeWidgetItem *current,
 }
 
 //***************************************************************************
-void PlayBackDialog::listItemExpanded(QTreeWidgetItem *item)
+void Kwave::PlayBackDialog::listItemExpanded(QTreeWidgetItem *item)
 {
     Q_UNUSED(item);
     updateListSelection();
 }
 
 //***************************************************************************
-void PlayBackDialog::updateListSelection()
+void Kwave::PlayBackDialog::updateListSelection()
 {
     // set the current device again, otherwise nothing will be selected
     setDevice(m_playback_params.device);
 }
 
 //***************************************************************************
-void PlayBackDialog::setDevice(const QString &device)
+void Kwave::PlayBackDialog::setDevice(const QString &device)
 {
     Q_ASSERT(cbDevice);
     Q_ASSERT(listDevices);
     if (!cbDevice || !listDevices) return;
 
     if (!m_enable_setDevice) return;
-//     qDebug("PlayBackDialog::setDevice(%s)", device.toLocal8Bit().data());
+
+    qDebug("PlayBackDialog::setDevice(): '%s' -> '%s'",
+       DBG(m_playback_params.device.split(_("|")).at(0)),
+       DBG(device.split(_("|")).at(0)));
 
     if (listDevices->isEnabled()) {
 	// treeview mode
@@ -337,14 +451,38 @@ void PlayBackDialog::setDevice(const QString &device)
 	}
     }
 
-    if (m_playback_params.device != device) {
-	m_playback_params.device = device;
-	emit sigDeviceChanged(device);
+    // select the default device if new one is not supported
+    QString dev = device;
+    if (m_device) {
+	QStringList supported = m_device->supportedDevices();
+	supported.removeAll(_("#EDIT#"));
+	supported.removeAll(_("#SELECT#"));
+	supported.removeAll(_("#TREE#"));
+	if (!supported.isEmpty() && !supported.contains(device)) {
+	    // use the first entry as default
+	    dev = supported.first();
+	    qDebug("PlayBackPlugin::setDevice(%s) -> fallback to '%s'",
+		DBG(device.split(_("|")).at(0)),
+		DBG(dev.split(_("|")).at(0)));
+	}
     }
+
+    // take over the device, please note that this one might differ from
+    // the device we got as parameter, maybe it is a fallback
+    m_playback_params.device = dev;
+
+    QList<unsigned int> supported_bits;
+    if (m_device) supported_bits = m_device->supportedBits(dev);
+    setSupportedBits(supported_bits);
+
+    unsigned int min = 0;
+    unsigned int max = 0;
+    if (m_device) m_device->detectChannels(dev, min, max);
+    setSupportedChannels(min, max);
 }
 
 //***************************************************************************
-void PlayBackDialog::setBufferSize(int exp)
+void Kwave::PlayBackDialog::setBufferSize(int exp)
 {
     Q_ASSERT(slBufferSize);
     Q_ASSERT(txtBufferSize);
@@ -371,7 +509,7 @@ void PlayBackDialog::setBufferSize(int exp)
 }
 
 //***************************************************************************
-void PlayBackDialog::setSupportedBits(const QList<unsigned int> &bits)
+void Kwave::PlayBackDialog::setSupportedBits(const QList<unsigned int> &bits)
 {
     Q_ASSERT(cbBitsPerSample);
     if (!cbBitsPerSample) return;
@@ -398,7 +536,7 @@ void PlayBackDialog::setSupportedBits(const QList<unsigned int> &bits)
 }
 
 //***************************************************************************
-void PlayBackDialog::bitsPerSampleSelected(const QString &text)
+void Kwave::PlayBackDialog::bitsPerSampleSelected(const QString &text)
 {
     bool ok = false;
     unsigned int bits = text.toUInt(&ok);
@@ -408,12 +546,13 @@ void PlayBackDialog::bitsPerSampleSelected(const QString &text)
 }
 
 //***************************************************************************
-void PlayBackDialog::setBitsPerSample(unsigned int bits)
+void Kwave::PlayBackDialog::setBitsPerSample(unsigned int bits)
 {
     Q_ASSERT(cbBitsPerSample);
     if (!cbBitsPerSample) return;
 
-//     qDebug("PlayBackDialog::setBitsPerSample(%u)", bits);
+    qDebug("PlayBackDialog::setBitsPerSample(): %u -> %u",
+           m_playback_params.bits_per_sample, bits);
 
     QString txt;
     txt.setNum(bits);
@@ -424,7 +563,7 @@ void PlayBackDialog::setBitsPerSample(unsigned int bits)
 }
 
 //***************************************************************************
-void PlayBackDialog::setSupportedChannels(unsigned int min, unsigned int max)
+void Kwave::PlayBackDialog::setSupportedChannels(unsigned int min, unsigned int max)
 {
     Q_ASSERT(sbChannels);
     if (!sbChannels) return;
@@ -442,14 +581,11 @@ void PlayBackDialog::setSupportedChannels(unsigned int min, unsigned int max)
 }
 
 //***************************************************************************
-void PlayBackDialog::setChannels(int channels)
+void Kwave::PlayBackDialog::setChannels(int channels)
 {
     Q_ASSERT(sbChannels);
     if (!sbChannels) return;
 
-//     qDebug("PlayBackDialog::setChannels(%d)", channels);
-    m_playback_params.channels = channels;
-
     if ((sbChannels->value() != channels) &&
         (sbChannels->minimum() != sbChannels->maximum()) &&
 	(sbChannels->maximum() > 0))
@@ -457,45 +593,49 @@ void PlayBackDialog::setChannels(int channels)
 	sbChannels->setValue(channels);
 	channels = sbChannels->value();
     }
-//     qDebug("PlayBackDialog::setChannels --> %d", channels);
+
+    qDebug("PlayBackDialog::setChannels(): %d -> %d",
+           m_playback_params.channels, channels);
+    m_playback_params.channels = channels;
 
     QString txt;
     switch (channels) {
 	case 1: txt = i18n("(mono)");   break;
 	case 2: txt = i18n("(stereo)"); break;
 	case 4: txt = i18n("(quadro)"); break;
-	default: txt = "";
+	default: txt = _("");
     }
     lblChannels->setText(txt);
 }
 
 //***************************************************************************
-const PlayBackParam &PlayBackDialog::params()
+const Kwave::PlayBackParam &Kwave::PlayBackDialog::params()
 {
     return m_playback_params;
 }
 
 //***************************************************************************
-void PlayBackDialog::setFileFilter(const QString &filter)
+void Kwave::PlayBackDialog::setFileFilter(const QString &filter)
 {
     m_file_filter = filter;
     if (btSelectDevice) btSelectDevice->setEnabled(m_file_filter.length());
 }
 
 //***************************************************************************
-void PlayBackDialog::selectPlaybackDevice()
+void Kwave::PlayBackDialog::selectPlaybackDevice()
 {
     QString filter = m_file_filter;
 
-    KwaveFileDialog dlg("kfiledialog:///kwave_playback_device", filter, this,
-	true, "file:/dev");
+    Kwave::FileDialog dlg(
+	_("kfiledialog:///kwave_playback_device"), filter, this,
+	true, _("file:/dev"));
     dlg.setKeepLocation(true);
     dlg.setOperationMode(KFileDialog::Opening);
     dlg.setCaption(i18n("Select Playback Device"));
-    if (m_playback_params.device[0] != '[')
-        dlg.setUrl(KUrl("file:"+m_playback_params.device));
+    if (!m_playback_params.device.startsWith(_("#")))
+        dlg.setUrl(KUrl(_("file:") + m_playback_params.device));
     else
-        dlg.setUrl(KUrl("file:/dev/*"));
+        dlg.setUrl(KUrl(_("file:/dev/*")));
     if (dlg.exec() != QDialog::Accepted) return;
 
     QString new_device = dlg.selectedFile();
@@ -505,9 +645,9 @@ void PlayBackDialog::selectPlaybackDevice()
 }
 
 //***************************************************************************
-void PlayBackDialog::invokeHelp()
+void Kwave::PlayBackDialog::invokeHelp()
 {
-    KToolInvocation::invokeHelp("playback");
+    KToolInvocation::invokeHelp(_("playback"));
 }
 
 //***************************************************************************
