@@ -21,15 +21,18 @@
 #include <errno.h>
 #include <math.h>
 
-#include <QtGlobal>
+#include <QtCore/QtGlobal>
+
+#include "libkwave/Compression.h"
+#include "libkwave/String.h"
 
 #include "Record-ALSA.h"
 
 /** initializer for the list of devices */
-QMap<QString, QString> RecordALSA::m_device_list;
+QMap<QString, QString> Kwave::RecordALSA::m_device_list;
 
 /** gui name of the default device */
-#define DEFAULT_DEVICE (i18n("DSNOOP plugin")+QString("|sound_note"))
+#define DEFAULT_DEVICE (i18n("DSNOOP plugin") + _("|sound_note"))
 
 /** helper macro: returns the number of elements in an array */
 #define ELEMENTS_OF(__array__) (sizeof(__array__) / sizeof(__array__[0]))
@@ -144,32 +147,32 @@ static const unsigned int g_sleep_min = 0;
 
 //***************************************************************************
 /** find out the SampleFormat of an ALSA format */
-static SampleFormat sample_format_of(snd_pcm_format_t fmt)
+static Kwave::SampleFormat sample_format_of(snd_pcm_format_t fmt)
 {
     if (snd_pcm_format_float(fmt)) {
 	if (snd_pcm_format_width(fmt) == 32)
-	    return SampleFormat::Float;
+	    return Kwave::SampleFormat::Float;
 	if (snd_pcm_format_width(fmt) == 64)
-	    return SampleFormat::Double;
+	    return Kwave::SampleFormat::Double;
     } else if (snd_pcm_format_linear(fmt)) {
 	if (snd_pcm_format_signed(fmt) == 1)
-	    return SampleFormat::Signed;
+	    return Kwave::SampleFormat::Signed;
 	else if (snd_pcm_format_unsigned(fmt) == 1)
-	    return SampleFormat::Unsigned;
+	    return Kwave::SampleFormat::Unsigned;
     }
 
-    return SampleFormat::Unknown;
+    return Kwave::SampleFormat::Unknown;
 }
 
 //***************************************************************************
 /** find out the endianness of an ALSA format */
-static byte_order_t endian_of(snd_pcm_format_t fmt)
+static Kwave::byte_order_t endian_of(snd_pcm_format_t fmt)
 {
     if (snd_pcm_format_little_endian(fmt) == 1)
-	return LittleEndian;
+	return Kwave::LittleEndian;
     if (snd_pcm_format_big_endian(fmt) == 1)
-	return BigEndian;
-    return CpuEndian;
+	return Kwave::BigEndian;
+    return Kwave::CpuEndian;
 }
 
 //***************************************************************************
@@ -177,27 +180,27 @@ static int compression_of(snd_pcm_format_t fmt)
 {
     switch (fmt) {
 	case SND_PCM_FORMAT_MU_LAW:
-	    return AF_COMPRESSION_G711_ULAW;
+	    return Kwave::Compression::G711_ULAW;
 	case SND_PCM_FORMAT_A_LAW:
-	    return AF_COMPRESSION_G711_ALAW;
+	    return Kwave::Compression::G711_ALAW;
 	case SND_PCM_FORMAT_IMA_ADPCM:
-	    return AF_COMPRESSION_MS_ADPCM;
+	    return Kwave::Compression::MS_ADPCM;
 	case SND_PCM_FORMAT_MPEG:
-	    return CompressionType::MPEG_LAYER_I;
+	    return Kwave::Compression::MPEG_LAYER_I;
 	case SND_PCM_FORMAT_GSM:
-	    return AF_COMPRESSION_GSM;
+	    return Kwave::Compression::GSM;
 	default:
-	    return AF_COMPRESSION_NONE;
+	    return Kwave::Compression::NONE;
     }
-    return AF_COMPRESSION_NONE;
+    return Kwave::Compression::NONE;
 }
 
 //***************************************************************************
-RecordALSA::RecordALSA()
-    :RecordDevice(), m_handle(0), m_hw_params(0),
+Kwave::RecordALSA::RecordALSA()
+    :Kwave::RecordDevice(), m_handle(0), m_hw_params(0),
      m_sw_params(0), m_open_result(0), m_tracks(0),
      m_rate(0.0), m_compression(0), m_bits_per_sample(0),
-     m_bytes_per_sample(0), m_sample_format(SampleFormat::Unknown),
+     m_bytes_per_sample(0), m_sample_format(Kwave::SampleFormat::Unknown),
      m_supported_formats(), m_initialized(false), m_buffer_size(0),
      m_chunk_size(0)
 {
@@ -208,7 +211,7 @@ RecordALSA::RecordALSA()
 }
 
 //***************************************************************************
-RecordALSA::~RecordALSA()
+Kwave::RecordALSA::~RecordALSA()
 {
     close();
     snd_pcm_hw_params_free(m_hw_params);
@@ -216,7 +219,7 @@ RecordALSA::~RecordALSA()
 }
 
 //***************************************************************************
-void RecordALSA::detectSupportedFormats()
+void Kwave::RecordALSA::detectSupportedFormats()
 {
     // start with an empty list
     m_supported_formats.clear();
@@ -249,19 +252,18 @@ void RecordALSA::detectSupportedFormats()
 	}
 	if (!fmt) continue;
 
-// 	CompressionType t;
-// 	SampleFormat::Map sf;
+// 	Kwave::Compression t;
+// 	Kwave::SampleFormat::Map sf;
 // 	qDebug("#%2u, %2d, %2u bit [%u byte], %s, '%s', '%s'",
 // 	    i,
 // 	    *fmt,
 // 	    snd_pcm_format_width(*fmt),
 // 	    (snd_pcm_format_physical_width(*fmt)+7) >> 3,
-// 	    endian_of(*fmt) == CpuEndian ? "CPU" :
-// 	    (endian_of(*fmt) == LittleEndian ? "LE " : "BE "),
-// 	    sf.name(sf.findFromData(sample_format_of(
-// 		*fmt))).toLocal8Bit().data(),
-// 	    t.name(t.findFromData(compression_of(
-// 		*fmt))).toLocal8Bit().data());
+// 	    endian_of(*fmt) == Kwave::CpuEndian ? "CPU" :
+// 	    (endian_of(*fmt) == Kwave::LittleEndian ? "LE " : "BE "),
+// 	    DBG(sf.description(sf.findFromData(sample_format_of(
+// 	    DBG(t.description(t.findFromData(compression_of(
+// 		*fmt), true))));
 
 	m_supported_formats.append(i);
     }
@@ -270,9 +272,9 @@ void RecordALSA::detectSupportedFormats()
 }
 
 //***************************************************************************
-int RecordALSA::open(const QString &device)
+int Kwave::RecordALSA::open(const QString &device)
 {
-//     qDebug("RecordALSA::open(%s)", device.toLocal8Bit().data());
+//     qDebug("RecordALSA::open(%s)", DBG(device));
 
     // close the previous device
     if (m_handle) close();
@@ -282,13 +284,13 @@ int RecordALSA::open(const QString &device)
 
     // translate verbose name to internal ALSA name
     QString alsa_device = alsaDeviceName(device);
-    qDebug("RecordALSA::open -> '%s'", alsa_device.toLocal8Bit().data());
+    qDebug("RecordALSA::open -> '%s'", DBG(alsa_device));
 
     if (!alsa_device.length()) return -ENOENT;
 
     // workaround for bug in ALSA
     // if the device name ends with "," -> invalid name
-    if (alsa_device.endsWith(",")) return -ENOENT;
+    if (alsa_device.endsWith(_(","))) return -ENOENT;
 
     // open the device in case it's not already open
     m_open_result = snd_pcm_open(&m_handle, alsa_device.toLocal8Bit().data(),
@@ -297,7 +299,7 @@ int RecordALSA::open(const QString &device)
     if (m_open_result < 0) {
 	m_handle = 0;
 	qWarning("RecordALSA::openDevice('%s') - failed, err=%d (%s)",
-	         alsa_device.toLocal8Bit().data(),
+	         DBG(alsa_device),
 	         m_open_result, snd_strerror(m_open_result));
 	return m_open_result;
     }
@@ -309,7 +311,7 @@ int RecordALSA::open(const QString &device)
 }
 
 //***************************************************************************
-int RecordALSA::initialize()
+int Kwave::RecordALSA::initialize()
 {
     int err;
     snd_output_t *output = NULL;
@@ -359,14 +361,13 @@ int RecordALSA::initialize()
                                    m_sample_format);
     Q_ASSERT(format_index >= 0);
     if (format_index < 0) {
-	CompressionType t;
-	SampleFormat::Map sf;
+	Kwave::SampleFormat::Map sf;
 
 	qWarning("RecordkALSA::setFormat(): no matching format for "\
 	         "compression '%s', %d bits/sample, format '%s'",
-	         sf.name(sf.findFromData(m_sample_format)).toLocal8Bit().data(),
+	         DBG(sf.description(sf.findFromData(m_sample_format), true)),
 	         m_bits_per_sample,
-	         t.name(t.findFromData(m_compression)).toLocal8Bit().data());
+	         DBG(Kwave::Compression(m_compression).name()));
 
 	snd_output_close(output);
 	return -EINVAL;
@@ -522,7 +523,7 @@ int RecordALSA::initialize()
 }
 
 //***************************************************************************
-int RecordALSA::read(QByteArray &buffer, unsigned int offset)
+int Kwave::RecordALSA::read(QByteArray &buffer, unsigned int offset)
 {
     unsigned int length = buffer.size();
 
@@ -613,9 +614,9 @@ int RecordALSA::read(QByteArray &buffer, unsigned int offset)
 	// underrun -> start again
 	qWarning("RecordALSA::read(), underrun");
 	r = snd_pcm_prepare(m_handle);
-	r = snd_pcm_start(m_handle);
+	if (r >= 0) r = snd_pcm_start(m_handle);
 	if (r < 0) {
-	    qWarning("RecordALSA::read(), "\
+	    qWarning("RecordALSA::read(), "
 		     "resume after underrun failed: %s",
 		     snd_strerror(r));
 	    return r;
@@ -628,7 +629,7 @@ int RecordALSA::read(QByteArray &buffer, unsigned int offset)
 	while ((r = snd_pcm_resume(m_handle)) == -EAGAIN)
 	    return -EAGAIN; /* wait until suspend flag is released */
 	if (r < 0) {
-	    qWarning("RecordALSA::read(), resume failed, "\
+	    qWarning("RecordALSA::read(), resume failed, "
 		    "restarting stream.");
 	    if ((r = snd_pcm_prepare(m_handle)) < 0) {
 		qWarning("RecordALSA::read(), resume error: %s",
@@ -636,7 +637,7 @@ int RecordALSA::read(QByteArray &buffer, unsigned int offset)
 		return r;
 	    }
 	}
-	qWarning("PlayBackALSA::read(), after suspend: resuming");
+	qWarning("RecordALSA::read(), after suspend: resuming");
 	return -EAGAIN; // try again
     } else if (r < 0) {
 	qWarning("RecordALSA: read error: %s", snd_strerror(r));
@@ -653,7 +654,7 @@ int RecordALSA::read(QByteArray &buffer, unsigned int offset)
 }
 
 //***************************************************************************
-int RecordALSA::close()
+int Kwave::RecordALSA::close()
 {
     // close the device handle
 
@@ -675,7 +676,7 @@ int RecordALSA::close()
 }
 
 //***************************************************************************
-int RecordALSA::detectTracks(unsigned int &min, unsigned int &max)
+int Kwave::RecordALSA::detectTracks(unsigned int &min, unsigned int &max)
 {
     min = max = 0;
 
@@ -696,7 +697,7 @@ int RecordALSA::detectTracks(unsigned int &min, unsigned int &max)
 }
 
 //***************************************************************************
-int RecordALSA::setTracks(unsigned int &tracks)
+int Kwave::RecordALSA::setTracks(unsigned int &tracks)
 {
     if (tracks != m_tracks) m_initialized = false;
     m_tracks = tracks;
@@ -704,13 +705,13 @@ int RecordALSA::setTracks(unsigned int &tracks)
 }
 
 //***************************************************************************
-int RecordALSA::tracks()
+int Kwave::RecordALSA::tracks()
 {
     return m_tracks;
 }
 
 //***************************************************************************
-QList<double> RecordALSA::detectSampleRates()
+QList<double> Kwave::RecordALSA::detectSampleRates()
 {
     QList<double> list;
     int err;
@@ -775,7 +776,7 @@ QList<double> RecordALSA::detectSampleRates()
 }
 
 //***************************************************************************
-int RecordALSA::setSampleRate(double &new_rate)
+int Kwave::RecordALSA::setSampleRate(double &new_rate)
 {
     if (new_rate != m_rate) m_initialized = false;
     m_rate = new_rate;
@@ -783,14 +784,14 @@ int RecordALSA::setSampleRate(double &new_rate)
 }
 
 //***************************************************************************
-double RecordALSA::sampleRate()
+double Kwave::RecordALSA::sampleRate()
 {
     return m_rate;
 }
 
 //***************************************************************************
-int RecordALSA::mode2format(int compression, int bits,
-                            SampleFormat sample_format)
+int Kwave::RecordALSA::mode2format(int compression, int bits,
+                                   Kwave::SampleFormat sample_format)
 {
     // loop over all supported formats and keep only those that are
     // compatible with the given compression, bits and sample format
@@ -815,7 +816,7 @@ int RecordALSA::mode2format(int compression, int bits,
 }
 
 //***************************************************************************
-QList<int> RecordALSA::detectCompressions()
+QList<int> Kwave::RecordALSA::detectCompressions()
 {
     QList<int> list;
 
@@ -828,9 +829,9 @@ QList<int> RecordALSA::detectCompressions()
 	// do not produce duplicates
 	if (list.contains(compression)) continue;
 
-	CompressionType t;
+// 	Kwave::Compression t;
 // 	qDebug("found compression %d '%s'", compression,
-// 	       t.name(t.findFromData(compression)).toLocal8Bit().data());
+// 	       DBG(t.name(t.findFromData(compression))));
 	list.append(compression);
     }
 
@@ -838,7 +839,7 @@ QList<int> RecordALSA::detectCompressions()
 }
 
 //***************************************************************************
-int RecordALSA::setCompression(int new_compression)
+int Kwave::RecordALSA::setCompression(int new_compression)
 {
     if (m_compression != new_compression) m_initialized = false;
     m_compression = new_compression;
@@ -846,13 +847,13 @@ int RecordALSA::setCompression(int new_compression)
 }
 
 //***************************************************************************
-int RecordALSA::compression()
+int Kwave::RecordALSA::compression()
 {
     return m_compression;
 }
 
 //***************************************************************************
-QList<unsigned int> RecordALSA::supportedBits()
+QList<unsigned int> Kwave::RecordALSA::supportedBits()
 {
     QList<unsigned int> list;
 
@@ -879,7 +880,7 @@ QList<unsigned int> RecordALSA::supportedBits()
 }
 
 //***************************************************************************
-int RecordALSA::setBitsPerSample(unsigned int new_bits)
+int Kwave::RecordALSA::setBitsPerSample(unsigned int new_bits)
 {
     if (m_bits_per_sample != new_bits) m_initialized = false;
     m_bits_per_sample = new_bits;
@@ -887,21 +888,21 @@ int RecordALSA::setBitsPerSample(unsigned int new_bits)
 }
 
 //***************************************************************************
-int RecordALSA::bitsPerSample()
+int Kwave::RecordALSA::bitsPerSample()
 {
     return m_bits_per_sample;
 }
 
 //***************************************************************************
-QList<SampleFormat> RecordALSA::detectSampleFormats()
+QList<Kwave::SampleFormat> Kwave::RecordALSA::detectSampleFormats()
 {
-    QList<SampleFormat> list;
+    QList<Kwave::SampleFormat> list;
 
     // try all known sample formats
     foreach(int it, m_supported_formats)
     {
 	const snd_pcm_format_t *fmt = &(_known_formats[it]);
-	const SampleFormat sample_format = sample_format_of(*fmt);
+	const Kwave::SampleFormat sample_format = sample_format_of(*fmt);
 
 	// only accept bits/sample if compression types
 	// and bits per sample match
@@ -912,9 +913,9 @@ QList<SampleFormat> RecordALSA::detectSampleFormats()
 	// do not produce duplicates
 	if (list.contains(sample_format)) continue;
 
-	SampleFormat::Map sf;
+// 	Kwave::SampleFormat::Map sf;
 // 	qDebug("found sample format %u ('%s')", (int)sample_format,
-// 		sf.name(sf.findFromData(sample_format)).toLocal8Bit().data());
+// 		DBG(sf.name(sf.findFromData(sample_format))));
 
 	list.append(sample_format);
     }
@@ -923,7 +924,7 @@ QList<SampleFormat> RecordALSA::detectSampleFormats()
 }
 
 //***************************************************************************
-int RecordALSA::setSampleFormat(SampleFormat new_format)
+int Kwave::RecordALSA::setSampleFormat(Kwave::SampleFormat new_format)
 {
     if (m_sample_format != new_format) m_initialized = false;
     m_sample_format = new_format;
@@ -931,20 +932,21 @@ int RecordALSA::setSampleFormat(SampleFormat new_format)
 }
 
 //***************************************************************************
-SampleFormat RecordALSA::sampleFormat()
+Kwave::SampleFormat Kwave::RecordALSA::sampleFormat()
 {
     return m_sample_format;
 }
 
 //***************************************************************************
-byte_order_t RecordALSA::endianness()
+Kwave::byte_order_t Kwave::RecordALSA::endianness()
 {
     int index = mode2format(m_compression, m_bits_per_sample, m_sample_format);
-    return (index >= 0) ? endian_of(_known_formats[index]) : UnknownEndian;
+    return (index >= 0) ?
+	endian_of(_known_formats[index]) : Kwave::UnknownEndian;
 }
 
 //***************************************************************************
-QStringList RecordALSA::supportedDevices()
+QStringList Kwave::RecordALSA::supportedDevices()
 {
     // re-validate the list if necessary
     scanDevices();
@@ -955,12 +957,12 @@ QStringList RecordALSA::supportedDevices()
     if (list.contains(DEFAULT_DEVICE))
 	list.move(list.indexOf(DEFAULT_DEVICE), 0);
 
-    list.append("#TREE#");
+    list.append(_("#TREE#"));
     return list;
 }
 
 //***************************************************************************
-void RecordALSA::scanDevices()
+void Kwave::RecordALSA::scanDevices()
 {
     snd_ctl_t *handle = 0;
     int card, err, dev;
@@ -982,7 +984,7 @@ void RecordALSA::scanDevices()
 //     qDebug("**** List of RECORD Hardware Devices ****");
     while (card >= 0) {
 	QString name;
-	name = "hw:%1";
+	name = _("hw:%1");
 	name = name.arg(card);
 	if ((err = snd_ctl_open(&handle, name.toLocal8Bit().data(), 0)) < 0) {
 	    qWarning("control open (%i): %s", card, snd_strerror(err));
@@ -1022,11 +1024,11 @@ void RecordALSA::scanDevices()
 
 	    // add the device to the list
 	    QString hw_device;
-	    hw_device = "hw:%1,%2";
+	    hw_device = _("hw:%1,%2");
 	    hw_device = hw_device.arg(card).arg(dev);
 
-	    QString card_name   = snd_ctl_card_info_get_name(info);
-	    QString device_name = snd_pcm_info_get_name(pcminfo);
+	    QString card_name   = _(snd_ctl_card_info_get_name(info));
+	    QString device_name = _(snd_pcm_info_get_name(pcminfo));
 
 //  	    qDebug("  Subdevices: %i/%i\n",
 // 		snd_pcm_info_get_subdevices_avail(pcminfo), count);
@@ -1037,27 +1039,27 @@ void RecordALSA::scanDevices()
 			qWarning("ctrl digital audio playback info (%i): %s",
 			         card, snd_strerror(err));
 		    } else {
-			QString hwdev = hw_device + QString(",%1").arg(idx);
-			QString subdevice_name =
-			    snd_pcm_info_get_subdevice_name(pcminfo);
-			QString name = QString(
+			QString hwdev = hw_device + _(",%1").arg(idx);
+			QString subdevice_name = _(
+			    snd_pcm_info_get_subdevice_name(pcminfo));
+			QString name =
 			    i18n("Card %1: ", card_name) +
-			    "|sound_card||" +
+			    _("|sound_card||") +
 			    i18n("Device %1: ", device_name) +
-			    "|sound_device||" +
+			    _("|sound_device||") +
 			    i18n("Subdevice %1: ", subdevice_name) +
-			    "|sound_subdevice"
-			)/*.arg(card).arg(dev).arg(idx)*/;
-			qDebug("# '%s' -> '%s'", hwdev.toLocal8Bit().data(),
-			       name.toLocal8Bit().data());
+			    _("|sound_subdevice");
+			qDebug("# '%s' -> '%s'", DBG(hwdev), DBG(name));
 			m_device_list.insert(name, hwdev);
 		    }
 		}
 	    } else {
 		// no sub-devices
 		QString name = QString(
-		    i18n("Card %1: ", card_name) + "|sound_card||" +
-		    i18n("Device %1: ", device_name) + "|sound_subdevice"
+		    i18n("Card %1: ", card_name) +
+		    _("|sound_card||") +
+		    i18n("Device %1: ", device_name) +
+		    _("|sound_subdevice")
 		)/*.arg(card).arg(dev)*/;
 // 		qDebug("# '%s' -> '%s'", hw_device.data(), name.data());
 		m_device_list.insert(name, hw_device);
@@ -1075,7 +1077,7 @@ next_card:
 
     // per default: offer the dsnoop plugin if any slave devices exist
     if (!m_device_list.isEmpty()) {
-	m_device_list.insert(DEFAULT_DEVICE, "plug:dsnoop");
+	m_device_list.insert(DEFAULT_DEVICE, _("plug:dsnoop"));
     }
 
     snd_ctl_card_info_free(info);
@@ -1091,7 +1093,7 @@ next_card:
 }
 
 //***************************************************************************
-QString RecordALSA::alsaDeviceName(const QString &name)
+QString Kwave::RecordALSA::alsaDeviceName(const QString &name)
 {
     if (m_device_list.isEmpty() || (name.length() &&
         !m_device_list.contains(name)))
@@ -1104,9 +1106,8 @@ QString RecordALSA::alsaDeviceName(const QString &name)
 	foreach (QString n, m_device_list.values())
 	    if (n == name) return n;
 
-	qWarning("RecordALSA::alsaDeviceName('%s') - NOT FOUND",
-	         name.toLocal8Bit().data());
-	return "";
+	qWarning("RecordALSA::alsaDeviceName('%s') - NOT FOUND", DBG(name));
+	return _("");
     }
     return m_device_list[name];
 }
