@@ -27,12 +27,14 @@
 #include <math.h>
 #include <errno.h>
 
-#include <QDir>
-#include <QFile>
-#include <QtGlobal>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QtGlobal>
 
-#include "libkwave/CompressionType.h"
+#include "libkwave/Compression.h"
 #include "libkwave/SampleFormat.h"
+#include "libkwave/String.h"
 
 #include "Record-OSS.h"
 
@@ -71,19 +73,20 @@
 #define MAX_CHANNELS 2 /**< highest available number of channels */
 
 //***************************************************************************
-RecordOSS::RecordOSS()
-    :RecordDevice(), m_fd(-1), m_oss_version(-1)
+Kwave::RecordOSS::RecordOSS()
+    :Kwave::RecordDevice(),
+     m_fd(-1), m_rate(0), m_tracks(0), m_oss_version(-1)
 {
 }
 
 //***************************************************************************
-RecordOSS::~RecordOSS()
+Kwave::RecordOSS::~RecordOSS()
 {
     close();
 }
 
 //***************************************************************************
-int RecordOSS::open(const QString &dev)
+int Kwave::RecordOSS::open(const QString &dev)
 {
     // close the device if it is still open
     if (m_fd >= 0) close();
@@ -107,7 +110,7 @@ int RecordOSS::open(const QString &dev)
 }
 
 //***************************************************************************
-int RecordOSS::read(QByteArray &buffer, unsigned int offset)
+int Kwave::RecordOSS::read(QByteArray &buffer, unsigned int offset)
 {
     fd_set rfds;
     struct timeval tv;
@@ -146,7 +149,7 @@ int RecordOSS::read(QByteArray &buffer, unsigned int offset)
 
     unsigned int timeout = (length / rate) * 2;
     if (timeout < 2) timeout = 2;
-    u_int8_t *buf = reinterpret_cast<u_int8_t *>(buffer.data()) + offset;
+    quint8 *buf = reinterpret_cast<quint8 *>(buffer.data()) + offset;
 
     int mask = 0;
     retval = ioctl(m_fd, SNDCTL_DSP_SETTRIGGER, &mask);
@@ -197,7 +200,7 @@ int RecordOSS::read(QByteArray &buffer, unsigned int offset)
 }
 
 //***************************************************************************
-int RecordOSS::close()
+int Kwave::RecordOSS::close()
 {
     if (m_fd < 0) return 0; // already closed
     ::close(m_fd);
@@ -212,9 +215,9 @@ static bool addIfExists(QStringList &list, const QString &name)
 {
     QFile file;
 
-    if (name.contains("%1")) {
+    if (name.contains(_("%1"))) {
 	// test for the name without suffix first
-	addIfExists(list, name.arg(""));
+	addIfExists(list, name.arg(_("")));
 
 	// loop over the list and try until a suffix does not exist
 	for (unsigned int index=0; index < 64; index++)
@@ -240,12 +243,12 @@ static void scanFiles(QStringList &list, const QString &dirname,
     QDir dir;
 
     dir.setPath(dirname);
-    dir.setNameFilters(mask.split(' '));
+    dir.setNameFilters(mask.split(QLatin1Char(' ')));
     dir.setFilter(QDir::Files | QDir::Readable | QDir::System);
     dir.setSorting(QDir::Name);
     files = dir.entryList();
 
-    for (QStringList::Iterator it=files.begin(); it != files.end(); ++it) {
+    for (QStringList::Iterator it = files.begin(); it != files.end(); ++it) {
 	QString devicename = dirname + QDir::separator() + (*it);
 	addIfExists(list, devicename);
     }
@@ -254,92 +257,94 @@ static void scanFiles(QStringList &list, const QString &dirname,
 //***************************************************************************
 static void scanDirectory(QStringList &list, const QString &dir)
 {
-    scanFiles(list, dir, "*audio*");
-    scanFiles(list, dir, "adsp*");
-    scanFiles(list, dir, "dsp*");
-    scanFiles(list, dir, "dio*");
-    scanFiles(list, dir, "pcm*");
+    scanFiles(list, dir, _("*audio*"));
+    scanFiles(list, dir, _("adsp*"));
+    scanFiles(list, dir, _("dsp*"));
+    scanFiles(list, dir, _("dio*"));
+    scanFiles(list, dir, _("pcm*"));
 }
 
 //***************************************************************************
-QStringList RecordOSS::supportedDevices()
+QStringList Kwave::RecordOSS::supportedDevices()
 {
     QStringList list, dirlist;
 
-    scanDirectory(list, "/dev");
-    scanDirectory(list, "/dev/sound");
-    scanFiles(dirlist, "/dev/oss", "[^.]*");
+    scanDirectory(list, _("/dev"));
+    scanDirectory(list, _("/dev/sound"));
+    scanFiles(dirlist, _("/dev/oss"), _("[^.]*"));
     foreach(QString dir, dirlist)
 	scanDirectory(list, dir);
-    list.append("#EDIT#");
-    list.append("#SELECT#");
+    list.append(_("#EDIT#"));
+    list.append(_("#SELECT#"));
 
     return list;
 }
 
 //***************************************************************************
-QString RecordOSS::fileFilter()
+QString Kwave::RecordOSS::fileFilter()
 {
     QString filter;
 
-    if (filter.length()) filter += "\n";
-    filter += QString("audio*|") + i18n("OSS recording device (audio*)");
-    filter += QString("dsp*|") + i18n("OSS recording device (dsp*)");
+    if (filter.length()) filter += _("\n");
+    filter += _("audio*|") + i18n("OSS recording device (audio*)");
+    filter += _("dsp*|")   + i18n("OSS recording device (dsp*)");
 
-    if (filter.length()) filter += "\n";
-    filter += QString("adsp*|") + i18n("ALSA recording device (adsp*)");
+    if (filter.length()) filter += _("\n");
+    filter += _("adsp*|")  + i18n("ALSA recording device (adsp*)");
 
-    if (filter.length()) filter += "\n";
-    filter += QString("*|") + i18n("Any device (*)");
+    if (filter.length()) filter += _("\n");
+    filter += _("*|")      + i18n("Any device (*)");
 
     return filter;
 }
 
 //***************************************************************************
-int RecordOSS::detectTracks(unsigned int &min, unsigned int &max)
+int Kwave::RecordOSS::detectTracks(unsigned int &min, unsigned int &max)
 {
     Q_ASSERT(m_fd >= 0);
-    int t;
+    unsigned int t;
     int err;
 
+    // preset
+    min = 0;
+    max = 0;
+
     // find the smalles number of tracks, limit to MAX_CHANNELS
-    for (t=1; t < MAX_CHANNELS; t++) {
+    for (t = 1; t < MAX_CHANNELS; t++) {
 	int real_tracks = t;
 	err = ioctl(m_fd, SNDCTL_DSP_CHANNELS, &real_tracks);
-	Q_ASSERT(real_tracks == t);
-	if (err >= 0) {
+	if ((err >= 0) && (static_cast<unsigned int>(real_tracks) == t)) {
 	    min = real_tracks;
 	    break;
 	}
     }
     if (t >= MAX_CHANNELS) {
 	// no minimum track number found :-o
-	qWarning("no minimum track number found, err=%d",err);
+	qWarning("no minimum track number found, err=%d", err);
 	min = 0;
 	max = 0;
 	return err;
     }
 
     // find the highest number of tracks, start from MAX_CHANNELS downwards
-    for (t=MAX_CHANNELS; t >= static_cast<int>(min); t--) {
+    max = min;
+    for (t = MAX_CHANNELS; t >= min; t--) {
 	int real_tracks = t;
 	err = ioctl(m_fd, SNDCTL_DSP_CHANNELS, &real_tracks);
-	Q_ASSERT(real_tracks == t);
-	if (err >= 0) {
+	if ((err >= 0) && (static_cast<unsigned int>(real_tracks) == t)) {
 	    max = real_tracks;
 	    break;
 	}
     }
-    max = t;
     m_tracks = max;
 
-    qDebug("RecordOSS::detectTracks, min=%u, max=%u",min,max);
+    qDebug("RecordOSS::detectTracks, min=%u, max=%u", min, max);
 
-    return 0;
+    return (max > 0) ? 0 : -1;
 }
 
 //***************************************************************************
-int RecordOSS::setTracks(unsigned int &tracks)
+int Kwave::RecordOSS::setTracks(unsigned int &tracks)
 {
     Q_ASSERT(m_fd >= 0);
 
@@ -356,13 +361,13 @@ int RecordOSS::setTracks(unsigned int &tracks)
 }
 
 //***************************************************************************
-int RecordOSS::tracks()
+int Kwave::RecordOSS::tracks()
 {
     return m_tracks;
 }
 
 //***************************************************************************
-QList<double> RecordOSS::detectSampleRates()
+QList<double> Kwave::RecordOSS::detectSampleRates()
 {
     QList<double> list;
     Q_ASSERT(m_fd >= 0);
@@ -412,8 +417,8 @@ QList<double> RecordOSS::detectSampleRates()
 	int rate = known_rates[i];
 	int err = ioctl(m_fd, SNDCTL_DSP_SPEED, &rate);
 	if (err < 0) {
-	    qDebug("RecordOSS::detectSampleRates(): "\
-	           "sample rate %d Hz not supported", known_rates[i]);
+// 	    qDebug("RecordOSS::detectSampleRates(): "
+// 	           "sample rate %d Hz not supported", known_rates[i]);
 	    continue;
 	}
 
@@ -429,7 +434,7 @@ QList<double> RecordOSS::detectSampleRates()
 }
 
 //***************************************************************************
-int RecordOSS::setSampleRate(double &new_rate)
+int Kwave::RecordOSS::setSampleRate(double &new_rate)
 {
     Q_ASSERT(m_fd >= 0);
     // OSS supports only integer rates
@@ -447,7 +452,7 @@ int RecordOSS::setSampleRate(double &new_rate)
 }
 
 //***************************************************************************
-double RecordOSS::sampleRate()
+double Kwave::RecordOSS::sampleRate()
 {
     Q_ASSERT(m_fd >= 0);
 
@@ -455,95 +460,96 @@ double RecordOSS::sampleRate()
 }
 
 //***************************************************************************
-void RecordOSS::format2mode(int format, int &compression, int &bits,
-                            SampleFormat &sample_format)
+void Kwave::RecordOSS::format2mode(int format, int &compression, int &bits,
+                                   Kwave::SampleFormat &sample_format)
 {
 
     switch (format) {
 	case AFMT_MU_LAW:
-	    compression   = AF_COMPRESSION_G711_ULAW;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::G711_ULAW;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 	case AFMT_A_LAW:
-	    compression   = AF_COMPRESSION_G711_ALAW;
-	    sample_format = SampleFormat::Unsigned;
+	    compression   = Kwave::Compression::G711_ALAW;
+	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 16;
 	    break;
 	case AFMT_IMA_ADPCM:
-	    compression   = AF_COMPRESSION_MS_ADPCM;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::MS_ADPCM;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 	case AFMT_U8:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Unsigned;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 8;
 	    break;
 	case AFMT_S16_LE:
 	case AFMT_S16_BE:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 	case AFMT_S8:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 8;
 	    break;
 	case AFMT_U16_LE:
 	case AFMT_U16_BE:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Unsigned;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 16;
 	    break;
 	case AFMT_MPEG:
-	    compression   = static_cast<int>(CompressionType::MPEG_LAYER_II);
-	    sample_format = SampleFormat::Signed;
+	    compression   = static_cast<int>(
+	                    Kwave::Compression::MPEG_LAYER_II);
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
 #if 0
 	case AFMT_AC3: /* Dolby Digital AC3 */
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Unknown;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Unknown;
 	    bits          = 16;
 	    break;
 #endif
 	case AFMT_S24_LE:
 	case AFMT_S24_BE:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 24;
 	    break;
 	case AFMT_S32_LE:
 	case AFMT_S32_BE:
-	    compression   = AF_COMPRESSION_NONE;
-	    sample_format = SampleFormat::Signed;
+	    compression   = Kwave::Compression::NONE;
+	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 32;
 	    break;
 	default:
 	    compression   = -1;
-	    sample_format = SampleFormat::Unknown;
+	    sample_format = Kwave::SampleFormat::Unknown;
 	    bits          = -1;
     }
 
 }
 
 //***************************************************************************
-int RecordOSS::mode2format(int compression, int bits,
-                           SampleFormat sample_format)
+int Kwave::RecordOSS::mode2format(int compression, int bits,
+                                  Kwave::SampleFormat sample_format)
 {
     // first level: compression
-    if (compression == AF_COMPRESSION_G711_ULAW) return AFMT_MU_LAW;
-    if (compression == AF_COMPRESSION_G711_ALAW) return AFMT_A_LAW;
-    if (compression == AF_COMPRESSION_MS_ADPCM)  return AFMT_IMA_ADPCM;
-    if (compression == static_cast<int>(CompressionType::MPEG_LAYER_II))
+    if (compression == Kwave::Compression::G711_ULAW) return AFMT_MU_LAW;
+    if (compression == Kwave::Compression::G711_ALAW) return AFMT_A_LAW;
+    if (compression == Kwave::Compression::MS_ADPCM)  return AFMT_IMA_ADPCM;
+    if (compression == static_cast<int>(Kwave::Compression::MPEG_LAYER_II))
 	return AFMT_MPEG;
 
     // non-compressed: switch by sample format
-    if ((sample_format == SampleFormat::Unsigned) && (bits == 8))
+    if ((sample_format == Kwave::SampleFormat::Unsigned) && (bits == 8))
 	return AFMT_U8;
-    if ((sample_format == SampleFormat::Signed) && (bits == 8))
+    if ((sample_format == Kwave::SampleFormat::Signed) && (bits == 8))
         return AFMT_S8;
 
     // get supported modes, maybe one endianness is not supported
@@ -553,7 +559,7 @@ int RecordOSS::mode2format(int compression, int bits,
 
     // unsigned 16 bit mode
     // note: we prefer the machine's native endianness if both are supported !
-    if ((sample_format == SampleFormat::Unsigned) && (bits == 16)) {
+    if ((sample_format == Kwave::SampleFormat::Unsigned) && (bits == 16)) {
 	mask &= (AFMT_U16_LE | AFMT_U16_BE);
 	if (mask != (AFMT_U16_LE | AFMT_U16_BE)) return mask;
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
@@ -564,7 +570,7 @@ int RecordOSS::mode2format(int compression, int bits,
     }
 
     // signed 16 bit mode
-    if ((sample_format == SampleFormat::Signed) && (bits == 16)) {
+    if ((sample_format == Kwave::SampleFormat::Signed) && (bits == 16)) {
 	mask &= (AFMT_S16_LE | AFMT_S16_BE);
 	if (mask != (AFMT_S16_LE | AFMT_S16_BE)) return mask;
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
@@ -574,7 +580,7 @@ int RecordOSS::mode2format(int compression, int bits,
 #endif
     }
 
-    if ((sample_format == SampleFormat::Signed) && (bits == 24)) {
+    if ((sample_format == Kwave::SampleFormat::Signed) && (bits == 24)) {
 	mask &= (AFMT_S24_LE | AFMT_S24_BE);
 	if (mask != (AFMT_S24_LE | AFMT_S24_BE)) return mask;
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
@@ -584,7 +590,7 @@ int RecordOSS::mode2format(int compression, int bits,
 #endif
     }
 
-    if ((sample_format == SampleFormat::Signed) && (bits == 32)) {
+    if ((sample_format == Kwave::SampleFormat::Signed) && (bits == 32)) {
 	mask &= (AFMT_S32_LE | AFMT_S32_BE);
 	if (mask != (AFMT_S32_LE | AFMT_S32_BE)) return mask;
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
@@ -600,7 +606,7 @@ int RecordOSS::mode2format(int compression, int bits,
 }
 
 //***************************************************************************
-QList<int> RecordOSS::detectCompressions()
+QList<int> Kwave::RecordOSS::detectCompressions()
 {
     Q_ASSERT(m_fd >= 0);
     QList<int> compressions;
@@ -611,24 +617,24 @@ QList<int> RecordOSS::detectCompressions()
     if (err < 0) return compressions;
 
     if (mask & AFMT_MPEG)
-        compressions += static_cast<int>(CompressionType::MPEG_LAYER_II);
-    if (mask & AFMT_A_LAW)     compressions += AF_COMPRESSION_G711_ALAW;
-    if (mask & AFMT_MU_LAW)    compressions += AF_COMPRESSION_G711_ULAW;
-    if (mask & AFMT_IMA_ADPCM) compressions += AF_COMPRESSION_MS_ADPCM;
-    if (mask & (AFMT_U16_LE | AFMT_U16_BE | AFMT_S16_LE | AFMT_S16_BE | \
-                AFMT_S24_LE | AFMT_S24_BE | AFMT_S32_LE | AFMT_S32_BE | \
+        compressions += static_cast<int>(Kwave::Compression::MPEG_LAYER_II);
+    if (mask & AFMT_A_LAW)   compressions += Kwave::Compression::G711_ALAW;
+    if (mask & AFMT_MU_LAW)  compressions += Kwave::Compression::G711_ULAW;
+    if (mask & AFMT_IMA_ADPCM) compressions += Kwave::Compression::MS_ADPCM;
+    if (mask & (AFMT_U16_LE | AFMT_U16_BE | AFMT_S16_LE | AFMT_S16_BE |
+                AFMT_S24_LE | AFMT_S24_BE | AFMT_S32_LE | AFMT_S32_BE |
                 AFMT_S8 | AFMT_U8))
-        compressions += AF_COMPRESSION_NONE;
+        compressions += Kwave::Compression::NONE;
 
     return compressions;
 }
 
 //***************************************************************************
-int RecordOSS::setCompression(int new_compression)
+int Kwave::RecordOSS::setCompression(int new_compression)
 {
     Q_ASSERT(m_fd >= 0);
     int compression, bits, format = AFMT_QUERY;
-    SampleFormat sample_format;
+    Kwave::SampleFormat sample_format;
 
     // read back current format
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &format);
@@ -649,21 +655,21 @@ int RecordOSS::setCompression(int new_compression)
 }
 
 //***************************************************************************
-int RecordOSS::compression()
+int Kwave::RecordOSS::compression()
 {
     Q_ASSERT(m_fd >= 0);
     int mask = AFMT_QUERY;
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &mask);
-    if (err < 0) return AF_COMPRESSION_NONE;
+    if (err < 0) return Kwave::Compression::NONE;
 
     int c, b;
-    SampleFormat s;
+    Kwave::SampleFormat s;
     format2mode(mask, c, b, s);
     return c;
 }
 
 //***************************************************************************
-QList<unsigned int> RecordOSS::supportedBits()
+QList<unsigned int> Kwave::RecordOSS::supportedBits()
 {
     Q_ASSERT(m_fd >= 0);
     QList<unsigned int> bits;
@@ -677,11 +683,11 @@ QList<unsigned int> RecordOSS::supportedBits()
     // mask out all modes that do not match the current compression
     const int compression = this->compression();
     for (unsigned int bit=0; bit < (sizeof(mask) << 3); bit++) {
-	if (!mask & (1 << bit)) continue;
+	if (!(mask & (1 << bit))) continue;
 
 	// format is supported, split into compression, bits, sample format
 	int c, b;
-	SampleFormat s;
+	Kwave::SampleFormat s;
 	format2mode(1 << bit, c, b, s);
 	if (b < 0) continue; // unknown -> skip
 
@@ -700,11 +706,11 @@ QList<unsigned int> RecordOSS::supportedBits()
 }
 
 //***************************************************************************
-int RecordOSS::setBitsPerSample(unsigned int new_bits)
+int Kwave::RecordOSS::setBitsPerSample(unsigned int new_bits)
 {
     Q_ASSERT(m_fd >= 0);
     int compression, bits, format = AFMT_QUERY;
-    SampleFormat sample_format;
+    Kwave::SampleFormat sample_format;
 
     // read back current format
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &format);
@@ -725,7 +731,7 @@ int RecordOSS::setBitsPerSample(unsigned int new_bits)
 }
 
 //***************************************************************************
-int RecordOSS::bitsPerSample()
+int Kwave::RecordOSS::bitsPerSample()
 {
     Q_ASSERT(m_fd >= 0);
     int mask = AFMT_QUERY;
@@ -733,16 +739,16 @@ int RecordOSS::bitsPerSample()
     if (err < 0) return err;
 
     int c, b;
-    SampleFormat s;
+    Kwave::SampleFormat s;
     format2mode(mask, c, b, s);
     return b;
 }
 
 //***************************************************************************
-QList<SampleFormat> RecordOSS::detectSampleFormats()
+QList<Kwave::SampleFormat> Kwave::RecordOSS::detectSampleFormats()
 {
     Q_ASSERT(m_fd >= 0);
-    QList<SampleFormat> formats;
+    QList<Kwave::SampleFormat> formats;
     formats.clear();
     int err = 0;
     int mask = AFMT_QUERY;
@@ -754,12 +760,12 @@ QList<SampleFormat> RecordOSS::detectSampleFormats()
     // and bits per sample
     const int compression     = this->compression();
     const int bits_per_sample = this->bitsPerSample();
-    for (unsigned int bit=0; bit < (sizeof(mask) << 3); bit++) {
-	if (!mask & (1 << bit)) continue;
+    for (unsigned int bit = 0; bit < (sizeof(mask) << 3); bit++) {
+	if (!(mask & (1 << bit))) continue;
 
 	// format is supported, split into compression, bits, sample format
 	int c, b;
-	SampleFormat s;
+	Kwave::SampleFormat s;
 	format2mode(1 << bit, c, b, s);
 	if (c < 0) continue; // unknown -> skip
 
@@ -773,11 +779,11 @@ QList<SampleFormat> RecordOSS::detectSampleFormats()
 }
 
 //***************************************************************************
-int RecordOSS::setSampleFormat(SampleFormat new_format)
+int Kwave::RecordOSS::setSampleFormat(Kwave::SampleFormat new_format)
 {
     Q_ASSERT(m_fd >= 0);
     int compression, bits, format = AFMT_QUERY;
-    SampleFormat sample_format;
+    Kwave::SampleFormat sample_format;
 
     // read back current format
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &format);
@@ -798,37 +804,37 @@ int RecordOSS::setSampleFormat(SampleFormat new_format)
 }
 
 //***************************************************************************
-SampleFormat RecordOSS::sampleFormat()
+Kwave::SampleFormat Kwave::RecordOSS::sampleFormat()
 {
     Q_ASSERT(m_fd >= 0);
     int mask = AFMT_QUERY;
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &mask);
-    if (err < 0) return SampleFormat::Unknown;
+    if (err < 0) return Kwave::SampleFormat::Unknown;
 
     int c, b;
-    SampleFormat s;
+    Kwave::SampleFormat s;
     format2mode(mask, c, b, s);
     return s;
 }
 
 //***************************************************************************
-byte_order_t RecordOSS::endianness()
+Kwave::byte_order_t Kwave::RecordOSS::endianness()
 {
     Q_ASSERT(m_fd >= 0);
     int mask = AFMT_QUERY;
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &mask);
-    if (err < 0) return UnknownEndian;
+    if (err < 0) return Kwave::UnknownEndian;
 
     if (mask & (AFMT_U16_LE | AFMT_S16_LE | AFMT_S24_LE | AFMT_S32_LE))
-	return LittleEndian;
+	return Kwave::LittleEndian;
 
     if (mask & (AFMT_U16_BE | AFMT_S16_BE | AFMT_S24_BE | AFMT_S32_BE))
-	return BigEndian;
+	return Kwave::BigEndian;
 
     if (mask & (AFMT_S8 | AFMT_U8))
-	return CpuEndian;
+	return Kwave::CpuEndian;
 
-    return UnknownEndian;
+    return Kwave::UnknownEndian;
 }
 
 #endif /* HAVE_OSS_SUPPORT */
