@@ -17,18 +17,16 @@
 
 #include "config.h"
 
-#include <QPushButton>
-#include <QCheckBox>
-#include <QGroupBox>
-#include <QLabel>
-#include <QTreeView>
-#include <QPixmap>
-#include <QProgressBar>
-#include <QSlider>
-#include <QTabWidget>
-#include <QTreeWidget>
-#include <QTreeWidgetItem>
-#include <QStatusBar>
+#include <QtCore/QLatin1Char>
+#include <QtGui/QCheckBox>
+#include <QtGui/QGroupBox>
+#include <QtGui/QLabel>
+#include <QtGui/QTreeView>
+#include <QtGui/QPixmap>
+#include <QtGui/QProgressBar>
+#include <QtGui/QSlider>
+#include <QtGui/QTreeWidget>
+#include <QtGui/QTreeWidgetItem>
 
 #include <kcombobox.h>
 #include <kglobal.h>
@@ -38,14 +36,16 @@
 #include <kpushbutton.h>
 #include <knuminput.h>
 #include <kstatusbar.h>
+#include <ktabwidget.h>
 #include <ktoolinvocation.h>
 
-#include "libkwave/CompressionType.h"
+#include "libkwave/Compression.h"
 #include "libkwave/SampleFormat.h"
+#include "libkwave/String.h"
 #include "libkwave/Utils.h"
 
+#include "libgui/FileDialog.h"
 #include "libgui/HMSTimeWidget.h"
-#include "libgui/KwaveFileDialog.h"
 
 #include "LevelMeter.h"
 #include "RecordDevice.h"
@@ -98,11 +98,11 @@ enum {
 };
 
 //***************************************************************************
-RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
-                           RecordController *controller)
+Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
+                                  Kwave::RecordController *controller)
     :QDialog(parent), Ui::RecordDlg(), m_methods_map(),
      m_file_filter(), m_devices_list_map(),
-     m_state(REC_EMPTY), m_params(),
+     m_state(Kwave::REC_EMPTY), m_params(),
      m_supported_resolutions(), m_buffer_progress_count(0),
      m_buffer_progress_total(0), m_buffer_progress_timer(this),
      m_record_enabled(true), m_samples_recorded(0),
@@ -115,8 +115,8 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
 
     /* set the icons of the record control buttons */
     KIconLoader icon_loader;
-    btNew->setIcon(   KIcon(icon_loader.loadIcon(
-	              "document-new", KIconLoader::Toolbar)));
+    btNew->setIcon(   KIcon(icon_loader.loadIcon(_("document-new"),
+	              KIconLoader::Toolbar)));
     btStop->setIcon(  KIcon(QPixmap(xpm_stop)));
     btPause->setIcon( KIcon(QPixmap(xpm_pause)));
     btRecord->setIcon(KIcon(QPixmap(xpm_krec_record)));
@@ -234,14 +234,14 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     connect(sbFormatTracks, SIGNAL(valueChanged(int)),
             this, SLOT(tracksChanged(int)));
 
-    connect(cbFormatCompression, SIGNAL(activated(const QString &)),
-            this, SLOT(compressionChanged(const QString&)));
+    connect(cbFormatCompression, SIGNAL(activated(int)),
+            this, SLOT(compressionChanged(int)));
 
     connect(sbFormatResolution, SIGNAL(valueChanged(int)),
             this, SLOT(bitsPerSampleChanged(int)));
 
-    connect(cbFormatSampleFormat, SIGNAL(activated(const QString &)),
-            this, SLOT(sampleFormatChanged(const QString &)));
+    connect(cbFormatSampleFormat, SIGNAL(activated(int)),
+            this, SLOT(sampleFormatChanged(int)));
 
     // connect the buttons to the record controller
     connect(btNew, SIGNAL(clicked()),
@@ -258,45 +258,45 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     connect(this, SIGNAL(accepted()), controller, SLOT(actionStop()));
 
     // connect the notifications/commands of the record controller
-    connect(controller, SIGNAL(stateChanged(RecordState)),
-            this, SLOT(setState(RecordState )));
+    connect(controller, SIGNAL(stateChanged(Kwave::RecordState)),
+            this, SLOT(setState(Kwave::RecordState )));
 
     // timer for updating the buffer progress bar
     connect(&m_buffer_progress_timer, SIGNAL(timeout()),
             this, SLOT(updateBufferProgressBar()));
 
     // help button
-    connect(btHelp, SIGNAL(clicked()),
+    connect(buttonBox->button(QDialogButtonBox::Help), SIGNAL(clicked()),
             this,   SLOT(invokeHelp()));
 
     // status bar
-    m_state_icon_widget = new StatusWidget(this);
+    m_state_icon_widget = new Kwave::StatusWidget(this);
     Q_ASSERT(m_state_icon_widget);
     if (!m_state_icon_widget) return;
 
     m_state_icon_widget->setFixedSize(16, 16);
     lbl_state->addWidget(m_state_icon_widget);
 
-    lbl_state->insertItem(" ", ID_STATE, 100);
+    lbl_state->insertItem(_(" "), ID_STATE, 100);
     lbl_state->setItemAlignment(ID_STATE,
                                 Qt::AlignLeft | Qt::AlignVCenter);
-    lbl_state->insertItem(" ", ID_TIME);
+    lbl_state->insertItem(_(" "), ID_TIME);
     lbl_state->setItemAlignment(ID_TIME,
                                 Qt::AlignLeft | Qt::AlignVCenter);
-    lbl_state->insertItem(" ", ID_SAMPLE_RATE);
+    lbl_state->insertItem(_(" "), ID_SAMPLE_RATE);
     lbl_state->setItemAlignment(ID_SAMPLE_RATE,
                                 Qt::AlignRight | Qt::AlignVCenter);
-    lbl_state->insertItem(" ", ID_BITS_PER_SAMPLE);
+    lbl_state->insertItem(_(" "), ID_BITS_PER_SAMPLE);
     lbl_state->setItemAlignment(ID_BITS_PER_SAMPLE,
                                 Qt::AlignRight | Qt::AlignVCenter);
-    lbl_state->insertItem(" ", ID_TRACKS);
+    lbl_state->insertItem(_(" "), ID_TRACKS);
     lbl_state->setItemAlignment(ID_TRACKS,
                                 Qt::AlignRight | Qt::AlignVCenter);
 
     m_state_icon_widget->setFixedSize(16, lbl_state->childrenRect().height());
 
     // set the initial state of the dialog to "Reset/Empty"
-    setState(REC_EMPTY);
+    setState(Kwave::REC_EMPTY);
 
     // disable the "level" tab, it is not implemented yet
     tabRecord->setCurrentIndex(1);
@@ -304,22 +304,24 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     tabRecord->setCurrentIndex(0);
     if (page) delete page;
 
+    // set the focus onto the "Record" button
+    btRecord->setFocus();
 }
 
 //***************************************************************************
-RecordDialog::~RecordDialog()
+Kwave::RecordDialog::~RecordDialog()
 {
     updateBufferState(0,0);
 }
 
 //***************************************************************************
-RecordParams &RecordDialog::params()
+Kwave::RecordParams &Kwave::RecordDialog::params()
 {
     return m_params;
 }
 
 //***************************************************************************
-void RecordDialog::setMethod(record_method_t method)
+void Kwave::RecordDialog::setMethod(Kwave::record_method_t method)
 {
     m_params.method = method;
     cbMethod->setCurrentIndex(m_methods_map.findFromData(
@@ -327,15 +329,15 @@ void RecordDialog::setMethod(record_method_t method)
 }
 
 //***************************************************************************
-void RecordDialog::methodSelected(int index)
+void Kwave::RecordDialog::methodSelected(int index)
 {
-    record_method_t method = m_methods_map.data(index);
+    Kwave::record_method_t method = m_methods_map.data(index);
 //     qDebug("RecordDialog::methodSelected(%d) - %d", index, (int)method);
 
-    Q_ASSERT(method > RECORD_NONE);
-    Q_ASSERT(method < RECORD_INVALID);
-    if (method <= RECORD_NONE) return;
-    if (method >= RECORD_INVALID) return;
+    Q_ASSERT(method > Kwave::RECORD_NONE);
+    Q_ASSERT(method < Kwave::RECORD_INVALID);
+    if (method <= Kwave::RECORD_NONE) return;
+    if (method >= Kwave::RECORD_INVALID) return;
 
     if (method != m_params.method) {
 	setMethod(method);
@@ -344,7 +346,7 @@ void RecordDialog::methodSelected(int index)
 }
 
 //***************************************************************************
-void RecordDialog::setSupportedDevices(QStringList devices)
+void Kwave::RecordDialog::setSupportedDevices(QStringList devices)
 {
 //     qDebug("RecordDialog::setSupportedDevices(QStringList devices)");
     Q_ASSERT(cbDevice);
@@ -362,15 +364,15 @@ void RecordDialog::setSupportedDevices(QStringList devices)
     cbDevice->clear();
     listDevices->clear();
 
-    if (devices.contains("#EDIT#")) {
-	devices.removeAll("#EDIT#");
+    if (devices.contains(_("#EDIT#"))) {
+	devices.removeAll(_("#EDIT#"));
 	cbDevice->setEditable(true);
     } else {
 	cbDevice->setEditable(false);
     }
 
-    if (devices.contains("#SELECT#")) {
-	devices.removeAll("#SELECT#");
+    if (devices.contains(_("#SELECT#"))) {
+	devices.removeAll(_("#SELECT#"));
 	btSourceSelect->setEnabled(true);
 	btSourceSelect->show();
     } else {
@@ -378,9 +380,9 @@ void RecordDialog::setSupportedDevices(QStringList devices)
 	btSourceSelect->hide();
     }
 
-    if (devices.contains("#TREE#")) {
+    if (devices.contains(_("#TREE#"))) {
 	// treeview mode
-	devices.removeAll("#TREE#");
+	devices.removeAll(_("#TREE#"));
 	listDevices->setEnabled(true);
 	cbDevice->setEnabled(false);
 	cbDevice->hide();
@@ -390,13 +392,13 @@ void RecordDialog::setSupportedDevices(QStringList devices)
 	foreach (QString dev_id, devices) {
 	    QTreeWidgetItem *parent = 0;
 
-	    QStringList list = dev_id.split("||", QString::KeepEmptyParts);
+	    QStringList list = dev_id.split(_("||"), QString::KeepEmptyParts);
 	    foreach (QString token, list) {
 		QTreeWidgetItem *item = 0;
 
 		// split the icon name from the token
 		QString icon_name;
-		int pos = token.indexOf('|');
+		int pos = token.indexOf(QLatin1Char('|'));
 		if (pos > 0) {
 		    icon_name = token.mid(pos+1);
 		    token     = token.left(pos);
@@ -405,7 +407,7 @@ void RecordDialog::setSupportedDevices(QStringList devices)
 		// find the first item with the same text
 		// and the same root
 		if (parent) {
-		    for (int i=0; i < parent->childCount(); i++) {
+		    for (int i = 0; i < parent->childCount(); i++) {
 			QTreeWidgetItem *node = parent->child(i);
 			if (node && node->text(0) == token) {
 			    item = node;
@@ -448,7 +450,7 @@ void RecordDialog::setSupportedDevices(QStringList devices)
 		    }
 		}
 
-		if (icon_name.length()) {
+		if (item && icon_name.length()) {
 		    QIcon icon = icon_loader.loadIcon(
 			icon_name, KIconLoader::User);
 		    item->setIcon(0, icon);
@@ -488,8 +490,8 @@ void RecordDialog::setSupportedDevices(QStringList devices)
 }
 
 //***************************************************************************
-void RecordDialog::listEntrySelected(QTreeWidgetItem *current,
-                                       QTreeWidgetItem *previous)
+void Kwave::RecordDialog::listEntrySelected(QTreeWidgetItem *current,
+                                            QTreeWidgetItem *previous)
 {
     Q_ASSERT(listDevices);
     Q_UNUSED(previous);
@@ -500,21 +502,21 @@ void RecordDialog::listEntrySelected(QTreeWidgetItem *current,
 }
 
 //***************************************************************************
-void RecordDialog::listItemExpanded(QTreeWidgetItem *item)
+void Kwave::RecordDialog::listItemExpanded(QTreeWidgetItem *item)
 {
     Q_UNUSED(item);
     updateListSelection();
 }
 
 //***************************************************************************
-void RecordDialog::updateListSelection()
+void Kwave::RecordDialog::updateListSelection()
 {
     // set the current device again, otherwise nothing will be selected
     setDevice(m_params.device_name);
 }
 
 //***************************************************************************
-void RecordDialog::setDevice(const QString &device)
+void Kwave::RecordDialog::setDevice(const QString &device)
 {
     Q_ASSERT(cbDevice);
     Q_ASSERT(listDevices);
@@ -551,7 +553,7 @@ void RecordDialog::setDevice(const QString &device)
 }
 
 //***************************************************************************
-void RecordDialog::sourceBufferCountChanged(int value)
+void Kwave::RecordDialog::sourceBufferCountChanged(int value)
 {
     Q_ASSERT(value >=  4);
     Q_ASSERT(value <= 64);
@@ -564,7 +566,7 @@ void RecordDialog::sourceBufferCountChanged(int value)
 }
 
 //***************************************************************************
-void RecordDialog::sourceBufferSizeChanged(int value)
+void Kwave::RecordDialog::sourceBufferSizeChanged(int value)
 {
     Q_ASSERT(value >= 10);
     Q_ASSERT(value <= 18);
@@ -582,31 +584,31 @@ void RecordDialog::sourceBufferSizeChanged(int value)
 }
 
 //***************************************************************************
-void RecordDialog::setFileFilter(const QString &filter)
+void Kwave::RecordDialog::setFileFilter(const QString &filter)
 {
     m_file_filter = filter;
     if (btSourceSelect) btSourceSelect->setEnabled(m_file_filter.length());
 }
 
 //***************************************************************************
-void RecordDialog::selectRecordDevice()
+void Kwave::RecordDialog::selectRecordDevice()
 {
     if (!m_enable_setDevice) return;
 
     QString filter;
-    filter += QString("dsp*|") + i18n("OSS record device (dsp*)");
-    filter += QString("\nadsp*|") + i18n("ALSA record device (adsp*)");
-    filter += QString("\n*|") + i18n("Any device (*)");
+    filter += _("dsp*|")    + i18n("OSS record device (dsp*)");
+    filter += _("\nadsp*|") + i18n("ALSA record device (adsp*)");
+    filter += _("\n*|")     + i18n("Any device (*)");
 
-    KwaveFileDialog dlg("kfiledialog:///kwave_record_device", filter, this,
-	true, "file:/dev");
+    Kwave::FileDialog dlg(_("kfiledialog:///kwave_record_device"),
+	filter, this, true, _("file:/dev"));
     dlg.setKeepLocation(true);
     dlg.setOperationMode(KFileDialog::Opening);
     dlg.setCaption(i18n("Select Record Device"));
-    if (m_params.device_name[0] != '[')
-        dlg.setUrl(KUrl("file:"+m_params.device_name));
+    if (!m_params.device_name.startsWith(_("#")))
+        dlg.setUrl(KUrl(_("file:") + m_params.device_name));
     else
-        dlg.setUrl(KUrl("file:/dev/*"));
+        dlg.setUrl(KUrl(_("file:/dev/*")));
     if (dlg.exec() != QDialog::Accepted) return;
 
     // selected new device
@@ -615,7 +617,7 @@ void RecordDialog::selectRecordDevice()
 }
 
 //***************************************************************************
-QString RecordDialog::rate2string(double rate) const
+QString Kwave::RecordDialog::rate2string(double rate) const
 {
     const KLocale *locale = KGlobal::locale();
     Q_ASSERT(locale);
@@ -633,7 +635,7 @@ QString RecordDialog::rate2string(double rate) const
     s.remove(tsep);
 
     // remove trailing zeroes
-    while (s.endsWith("0")) s.remove(s.length()-1, 1);
+    while (s.endsWith(_("0"))) s.remove(s.length()-1, 1);
 
     // remove decimal point if necessary
     if (s.endsWith(dot)) s.remove(s.length()-1, 1);
@@ -642,7 +644,7 @@ QString RecordDialog::rate2string(double rate) const
 }
 
 //***************************************************************************
-double RecordDialog::string2rate(const QString &rate) const
+double Kwave::RecordDialog::string2rate(const QString &rate) const
 {
     const KLocale *locale = KGlobal::locale();
     Q_ASSERT(locale);
@@ -660,7 +662,8 @@ double RecordDialog::string2rate(const QString &rate) const
 }
 
 //***************************************************************************
-void RecordDialog::setSupportedTracks(unsigned int min, unsigned int max)
+void Kwave::RecordDialog::setSupportedTracks(unsigned int min,
+                                             unsigned int max)
 {
     Q_ASSERT(sbFormatTracks);
     if (!sbFormatTracks) return;
@@ -682,7 +685,7 @@ void RecordDialog::setSupportedTracks(unsigned int min, unsigned int max)
 }
 
 //***************************************************************************
-void RecordDialog::setTracks(unsigned int tracks)
+void Kwave::RecordDialog::setTracks(unsigned int tracks)
 {
 //     qDebug("+++ RecordDialog::setTracks(%u)", tracks);
     Q_ASSERT(sbFormatTracks);
@@ -703,14 +706,14 @@ void RecordDialog::setTracks(unsigned int tracks)
 	    tracks_str = i18n("Quadro");
 	    break;
 	default:
-	    tracks_str = "";
+	    tracks_str = _("");
     }
 
     if (tracks_str.length()) {
-	lblTracksVerbose->setText("("+tracks_str+")");
+	lblTracksVerbose->setText(_("(") + tracks_str + _(")"));
 	lbl_state->changeItem(tracks_str, ID_TRACKS);
     } else {
-	lblTracksVerbose->setText("");
+	lblTracksVerbose->setText(_(""));
 	lbl_state->changeItem(i18n("%1 tracks", tracks), ID_TRACKS);
     }
 
@@ -718,7 +721,7 @@ void RecordDialog::setTracks(unsigned int tracks)
 }
 
 //***************************************************************************
-void RecordDialog::tracksChanged(int tracks)
+void Kwave::RecordDialog::tracksChanged(int tracks)
 {
     if (tracks < 1) return; // no device
     if (tracks == static_cast<int>(m_params.tracks)) return;
@@ -728,7 +731,7 @@ void RecordDialog::tracksChanged(int tracks)
 }
 
 //***************************************************************************
-void RecordDialog::setSupportedSampleRates(const QList<double> &rates)
+void Kwave::RecordDialog::setSupportedSampleRates(const QList<double> &rates)
 {
     Q_ASSERT(cbFormatSampleRate);
     if (!cbFormatSampleRate) return;
@@ -749,7 +752,7 @@ void RecordDialog::setSupportedSampleRates(const QList<double> &rates)
 }
 
 //***************************************************************************
-void RecordDialog::setSampleRate(double new_rate)
+void Kwave::RecordDialog::setSampleRate(double new_rate)
 {
     Q_ASSERT(cbFormatSampleRate);
     if (!cbFormatSampleRate) return;
@@ -770,7 +773,7 @@ void RecordDialog::setSampleRate(double new_rate)
 }
 
 //***************************************************************************
-void RecordDialog::sampleRateChanged(const QString &rate)
+void Kwave::RecordDialog::sampleRateChanged(const QString &rate)
 {
     if (!rate.length()) return; // no rate selected, combo box clear
     double sample_rate = string2rate(rate);
@@ -781,21 +784,21 @@ void RecordDialog::sampleRateChanged(const QString &rate)
 }
 
 //***************************************************************************
-void RecordDialog::setSupportedCompressions(const QList<int> &comps)
+void Kwave::RecordDialog::setSupportedCompressions(const QList<int> &comps)
 {
     Q_ASSERT(cbFormatCompression);
     if (!cbFormatCompression) return;
 
     cbFormatCompression->clear();
-    CompressionType types;
 
     if (comps.isEmpty()) {
 	// no compressions -> add "none" manually
-	cbFormatCompression->addItem(types.name(0));
+	const Kwave::Compression comp(Kwave::Compression::NONE);
+	cbFormatCompression->addItem(comp.name());
     } else {
 	foreach (int c, comps) {
-	    int index = types.findFromData(c);
-	    cbFormatCompression->addItem(types.name(index));
+	    const Kwave::Compression comp(c);
+	    cbFormatCompression->addItem(comp.name(), comp.toInt());
 	}
     }
 
@@ -804,7 +807,7 @@ void RecordDialog::setSupportedCompressions(const QList<int> &comps)
 }
 
 //***************************************************************************
-void RecordDialog::setCompression(int compression)
+void Kwave::RecordDialog::setCompression(int compression)
 {
     Q_ASSERT(cbFormatCompression);
     if (!cbFormatCompression) return;
@@ -818,24 +821,20 @@ void RecordDialog::setCompression(int compression)
 	m_params.compression = compression;
     }
 
-    CompressionType types;
-    int index = types.findFromData(compression);
-    cbFormatCompression->setCurrentItem(types.name(index), true);
+    const Kwave::Compression comp(compression);
+    cbFormatCompression->setCurrentItem(comp.name(), true);
 }
 
 //***************************************************************************
-void RecordDialog::compressionChanged(const QString &name)
+void Kwave::RecordDialog::compressionChanged(int index)
 {
-    CompressionType types;
-    int index = types.findFromName(name);
-    int compression = types.data(index);
-    if (compression == m_params.compression) return;
-
-    emit sigCompressionChanged(compression);
+    int compression = cbFormatCompression->itemData(index).toInt();
+    if (compression != m_params.compression)
+	emit sigCompressionChanged(compression);
 }
 
 //***************************************************************************
-void RecordDialog::setSupportedBits(const QList<unsigned int> &bits)
+void Kwave::RecordDialog::setSupportedBits(const QList<unsigned int> &bits)
 {
     Q_ASSERT(sbFormatResolution);
     if (!sbFormatResolution) return;
@@ -851,7 +850,7 @@ void RecordDialog::setSupportedBits(const QList<unsigned int> &bits)
 }
 
 //***************************************************************************
-void RecordDialog::setBitsPerSample(unsigned int bits)
+void Kwave::RecordDialog::setBitsPerSample(unsigned int bits)
 {
     Q_ASSERT(sbFormatResolution);
     if (!sbFormatResolution) return;
@@ -869,7 +868,7 @@ void RecordDialog::setBitsPerSample(unsigned int bits)
 }
 
 //***************************************************************************
-void RecordDialog::bitsPerSampleChanged(int bits)
+void Kwave::RecordDialog::bitsPerSampleChanged(int bits)
 {
     if (bits < 1) return; // no device
     int last = m_params.bits_per_sample;
@@ -906,18 +905,20 @@ void RecordDialog::bitsPerSampleChanged(int bits)
 }
 
 //***************************************************************************
-void RecordDialog::setSupportedSampleFormats(
-    const QList<SampleFormat> &formats)
+void Kwave::RecordDialog::setSupportedSampleFormats(
+    const QList<Kwave::SampleFormat> &formats)
 {
     Q_ASSERT(cbFormatSampleFormat);
     if (!cbFormatSampleFormat) return;
 
     cbFormatSampleFormat->clear();
-    SampleFormat::Map types;
-
-    foreach (SampleFormat format, formats) {
+    Kwave::SampleFormat::Map types;
+    foreach (Kwave::SampleFormat format, formats) {
 	int index = types.findFromData(format);
-	cbFormatSampleFormat->addItem(types.name(index));
+	cbFormatSampleFormat->addItem(
+	    types.description(index, true),
+	    format.toInt()
+	);
     }
 
     bool have_choice = (cbFormatSampleFormat->count() > 1);
@@ -925,12 +926,12 @@ void RecordDialog::setSupportedSampleFormats(
 }
 
 //***************************************************************************
-void RecordDialog::setSampleFormat(SampleFormat sample_format)
+void Kwave::RecordDialog::setSampleFormat(Kwave::SampleFormat sample_format)
 {
     Q_ASSERT(cbFormatSampleFormat);
     if (!cbFormatSampleFormat) return;
 
-    if (sample_format == SampleFormat::Unknown) {
+    if (sample_format == Kwave::SampleFormat::Unknown) {
 	cbFormatSampleFormat->setEnabled(false);
 	return;
     } else {
@@ -939,25 +940,26 @@ void RecordDialog::setSampleFormat(SampleFormat sample_format)
 	m_params.sample_format = sample_format;
     }
 
-    SampleFormat::Map types;
-    int index = types.findFromData(sample_format);
-    cbFormatSampleFormat->setCurrentItem(
-        (sample_format != -1) ? types.name(index) : "", true);
+    int cb_index = cbFormatSampleFormat->findData(sample_format.toInt());
+    cbFormatSampleFormat->setCurrentIndex(cb_index);
 }
 
 //***************************************************************************
-void RecordDialog::sampleFormatChanged(const QString &name)
+void Kwave::RecordDialog::sampleFormatChanged(int index)
 {
-    SampleFormat::Map types;
-    int index = types.findFromName(name);
-    SampleFormat format = types.data(index);
+    Q_ASSERT(cbFormatSampleFormat);
+    if (!cbFormatSampleFormat) return;
+
+    Kwave::SampleFormat format;
+    format.fromInt(cbFormatSampleFormat->itemData(index).toInt());
+
     if (format == m_params.sample_format) return;
 
     emit sigSampleFormatChanged(format);
 }
 
 //***************************************************************************
-void RecordDialog::setState(RecordState state)
+void Kwave::RecordDialog::setState(Kwave::RecordState state)
 {
     bool enable_new = false;
     bool enable_pause = false;
@@ -965,13 +967,13 @@ void RecordDialog::setState(RecordState state)
     bool enable_record = false;
     bool enable_settings = false;
     bool enable_trigger = false;
-    QString state_text = "";
+    QString state_text = _("");
     QVector<QPixmap> pixmaps;
     unsigned int animation_time = 500;
 
     m_state = state;
     switch (state) {
-	case REC_UNINITIALIZED:
+	case Kwave::REC_UNINITIALIZED:
 	    state_text = i18n("Please check the source device settings...");
 	    enable_new      = true;
 	    enable_pause    = false;
@@ -981,9 +983,9 @@ void RecordDialog::setState(RecordState state)
 	    enable_trigger  = true;
 	    pixmaps.push_back(QPixmap(stop_hand_xpm));
 	    pixmaps.push_back(QPixmap(ledred_xpm));
-	    lbl_state->changeItem("", ID_TIME);
+	    lbl_state->changeItem(_(""), ID_TIME);
 	    break;
-	case REC_EMPTY:
+	case Kwave::REC_EMPTY:
 	    state_text = i18n("(empty)");
 	    enable_new      = true;
 	    enable_pause    = false;
@@ -992,9 +994,9 @@ void RecordDialog::setState(RecordState state)
 	    enable_settings = true;
 	    enable_trigger  = true;
 	    pixmaps.push_back(QPixmap(ledgreen_xpm));
-	    lbl_state->changeItem("", ID_TIME);
+	    lbl_state->changeItem(_(""), ID_TIME);
 	    break;
-	case REC_BUFFERING:
+	case Kwave::REC_BUFFERING:
 	    state_text = i18n("Buffering...");
 	    enable_new      = true; /* throw away current FIFO content */
 	    enable_pause    = false;
@@ -1005,7 +1007,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledgreen_xpm));
 	    pixmaps.push_back(QPixmap(ledlightgreen_xpm));
 	    break;
-	case REC_PRERECORDING:
+	case Kwave::REC_PRERECORDING:
 	    state_text = i18n("Prerecording...");
 	    enable_new      = false;
 	    enable_pause    = false;
@@ -1016,7 +1018,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledgreen_xpm));
 	    pixmaps.push_back(QPixmap(ledlightgreen_xpm));
 	    break;
-	case REC_WAITING_FOR_TRIGGER:
+	case Kwave::REC_WAITING_FOR_TRIGGER:
 	    state_text = i18n("Waiting for trigger...");
 	    enable_new      = false;
 	    enable_pause    = false;
@@ -1027,7 +1029,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledgreen_xpm));
 	    pixmaps.push_back(QPixmap(ledlightgreen_xpm));
 	    break;
-	case REC_RECORDING:
+	case Kwave::REC_RECORDING:
 	    state_text = i18n("Recording...");
 	    enable_new      = false;
 	    enable_pause    = true;
@@ -1045,7 +1047,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(walk_r8_xpm));
 	    animation_time = 100;
 	    break;
-	case REC_PAUSED:
+	case Kwave::REC_PAUSED:
 	    state_text = i18n("Paused");
 	    enable_new      = true; /* start again */
 	    enable_pause    = true; /* used for "continue" */
@@ -1056,7 +1058,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledgreen_xpm));
 	    pixmaps.push_back(QPixmap(ledyellow_xpm));
 	    break;
-	case REC_DONE:
+	case Kwave::REC_DONE:
 	    state_text = i18n("Done");
 	    enable_new      = true;
 	    enable_pause    = false;
@@ -1104,7 +1106,8 @@ void RecordDialog::setState(RecordState state)
 }
 
 //***************************************************************************
-void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
+void Kwave::RecordDialog::updateBufferState(unsigned int count,
+                                            unsigned int total)
 {
     Q_ASSERT(progress_bar);
     if (!progress_bar) return;
@@ -1130,14 +1133,14 @@ void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
     // update recording time
     QString txt;
     switch (m_state) {
-	case REC_UNINITIALIZED:
-	case REC_EMPTY:
-	case REC_BUFFERING:
-	case REC_PRERECORDING:
-	    txt = "";
+	case Kwave::REC_UNINITIALIZED:
+	case Kwave::REC_EMPTY:
+	case Kwave::REC_BUFFERING:
+	case Kwave::REC_PRERECORDING:
+	    txt = _("");
 	    break;
-	case REC_WAITING_FOR_TRIGGER: {
-	    txt = "";
+	case Kwave::REC_WAITING_FOR_TRIGGER: {
+	    txt = _("");
 	    QString state_text;
 	    QDateTime now     = QDateTime::currentDateTime();
 	    QDateTime t_start = m_params.start_time;
@@ -1153,12 +1156,12 @@ void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
 		int d = h / 24;
 		h %= 24;
 
-		QString days    =
-		    (d) ? i18np("one day ",    "%1 days ",    d) : "";
-		QString hours   =
-		    (h) ? i18np("one hour ",   "%1 hours ",   h) : "";
-		QString minutes =
-		    (m) ? i18np("one minute ", "%1 minutes ", m) : "";
+		QString days    = (d) ?
+		    i18np("one day ",    "%1 days ",    d) : _("");
+		QString hours   = (h) ?
+		    i18np("one hour ",   "%1 hours ",   h) : _("");
+		QString minutes = (m) ?
+		    i18np("one minute ", "%1 minutes ", m) : _("");
 		QString seconds =
 		    (d | h | m) ?
 		    i18np("and %1 second", "and %1 seconds", s) :
@@ -1176,18 +1179,19 @@ void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
 
 	    break;
 	}
-	case REC_RECORDING:
-	case REC_PAUSED:
-	case REC_DONE: {
+	case Kwave::REC_RECORDING:
+	case Kwave::REC_PAUSED:
+	case Kwave::REC_DONE: {
 	    if (m_samples_recorded > 1) {
 		double rate = m_params.sample_rate;
 		double ms = (rate) ?
 		    ((static_cast<double>(m_samples_recorded) / rate) * 1E3)
 		    : 0;
-		txt = " " + i18n("Length: %1", Kwave::ms2string(ms)) +
-		    " " + i18n("(%1 samples)",
-		    Kwave::dottedNumber(m_samples_recorded));
-	    } else txt = "";
+		txt = _(" ") +
+		    i18n("Length: %1", Kwave::ms2string(ms)) +
+		    _(" ") + i18n("(%1 samples)",
+		    KGlobal::locale()->formatLong(m_samples_recorded));
+	    } else txt = _("");
 	    break;
 	}
     }
@@ -1195,27 +1199,27 @@ void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
 }
 
 //***************************************************************************
-void RecordDialog::preRecordingChecked(bool enabled)
+void Kwave::RecordDialog::preRecordingChecked(bool enabled)
 {
     m_params.pre_record_enabled = enabled;
     emit sigPreRecordingChanged(enabled);
 }
 
 //***************************************************************************
-void RecordDialog::preRecordingTimeChanged(int time)
+void Kwave::RecordDialog::preRecordingTimeChanged(int time)
 {
     m_params.pre_record_time = time;
 }
 
 //***************************************************************************
-void RecordDialog::recordTimeChecked(bool limited)
+void Kwave::RecordDialog::recordTimeChecked(bool limited)
 {
     m_params.record_time_limited = limited;
     emit sigRecordTimeChanged(limited ? sbRecordTime->value() : -1);
 }
 
 //***************************************************************************
-void RecordDialog::recordTimeChanged(int limit)
+void Kwave::RecordDialog::recordTimeChanged(int limit)
 {
     m_params.record_time = limit;
     emit sigRecordTimeChanged(chkRecordTime->isChecked() ?
@@ -1224,14 +1228,14 @@ void RecordDialog::recordTimeChanged(int limit)
 }
 
 //***************************************************************************
-void RecordDialog::startTimeChecked(bool enabled)
+void Kwave::RecordDialog::startTimeChecked(bool enabled)
 {
     m_params.start_time_enabled = enabled;
     emit sigTriggerChanged(enabled || m_params.record_trigger_enabled);
 }
 
 //***************************************************************************
-void RecordDialog::startTimeChanged(const QDateTime &datetime)
+void Kwave::RecordDialog::startTimeChanged(const QDateTime &datetime)
 {
     m_params.start_time = datetime;
 
@@ -1242,20 +1246,20 @@ void RecordDialog::startTimeChanged(const QDateTime &datetime)
 }
 
 //***************************************************************************
-void RecordDialog::triggerChecked(bool enabled)
+void Kwave::RecordDialog::triggerChecked(bool enabled)
 {
     m_params.record_trigger_enabled = enabled;
     emit sigTriggerChanged(enabled || m_params.start_time_enabled);
 }
 
 //***************************************************************************
-void RecordDialog::triggerChanged(int trigger)
+void Kwave::RecordDialog::triggerChanged(int trigger)
 {
     m_params.record_trigger = trigger;
 }
 
 //***************************************************************************
-void RecordDialog::displayLevelMeterChecked(bool enabled)
+void Kwave::RecordDialog::displayLevelMeterChecked(bool enabled)
 {
     m_params.display_level_meter = enabled;
 
@@ -1274,7 +1278,7 @@ void RecordDialog::displayLevelMeterChecked(bool enabled)
 }
 
 //***************************************************************************
-void RecordDialog::updateBufferProgressBar()
+void Kwave::RecordDialog::updateBufferProgressBar()
 {
     unsigned int count = m_buffer_progress_count;
     unsigned int total = m_buffer_progress_total;
@@ -1296,8 +1300,8 @@ void RecordDialog::updateBufferProgressBar()
 }
 
 //***************************************************************************
-void RecordDialog::updateEffects(unsigned int track,
-                                 Kwave::SampleArray &buffer)
+void Kwave::RecordDialog::updateEffects(unsigned int track,
+                                        Kwave::SampleArray &buffer)
 {
     if (!buffer.size()) return;
 
@@ -1310,7 +1314,7 @@ void RecordDialog::updateEffects(unsigned int track,
 }
 
 //***************************************************************************
-void RecordDialog::setRecordedSamples(unsigned int samples_recorded)
+void Kwave::RecordDialog::setRecordedSamples(unsigned int samples_recorded)
 {
     // if (!m_params.record_time_limited) return; // not of interest
     m_samples_recorded = samples_recorded;
@@ -1318,7 +1322,7 @@ void RecordDialog::setRecordedSamples(unsigned int samples_recorded)
 }
 
 //***************************************************************************
-void RecordDialog::updateRecordButton()
+void Kwave::RecordDialog::updateRecordButton()
 {
     bool old_enable = btRecord->isEnabled();
     bool new_enable;
@@ -1332,19 +1336,19 @@ void RecordDialog::updateRecordButton()
 }
 
 //***************************************************************************
-void RecordDialog::invokeHelp()
+void Kwave::RecordDialog::invokeHelp()
 {
-    KToolInvocation::invokeHelp("recording");
+    KToolInvocation::invokeHelp(_("recording"));
 }
 
 //***************************************************************************
-void RecordDialog::message(const QString &message)
+void Kwave::RecordDialog::message(const QString &message)
 {
     if (lbl_state) lbl_state->showMessage(message, 3000);
 }
 
 //***************************************************************************
-void RecordDialog::showDevicePage()
+void Kwave::RecordDialog::showDevicePage()
 {
     if (tabRecord) tabRecord->setCurrentIndex(2);
 }
