@@ -23,14 +23,15 @@
 #include <threadweaver/ThreadWeaver.h>
 #include <threadweaver/DebuggingAids.h>
 
-#include <QList>
-#include <QSharedPointer>
-#include <QStringList>
-#include <QThread>
+#include <QtCore/QList>
+#include <QtCore/QSharedPointer>
+#include <QtCore/QStringList>
+#include <QtCore/QThread>
 
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/PluginManager.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 #include "libkwave/Utils.h"
 #include "libkwave/Writer.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
@@ -40,67 +41,70 @@
 #include "ReversePlugin.h"
 #include "UndoReverseAction.h"
 
-KWAVE_PLUGIN(ReversePlugin, "reverse", "2.1",
+KWAVE_PLUGIN(Kwave::ReversePlugin, "reverse", "2.3",
              I18N_NOOP("Reverse"), "Thomas Eschenbacher");
 
 //***************************************************************************
-class ReverseJob: public ThreadWeaver::Job
+namespace Kwave
 {
-public:
+    class ReverseJob: public ThreadWeaver::Job
+    {
+    public:
 
-    /**
-     * Constructor
-     */
-    ReverseJob(
-	SignalManager &manager, unsigned int track,
-	sample_index_t first, sample_index_t last, unsigned int block_size,
-	SampleReader *src_a, SampleReader *src_b
-    );
+	/**
+	 * Constructor
+	 */
+	ReverseJob(
+	    Kwave::SignalManager &manager, unsigned int track,
+	    sample_index_t first, sample_index_t last, unsigned int block_size,
+	    Kwave::SampleReader *src_a, Kwave::SampleReader *src_b
+	);
 
-    /** Destructor */
-    virtual ~ReverseJob();
+	/** Destructor */
+	virtual ~ReverseJob();
 
-    /**
-    * overloaded 'run' function that runns goOn() in the context
-    * of the worker thread.
-    */
-    virtual void run();
+	/**
+	 * overloaded 'run' function that runns goOn() in the context
+	 * of the worker thread.
+	 */
+	virtual void run();
 
-private:
+    private:
 
-    /** reverses the content of an array of samples */
-    void reverse(Kwave::SampleArray &buffer);
+	/** reverses the content of an array of samples */
+	void reverse(Kwave::SampleArray &buffer);
 
-private:
+    private:
 
-    /** signal manager, for opening a sample writer */
-    SignalManager &m_manager;
+	/** signal manager, for opening a sample writer */
+	Kwave::SignalManager &m_manager;
 
-    /** index of the track */
-    unsigned int m_track;
+	/** index of the track */
+	unsigned int m_track;
 
-    /** first sample (from start) */
-    sample_index_t m_first;
+	/** first sample (from start) */
+	sample_index_t m_first;
 
-    /** last sample (from end) */
-    sample_index_t m_last;
+	/** last sample (from end) */
+	sample_index_t m_last;
 
-    /** block size in samples */
-    unsigned int m_block_size;
+	/** block size in samples */
+	unsigned int m_block_size;
 
-    /** reader for start of signal */
-    SampleReader *m_src_a;
+	/** reader for start of signal */
+	Kwave::SampleReader *m_src_a;
 
-    /** reader for end of signal */
-    SampleReader *m_src_b;
+	/** reader for end of signal */
+	Kwave::SampleReader *m_src_b;
 
-};
+    };
+}
 
 //***************************************************************************
-ReverseJob::ReverseJob(
-    SignalManager &manager, unsigned int track,
+Kwave::ReverseJob::ReverseJob(
+    Kwave::SignalManager &manager, unsigned int track,
     sample_index_t first, sample_index_t last, unsigned int block_size,
-    SampleReader *src_a, SampleReader *src_b)
+    Kwave::SampleReader *src_a, Kwave::SampleReader *src_b)
     :ThreadWeaver::Job(),
      m_manager(manager), m_track(track),
      m_first(first), m_last(last), m_block_size(block_size),
@@ -109,7 +113,7 @@ ReverseJob::ReverseJob(
 }
 
 //***************************************************************************
-ReverseJob::~ReverseJob()
+Kwave::ReverseJob::~ReverseJob()
 {
     int i = 0;
     while (!isFinished()) {
@@ -120,7 +124,7 @@ ReverseJob::~ReverseJob()
 }
 
 //***************************************************************************
-void ReverseJob::reverse(Kwave::SampleArray &buffer)
+void Kwave::ReverseJob::reverse(Kwave::SampleArray &buffer)
 {
     unsigned int count = buffer.size() >> 1;
     if (count <= 1) return;
@@ -135,7 +139,7 @@ void ReverseJob::reverse(Kwave::SampleArray &buffer)
 }
 
 //***************************************************************************
-void ReverseJob::run()
+void Kwave::ReverseJob::run()
 {
     sample_index_t start_a = m_first;
     sample_index_t start_b = (m_last >= m_block_size) ?
@@ -159,7 +163,7 @@ void ReverseJob::run()
 
 	// write back buffer from the end at the start
 	Kwave::Writer *dst_a = m_manager.openWriter(
-	    m_track, Overwrite,
+	    m_track, Kwave::Overwrite,
 	    start_a, start_a + m_block_size - 1);
 	Q_ASSERT(dst_a);
 	if (!dst_a) return;
@@ -169,7 +173,7 @@ void ReverseJob::run()
 
 	// write back buffer from the start at the end
 	Kwave::Writer *dst_b = m_manager.openWriter(
-	    m_track, Overwrite,
+	    m_track, Kwave::Overwrite,
 	    start_b, start_b + m_block_size - 1);
 	Q_ASSERT(dst_b);
 	if (!dst_b) return;
@@ -188,7 +192,7 @@ void ReverseJob::run()
 
 	// write back
 	Kwave::Writer *dst = m_manager.openWriter(
-	    m_track, Overwrite, m_first, m_last);
+	    m_track, Kwave::Overwrite, m_first, m_last);
 	if (!dst) return;
 	(*dst) << buffer << flush;
 	delete dst;
@@ -198,20 +202,20 @@ void ReverseJob::run()
 
 //***************************************************************************
 //***************************************************************************
-ReversePlugin::ReversePlugin(const PluginContext &context)
-    :Kwave::Plugin(context)
+Kwave::ReversePlugin::ReversePlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager)
 {
 }
 
 //***************************************************************************
-ReversePlugin::~ReversePlugin()
+Kwave::ReversePlugin::~ReversePlugin()
 {
 }
 
 //***************************************************************************
-void ReversePlugin::run(QStringList params)
+void Kwave::ReversePlugin::run(QStringList params)
 {
-    QSharedPointer<UndoTransactionGuard> undo_guard;
+    QSharedPointer<Kwave::UndoTransactionGuard> undo_guard;
 
     // get the current selection and the list of affected tracks
     QList<unsigned int> tracks;
@@ -221,22 +225,22 @@ void ReversePlugin::run(QStringList params)
     if (!length || tracks.isEmpty())
 	return;
 
-    if ((params.count() != 1) || (params.first() != "noundo")) {
+    if ((params.count() != 1) || (params.first() != _("noundo"))) {
 	// undo is enabled, create a undo guard
-	undo_guard = QSharedPointer<UndoTransactionGuard>(
-	    new UndoTransactionGuard(*this, i18n("Reverse")));
+	undo_guard = QSharedPointer<Kwave::UndoTransactionGuard>(
+	    new Kwave::UndoTransactionGuard(*this, i18n("Reverse")));
 	if (!undo_guard) return;
 
 	// try to save undo information
-	UndoAction *undo = new UndoReverseAction(manager());
+	Kwave::UndoAction *undo = new Kwave::UndoReverseAction(manager());
 	if (!undo_guard->registerUndoAction(undo))
 	    return;
 	undo->store(signalManager());
     }
 
-    MultiTrackReader source_a(Kwave::SinglePassForward,
+    Kwave::MultiTrackReader source_a(Kwave::SinglePassForward,
 	signalManager(), tracks, first, last);
-    MultiTrackReader source_b(Kwave::SinglePassReverse,
+    Kwave::MultiTrackReader source_b(Kwave::SinglePassReverse,
 	signalManager(), tracks, first, last);
 
     // break if aborted
@@ -266,7 +270,7 @@ void ReversePlugin::run(QStringList params)
 	// loop over all tracks
 	for (int track = 0; track < tracks.count(); track++) {
 
-	    ReverseJob *job = new ReverseJob(
+	    Kwave::ReverseJob *job = new Kwave::ReverseJob(
 		signalManager(), tracks[track], first, last, block_size,
 		source_a[track], source_b[track]
 	    );
@@ -293,7 +297,7 @@ void ReversePlugin::run(QStringList params)
 }
 
 //***************************************************************************
-void ReversePlugin::updateProgress(qreal progress)
+void Kwave::ReversePlugin::updateProgress(qreal progress)
 {
     Kwave::Plugin::updateProgress(progress + progress);
 }
