@@ -19,42 +19,44 @@
 
 #include <errno.h>
 
-#include <QByteArray>
-#include <QDir>
-#include <QFile>
-#include <QFileInfo>
-#include <QStringList>
-#include <QRegExp>
+#include <QtCore/QByteArray>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QStringList>
+#include <QtCore/QRegExp>
 
 #include <klocale.h>
 
 #include "libkwave/CodecManager.h"
-#include "libkwave/FileInfo.h"
 #include "libkwave/Label.h"
+#include "libkwave/LabelList.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/MetaDataList.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 
 #include "SaveBlocksDialog.h"
 #include "SaveBlocksPlugin.h"
 
-KWAVE_PLUGIN(SaveBlocksPlugin, "saveblocks", "2.1",
+KWAVE_PLUGIN(Kwave::SaveBlocksPlugin, "saveblocks", "2.3",
              I18N_NOOP("Save Blocks"), "Thomas Eschenbacher");
 
 //***************************************************************************
-SaveBlocksPlugin::SaveBlocksPlugin(const PluginContext &c)
-    :Kwave::Plugin(c), m_url(), m_pattern(), m_numbering_mode(CONTINUE),
+Kwave::SaveBlocksPlugin::SaveBlocksPlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager),
+     m_url(), m_pattern(), m_numbering_mode(CONTINUE),
      m_selection_only(true)
 {
 }
 
 //***************************************************************************
-SaveBlocksPlugin::~SaveBlocksPlugin()
+Kwave::SaveBlocksPlugin::~SaveBlocksPlugin()
 {
 }
 
 //***************************************************************************
-QStringList *SaveBlocksPlugin::setup(QStringList &previous_params)
+QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
 {
     // try to interprete the previous parameters
     interpreteParameters(previous_params);
@@ -72,10 +74,11 @@ QStringList *SaveBlocksPlugin::setup(QStringList &previous_params)
                          (selection_right + 1 >= signalLength()));
     bool enable_selection_only = selected_something && !selected_all;
 
-    SaveBlocksDialog *dialog = new SaveBlocksDialog(
-	":<kwave_save_blocks>", CodecManager::encodingFilter(),
+    Kwave::SaveBlocksDialog *dialog = new Kwave::SaveBlocksDialog(
+	_(":<kwave_save_blocks>"),
+	Kwave::CodecManager::encodingFilter(),
 	parentWidget(), true,
-	url.prettyUrl(), "*.wav",
+	url.prettyUrl(), _("*.wav"),
 	m_pattern,
 	m_numbering_mode,
 	m_selection_only,
@@ -86,9 +89,9 @@ QStringList *SaveBlocksPlugin::setup(QStringList &previous_params)
 
     // connect the signals/slots from the plugin and the dialog
     connect(dialog, SIGNAL(sigSelectionChanged(const QString &,
-	const QString &, SaveBlocksPlugin::numbering_mode_t, bool)),
+	const QString &, Kwave::SaveBlocksPlugin::numbering_mode_t, bool)),
 	this, SLOT(updateExample(const QString &, const QString &,
-	SaveBlocksPlugin::numbering_mode_t, bool)));
+	Kwave::SaveBlocksPlugin::numbering_mode_t, bool)));
     connect(this, SIGNAL(sigNewExample(const QString &)),
 	dialog, SLOT(setNewExample(const QString &)));
 
@@ -103,10 +106,10 @@ QStringList *SaveBlocksPlugin::setup(QStringList &previous_params)
 	// user has pressed "OK"
 	QString pattern, name;
 
-	name = QByteArray(
-	    dialog->selectedUrl().prettyUrl().toUtf8()).toBase64();
-	pattern = QByteArray(
-	    dialog->pattern().toUtf8()).toBase64();
+	name = QLatin1String(QByteArray(
+	    dialog->selectedUrl().prettyUrl().toUtf8()).toBase64());
+	pattern = QLatin1String(QByteArray(
+	    dialog->pattern().toUtf8()).toBase64());
 	int mode = static_cast<int>(dialog->numberingMode());
 	bool selection_only = (enable_selection_only) ?
 	    dialog->selectionOnly() : m_selection_only;
@@ -116,12 +119,10 @@ QStringList *SaveBlocksPlugin::setup(QStringList &previous_params)
 	*list << QString::number(mode);
 	*list << QString::number(selection_only);
 
-	emitCommand("plugin:execute(saveblocks,"+
-	    name+","+
-	    pattern+","+
-	    QString::number(mode)+","+
-	    QString::number(selection_only)+
-	    ")"
+	emitCommand(_("plugin:execute(saveblocks,") +
+	    name + _(",") + pattern + _(",") +
+	    QString::number(mode) + _(",") +
+	    QString::number(selection_only) + _(")")
 	);
     } else {
 	// user pressed "Cancel"
@@ -134,7 +135,7 @@ QStringList *SaveBlocksPlugin::setup(QStringList &previous_params)
 }
 
 //***************************************************************************
-int SaveBlocksPlugin::start(QStringList &params)
+int Kwave::SaveBlocksPlugin::start(QStringList &params)
 {
     qDebug("SaveBlocksPlugin::start()");
 
@@ -145,7 +146,6 @@ int SaveBlocksPlugin::start(QStringList &params)
     QString filename = m_url.prettyUrl();
     QFileInfo file(filename);
     QString path = file.absolutePath();
-    QString name = file.fileName();
     QString ext  = file.suffix();
     QString base = findBase(filename, m_pattern);
 
@@ -180,14 +180,15 @@ int SaveBlocksPlugin::start(QStringList &params)
 
     // check for filenames that might be overwritten
     const int max_overwrite_list_length = 7;
-    QDir dir(path, "*");
+    QDir dir(path, _("*"));
     QStringList files;
     files = dir.entryList();
     QStringList overwritten;
     for (unsigned int i = first; i < first+count; i++) {
 	QString name = createFileName(base, ext, m_pattern, i, count,
 	                              first + count - 1);
-	QRegExp rx("^(" + QRegExp::escape(name) + ")$", Qt::CaseInsensitive);
+	QRegExp rx(_("^(") + QRegExp::escape(name) + _(")$"),
+	           Qt::CaseInsensitive);
 	QStringList matches = files.filter(rx);
 	if (matches.count() > 0) {
 	    overwritten += name;
@@ -198,24 +199,24 @@ int SaveBlocksPlugin::start(QStringList &params)
     if (overwritten.count()) {
 	// ask the user for confirmation if he really wants to overwrite...
 
-	QString list = "<br><br>";
+	QString list = _("<br><br>");
 	int cnt = 0;
 	for (QStringList::Iterator it = overwritten.begin();
 	     it != overwritten.end() && (cnt <= max_overwrite_list_length);
 	     ++it, ++cnt)
 	{
 	    list += (*it);
-	    list += "<br>";
+	    list += _("<br>");
 	}
 	if (overwritten.count() > max_overwrite_list_length)
 	    list += i18n("...");
-	list += "<br>";
+	list += _("<br>");
 
 	if (Kwave::MessageBox::warningYesNo(parentWidget(),
-	    "<html>" +
+	    _("<html>") +
 	    i18n("This would overwrite the following file(s): %1" \
 	    "Do you really want to continue?",
-	    list) + "</html>") != KMessageBox::Yes)
+	    list) + _("</html>")) != KMessageBox::Yes)
 	{
 	    return -1;
 	}
@@ -229,9 +230,9 @@ int SaveBlocksPlugin::start(QStringList &params)
     // now we can loop over all blocks and save them
     sample_index_t block_start;
     sample_index_t block_end = 0;
-    LabelList labels(signalManager().metaData());
-    LabelListIterator it(labels);
-    Label label = it.hasNext() ? it.next() : Label();
+    Kwave::LabelList labels(signalManager().metaData());
+    Kwave::LabelListIterator it(labels);
+    Kwave::Label label = it.hasNext() ? it.next() : Kwave::Label();
 
     for (unsigned int index = first;;) {
 	block_start = block_end;
@@ -261,7 +262,7 @@ int SaveBlocksPlugin::start(QStringList &params)
 	    qDebug("saving %9lu...%9lu -> '%s'",
 		   static_cast<unsigned long int>(left),
 		   static_cast<unsigned long int>(right),
-		   filename.toLocal8Bit().data());
+		   DBG(filename));
 	    if (signalManager().save(url, true) < 0)
 		break;
 
@@ -269,7 +270,7 @@ int SaveBlocksPlugin::start(QStringList &params)
 	    index++;
 	}
 	if (label.isNull()) break;
-	label = (it.hasNext()) ? it.next() : Label();
+	label = (it.hasNext()) ? it.next() : Kwave::Label();
     }
 
     // restore the previous selection
@@ -281,7 +282,7 @@ int SaveBlocksPlugin::start(QStringList &params)
 }
 
 //***************************************************************************
-int SaveBlocksPlugin::interpreteParameters(QStringList &params)
+int Kwave::SaveBlocksPlugin::interpreteParameters(QStringList &params)
 {
     bool ok;
     QString param;
@@ -319,16 +320,16 @@ int SaveBlocksPlugin::interpreteParameters(QStringList &params)
 }
 
 //***************************************************************************
-unsigned int SaveBlocksPlugin::blocksToSave(bool selection_only)
+unsigned int Kwave::SaveBlocksPlugin::blocksToSave(bool selection_only)
 {
     unsigned int count = 0;
     sample_index_t selection_left, selection_right;
 
     sample_index_t block_start;
     sample_index_t block_end = 0;
-    LabelList labels(signalManager().metaData());
-    LabelListIterator it(labels);
-    Label label = (it.hasNext()) ? it.next() : Label();
+    Kwave::LabelList labels(signalManager().metaData());
+    Kwave::LabelListIterator it(labels);
+    Kwave::Label label = (it.hasNext()) ? it.next() : Kwave::Label();
 
     if (selection_only) {
 	selection(0, &selection_left, &selection_right, true);
@@ -342,14 +343,14 @@ unsigned int SaveBlocksPlugin::blocksToSave(bool selection_only)
 	if ((selection_left < block_end) && (selection_right > block_start))
 	    count++;
 	if (label.isNull()) break;
-	label = (it.hasNext()) ? it.next() : Label();
+	label = (it.hasNext()) ? it.next() : Kwave::Label();
     }
 
     return count;
 }
 
 //***************************************************************************
-QString SaveBlocksPlugin::createFileName(const QString &base,
+QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
     const QString &ext, const QString &pattern,
     unsigned int index, int count, int total)
 {
@@ -357,51 +358,51 @@ QString SaveBlocksPlugin::createFileName(const QString &base,
     QString nr;
 
     // format the "index" parameter
-    QRegExp rx_nr("(\\\\\\[%\\d*nr\\\\\\])", Qt::CaseInsensitive);
+    QRegExp rx_nr(_("(\\\\\\[%\\d*nr\\\\\\])"), Qt::CaseInsensitive);
     while (rx_nr.indexIn(p) >= 0) {
 	QString format = rx_nr.cap(1);
-	format = format.mid(2, format.length() - 6) + "u";
+	format = format.mid(2, format.length() - 6) + _("u");
 	p.replace(rx_nr, nr.sprintf(format.toAscii(), index));
     }
 
     // format the "count" parameter
-    QRegExp rx_count("(\\\\\\[%\\d*count\\\\\\])", Qt::CaseInsensitive);
+    QRegExp rx_count(_("(\\\\\\[%\\d*count\\\\\\])"), Qt::CaseInsensitive);
     while (rx_count.indexIn(p) >= 0) {
 	if (count >= 0) {
 	    QString format = rx_count.cap(1);
-	    format = format.mid(2, format.length() - 9) + "u";
+	    format = format.mid(2, format.length() - 9) + _("u");
 	    p.replace(rx_count, nr.sprintf(format.toAscii(), count));
 	} else {
-	    p.replace(rx_count, "(\\d+)");
+	    p.replace(rx_count, _("(\\d+)"));
 	}
     }
 
     // format the "total" parameter
-    QRegExp rx_total("(\\\\\\[%\\d*total\\\\\\])", Qt::CaseInsensitive);
+    QRegExp rx_total(_("(\\\\\\[%\\d*total\\\\\\])"), Qt::CaseInsensitive);
     while (rx_total.indexIn(p) >= 0) {
 	if (total >= 0) {
 	    QString format = rx_total.cap(1);
-	    format = format.mid(2, format.length() - 9) + "u";
+	    format = format.mid(2, format.length() - 9) + _("u");
 	    p.replace(rx_total, nr.sprintf(format.toAscii(), total));
 	} else {
-	    p.replace(rx_total, "(\\d+)");
+	    p.replace(rx_total, _("(\\d+)"));
 	}
     }
 
     // format the "filename" parameter
-    QRegExp rx_filename("\\\\\\[%filename\\\\\\]", Qt::CaseInsensitive);
+    QRegExp rx_filename(_("\\\\\\[%filename\\\\\\]"), Qt::CaseInsensitive);
     if (rx_filename.indexIn(p) >= 0) {
 	p.replace(rx_filename, QRegExp::escape(base));
     }
 
-    if (ext.length()) p += "." + ext;
+    if (ext.length()) p += _(".") + ext;
     return p;
 }
 
 //***************************************************************************
-unsigned int SaveBlocksPlugin::firstIndex(const QString &path,
+unsigned int Kwave::SaveBlocksPlugin::firstIndex(const QString &path,
     const QString &base, const QString &ext, const QString &pattern,
-    SaveBlocksPlugin::numbering_mode_t mode, unsigned int count)
+    Kwave::SaveBlocksPlugin::numbering_mode_t mode, unsigned int count)
 {
     unsigned int first = 1;
     switch (mode) {
@@ -409,12 +410,13 @@ unsigned int SaveBlocksPlugin::firstIndex(const QString &path,
 	    first = 1;
 	    break;
 	case CONTINUE: {
-	    QDir dir(path, "*");
+	    QDir dir(path, _("*"));
 	    QStringList files;
 	    files = dir.entryList();
 	    for (unsigned int i = first; i < first+count; i++) {
 		QString name = createFileName(base, ext, pattern, i, -1, -1);
-		QRegExp rx("^(" + name + ")$", Qt::CaseInsensitive);
+		QRegExp rx(_("^(") + name + _(")$"),
+		           Qt::CaseInsensitive);
 		QStringList matches = files.filter(rx);
 		if (matches.count() > 0) first = i + 1;
 	    }
@@ -426,11 +428,10 @@ unsigned int SaveBlocksPlugin::firstIndex(const QString &path,
 }
 
 //***************************************************************************
-QString SaveBlocksPlugin::findBase(const QString &filename,
-                                   const QString &pattern)
+QString Kwave::SaveBlocksPlugin::findBase(const QString &filename,
+                                          const QString &pattern)
 {
     QFileInfo file(filename);
-    QString path = file.absolutePath();
     QString name = file.fileName();
     QString base = file.completeBaseName();
     QString ext  = file.suffix();
@@ -441,20 +442,20 @@ QString SaveBlocksPlugin::findBase(const QString &filename,
     // \[%[0-9]?count\]   -> \d+
     // \[%[0-9]?total\]   -> \d+
     // \[%filename\]      -> base
-    QRegExp rx_nr("\\\\\\[%\\d*nr\\\\\\]", Qt::CaseInsensitive);
-    QRegExp rx_count("\\\\\\[%\\d*count\\\\\\]", Qt::CaseInsensitive);
-    QRegExp rx_total("\\\\\\[%\\d*total\\\\\\]", Qt::CaseInsensitive);
-    QRegExp rx_filename("\\\\\\[%filename\\\\\\]", Qt::CaseInsensitive);
+    QRegExp rx_nr(_("\\\\\\[%\\d*nr\\\\\\]"), Qt::CaseInsensitive);
+    QRegExp rx_count(_("\\\\\\[%\\d*count\\\\\\]"), Qt::CaseInsensitive);
+    QRegExp rx_total(_("\\\\\\[%\\d*total\\\\\\]"), Qt::CaseInsensitive);
+    QRegExp rx_filename(_("\\\\\\[%filename\\\\\\]"), Qt::CaseInsensitive);
 
     QString p = QRegExp::escape(pattern);
     int idx_nr = rx_nr.indexIn(p);
     int idx_count = rx_count.indexIn(p);
     int idx_total = rx_total.indexIn(p);
     int idx_filename = rx_filename.indexIn(p);
-    p.replace(rx_nr, "(\\d+)");
-    p.replace(rx_count, "(\\d+)");
-    p.replace(rx_total, "(\\d+)");
-    p.replace(rx_filename, "(.+)");
+    p.replace(rx_nr, _("(\\d+)"));
+    p.replace(rx_count, _("(\\d+)"));
+    p.replace(rx_total, _("(\\d+)"));
+    p.replace(rx_filename, _("(.+)"));
 
     int max = 0;
     for (int i=0; i < pattern.length(); i++) {
@@ -468,7 +469,7 @@ QString SaveBlocksPlugin::findBase(const QString &filename,
 	if (idx_filename > max) idx_filename--;
     }
 
-    if (ext.length()) p += "." + ext;
+    if (ext.length()) p += _(".") + ext;
     QRegExp rx_current(p, Qt::CaseInsensitive);
     if (rx_current.indexIn(name) >= 0) {
 	// filename already produced by this pattern
@@ -479,13 +480,12 @@ QString SaveBlocksPlugin::findBase(const QString &filename,
 }
 
 //***************************************************************************
-QString SaveBlocksPlugin::firstFileName(const QString &filename,
-    const QString &pattern, SaveBlocksPlugin::numbering_mode_t mode,
+QString Kwave::SaveBlocksPlugin::firstFileName(const QString &filename,
+    const QString &pattern, Kwave::SaveBlocksPlugin::numbering_mode_t mode,
     bool selection_only)
 {
     QFileInfo file(filename);
     QString path = file.absolutePath();
-    QString name = file.fileName();
     QString ext  = file.suffix();
     QString base = findBase(filename, pattern);
 
@@ -502,15 +502,15 @@ QString SaveBlocksPlugin::firstFileName(const QString &filename,
 //***************************************************************************
 static QString unescape(const QString &s)
 {
-    QRegExp rx_single("\\\\(?!\\\\)");
+    QRegExp rx_single(_("\\\\(?!\\\\)"));
     QString str = s;
-    str.replace(rx_single, "");
+    str.replace(rx_single, _(""));
     return str;
 }
 
 //***************************************************************************
-void SaveBlocksPlugin::updateExample(const QString &filename,
-    const QString &pattern, SaveBlocksPlugin::numbering_mode_t mode,
+void Kwave::SaveBlocksPlugin::updateExample(const QString &filename,
+    const QString &pattern, Kwave::SaveBlocksPlugin::numbering_mode_t mode,
     bool selection_only)
 {
     QString example = firstFileName(filename, pattern, mode, selection_only);
