@@ -19,34 +19,38 @@
 #include <errno.h>
 #include <math.h>
 
-#include <QString>
+#include <QtCore/QString>
 #include <klocale.h>
 
-#include "libkwave/KwavePlugin.h"
+#include "libkwave/Plugin.h"
 #include "libkwave/PluginManager.h"
+#include "libkwave/String.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
 
 #include "SelectRangePlugin.h"
 #include "SelectRangeDialog.h"
 
-KWAVE_PLUGIN(SelectRangePlugin, "selectrange", "2.1",
+KWAVE_PLUGIN(Kwave::SelectRangePlugin, "selectrange", "2.3",
              I18N_NOOP("Select Range"), "Thomas Eschenbacher");
 
 //***************************************************************************
-SelectRangePlugin::SelectRangePlugin(const PluginContext &c)
-    :Kwave::Plugin(c), m_start_mode(SelectTimeWidget::bySamples),
-     m_range_mode(SelectTimeWidget::bySamples), m_range(0)
+Kwave::SelectRangePlugin::SelectRangePlugin(
+    Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager),
+     m_start_mode(Kwave::SelectTimeWidget::bySamples),
+     m_range_mode(Kwave::SelectTimeWidget::bySamples),
+     m_start(0), m_range(0)
 {
 }
 
 //***************************************************************************
-SelectRangePlugin::~SelectRangePlugin()
+Kwave::SelectRangePlugin::~SelectRangePlugin()
 {
 }
 
 //***************************************************************************
-QStringList *SelectRangePlugin::setup(QStringList &previous_params)
+QStringList *Kwave::SelectRangePlugin::setup(QStringList &previous_params)
 {
     // try to interprete the previous parameters
     interpreteParameters(previous_params);
@@ -56,8 +60,9 @@ QStringList *SelectRangePlugin::setup(QStringList &previous_params)
     sample_index_t offset = manager().selectionStart();
     sample_index_t length = signalLength();
 
-    SelectRangeDialog *dialog = new SelectRangeDialog(parentWidget(),
-        m_start_mode, m_range_mode, m_range, rate, offset, length);
+    Kwave::SelectRangeDialog *dialog =
+	new Kwave::SelectRangeDialog(parentWidget(),
+	    m_start_mode, m_range_mode, m_range, rate, offset, length);
     Q_ASSERT(dialog);
     if (!dialog) return 0;
 
@@ -70,12 +75,12 @@ QStringList *SelectRangePlugin::setup(QStringList &previous_params)
 	*list << QString::number(dialog->start());
 	*list << QString::number(dialog->range());
 
-	emitCommand("plugin:execute(selectrange,"+
-	    QString::number(dialog->startMode())+","+
-	    QString::number(dialog->rangeMode())+","+
-	    QString::number(dialog->start())+","+
+	emitCommand(_("plugin:execute(selectrange,") +
+	    QString::number(dialog->startMode()) + _(",") +
+	    QString::number(dialog->rangeMode()) + _(",") +
+	    QString::number(dialog->start()) + _(",") +
 	    QString::number(dialog->range())+
-	    ")"
+	    _(")")
 	);
     } else {
 	// user pressed "Cancel"
@@ -88,18 +93,18 @@ QStringList *SelectRangePlugin::setup(QStringList &previous_params)
 }
 
 //***************************************************************************
-int SelectRangePlugin::start(QStringList &params)
+int Kwave::SelectRangePlugin::start(QStringList &params)
 {
     // interprete the parameters
     int result = interpreteParameters(params);
     if (result) return result;
 
     // get current offset of the signal
-    sample_index_t offset = SelectTimeWidget::timeToSamples(
+    sample_index_t offset = Kwave::SelectTimeWidget::timeToSamples(
 	m_start_mode, m_start, signalRate(), signalLength());
 
     // transform into offset and length [samples]
-    sample_index_t length = SelectTimeWidget::timeToSamples(
+    sample_index_t length = Kwave::SelectTimeWidget::timeToSamples(
 	m_range_mode, m_range, signalRate(), signalLength());
 
     // limit selection to end of signal
@@ -108,7 +113,7 @@ int SelectRangePlugin::start(QStringList &params)
 
     // change the selection through the signal manager
     {
-	UndoTransactionGuard undo_guard(*this, i18n("Select Range"));
+	Kwave::UndoTransactionGuard undo_guard(*this, i18n("Select Range"));
 	selectRange(offset, length);
     }
 
@@ -116,7 +121,7 @@ int SelectRangePlugin::start(QStringList &params)
 }
 
 //***************************************************************************
-int SelectRangePlugin::interpreteParameters(QStringList &params)
+int Kwave::SelectRangePlugin::interpreteParameters(QStringList &params)
 {
     bool ok;
     QString param;
@@ -132,16 +137,18 @@ int SelectRangePlugin::interpreteParameters(QStringList &params)
     mode = param.toInt(&ok);
     Q_ASSERT(ok);
     if (!ok) return -EINVAL;
-    Q_ASSERT((mode == static_cast<int>(SelectTimeWidget::byTime)) ||
-           (mode == static_cast<int>(SelectTimeWidget::bySamples)) ||
-           (mode == static_cast<int>(SelectTimeWidget::byPercents)));
-    if ((mode != static_cast<int>(SelectTimeWidget::byTime)) &&
-        (mode != static_cast<int>(SelectTimeWidget::bySamples)) &&
-        (mode != static_cast<int>(SelectTimeWidget::byPercents)))
+    Q_ASSERT(
+        (mode == static_cast<int>(Kwave::SelectTimeWidget::byTime)) ||
+        (mode == static_cast<int>(Kwave::SelectTimeWidget::bySamples)) ||
+        (mode == static_cast<int>(Kwave::SelectTimeWidget::byPercents))
+    );
+    if ((mode != static_cast<int>(Kwave::SelectTimeWidget::byTime)) &&
+        (mode != static_cast<int>(Kwave::SelectTimeWidget::bySamples)) &&
+        (mode != static_cast<int>(Kwave::SelectTimeWidget::byPercents)))
     {
 	return -EINVAL;
     }
-    m_start_mode = static_cast<SelectTimeWidget::Mode>(mode);
+    m_start_mode = static_cast<Kwave::SelectTimeWidget::Mode>(mode);
 
 
     // selection mode
@@ -149,16 +156,18 @@ int SelectRangePlugin::interpreteParameters(QStringList &params)
     mode = param.toInt(&ok);
     Q_ASSERT(ok);
     if (!ok) return -EINVAL;
-    Q_ASSERT((mode == static_cast<int>(SelectTimeWidget::byTime)) ||
-           (mode == static_cast<int>(SelectTimeWidget::bySamples)) ||
-           (mode == static_cast<int>(SelectTimeWidget::byPercents)));
-    if ((mode != static_cast<int>(SelectTimeWidget::byTime)) &&
-        (mode != static_cast<int>(SelectTimeWidget::bySamples)) &&
-        (mode != static_cast<int>(SelectTimeWidget::byPercents)))
+    Q_ASSERT(
+        (mode == static_cast<int>(Kwave::SelectTimeWidget::byTime)) ||
+        (mode == static_cast<int>(Kwave::SelectTimeWidget::bySamples)) ||
+        (mode == static_cast<int>(Kwave::SelectTimeWidget::byPercents))
+    );
+    if ((mode != static_cast<int>(Kwave::SelectTimeWidget::byTime)) &&
+        (mode != static_cast<int>(Kwave::SelectTimeWidget::bySamples)) &&
+        (mode != static_cast<int>(Kwave::SelectTimeWidget::byPercents)))
     {
 	return -EINVAL;
     }
-    m_range_mode = static_cast<SelectTimeWidget::Mode>(mode);
+    m_range_mode = static_cast<Kwave::SelectTimeWidget::Mode>(mode);
 
     // offset in ms, samples or percent
     param = params[2];
