@@ -21,29 +21,30 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <QButtonGroup>
-#include <QCheckBox>
-#include <QComboBox>
-#include <QLabel>
-#include <QLayout>
-#include <QPushButton>
-#include <QRadioButton>
-#include <QSlider>
-#include <QString>
-#include <QStringList>
+#include <QtGui/QButtonGroup>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QRadioButton>
+#include <QtGui/QSlider>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 
 #include <kcombobox.h>
 #include <klocale.h>
+#include <kpushbutton.h>
 #include <ktoolinvocation.h>
 
-#include "libkwave/KwavePlugin.h"
+#include "libkwave/Plugin.h"
+#include "libkwave/String.h"
 #include "libkwave/WindowFunction.h"
 #include "libkwave/Utils.h"
 
 #include "SonagramDialog.h"
 
 //***************************************************************************
-SonagramDialog::SonagramDialog(Kwave::Plugin &p)
+Kwave::SonagramDialog::SonagramDialog(Kwave::Plugin &p)
     :QDialog(p.parentWidget()), Ui::SonagramDlg(),
     m_length(p.selection(0, 0, 0,true)), m_rate(p.signalRate())
 {
@@ -59,9 +60,9 @@ SonagramDialog::SonagramDialog(Kwave::Plugin &p)
 
     pointslider->setMaximum(m_length / 16);
 
-    window_function_t wf = WINDOW_FUNC_NONE;
-    for (unsigned int i=0; i < WindowFunction::count(); i++) {
-	windowtypebox->addItem(WindowFunction::description(wf, true));
+    Kwave::window_function_t wf = Kwave::WINDOW_FUNC_NONE;
+    for (unsigned int i=0; i < Kwave::WindowFunction::count(); i++) {
+	windowtypebox->addItem(Kwave::WindowFunction::description(wf, true));
 	++wf;
     }
 
@@ -88,15 +89,19 @@ SonagramDialog::SonagramDialog(Kwave::Plugin &p)
     setPoints(1 << (bits-1));
     setBoxPoints(0);
 
-    connect(btOK,        SIGNAL(clicked()),         SLOT(accept()));
-    connect(btCancel,    SIGNAL(clicked()),         SLOT(reject()));
-    connect(btHelp,      SIGNAL(clicked()),         SLOT(invokeHelp()));
+    connect(
+	buttonBox->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+	this,                                      SLOT(invokeHelp())
+    );
     connect(pointslider, SIGNAL(valueChanged(int)), SLOT(setPoints(int)));
     connect(pointbox,    SIGNAL(activated(int)),    SLOT(setBoxPoints(int)));
+
+    // set the focus onto the "OK" button
+    buttonBox->button(QDialogButtonBox::Ok)->setFocus();
 }
 
 //***************************************************************************
-void SonagramDialog::parameters(QStringList &list)
+void Kwave::SonagramDialog::parameters(QStringList &list)
 {
     Q_ASSERT(pointbox);
     Q_ASSERT(windowtypebox);
@@ -110,9 +115,9 @@ void SonagramDialog::parameters(QStringList &list)
     list.append(param);
 
     // parameter #1: index of the window function
-    window_function_t wf = WindowFunction::findFromIndex(
+    Kwave::window_function_t wf = Kwave::WindowFunction::findFromIndex(
     	(windowtypebox) ? windowtypebox->currentIndex() : 0);
-    param = WindowFunction::name(wf);
+    param = Kwave::WindowFunction::name(wf);
     list.append(param);
 
     // parameter #2: flag: use color instead of greyscale
@@ -132,7 +137,7 @@ void SonagramDialog::parameters(QStringList &list)
 }
 
 //***************************************************************************
-void SonagramDialog::setPoints(int points)
+void Kwave::SonagramDialog::setPoints(int points)
 {
     Q_ASSERT(points >= 0);
     QString text;
@@ -150,15 +155,15 @@ void SonagramDialog::setPoints(int points)
 }
 
 //***************************************************************************
-void SonagramDialog::setWindowFunction(window_function_t type)
+void Kwave::SonagramDialog::setWindowFunction(Kwave::window_function_t type)
 {
     Q_ASSERT(windowtypebox);
     if (!windowtypebox) return;
-    windowtypebox->setCurrentIndex(WindowFunction::index(type));
+    windowtypebox->setCurrentIndex(Kwave::WindowFunction::index(type));
 }
 
 //***************************************************************************
-void SonagramDialog::setColorMode(int color)
+void Kwave::SonagramDialog::setColorMode(int color)
 {
     Q_ASSERT(rbColor);
     if (!rbColor) return;
@@ -168,7 +173,7 @@ void SonagramDialog::setColorMode(int color)
 }
 
 //***************************************************************************
-void SonagramDialog::setTrackChanges(bool track_changes)
+void Kwave::SonagramDialog::setTrackChanges(bool track_changes)
 {
     Q_ASSERT(cbTrackChanges);
     if (!cbTrackChanges) return;
@@ -176,7 +181,7 @@ void SonagramDialog::setTrackChanges(bool track_changes)
 }
 
 //***************************************************************************
-void SonagramDialog::setFollowSelection(bool follow_selection)
+void Kwave::SonagramDialog::setFollowSelection(bool follow_selection)
 {
     Q_ASSERT(cbFollowSelection);
     if (!cbFollowSelection) return;
@@ -184,7 +189,7 @@ void SonagramDialog::setFollowSelection(bool follow_selection)
 }
 
 //***************************************************************************
-void SonagramDialog::setBoxPoints(int num)
+void Kwave::SonagramDialog::setBoxPoints(int num)
 {
     Q_ASSERT(num >= 0);
     int points = pointbox->itemText(num).toInt();
@@ -192,14 +197,14 @@ void SonagramDialog::setBoxPoints(int num)
 }
 
 //***************************************************************************
-SonagramDialog::~SonagramDialog ()
+Kwave::SonagramDialog::~SonagramDialog ()
 {
 }
 
 //***************************************************************************
-void SonagramDialog::invokeHelp()
+void Kwave::SonagramDialog::invokeHelp()
 {
-    KToolInvocation::invokeHelp("sonagram");
+    KToolInvocation::invokeHelp(_("sonagram"));
 }
 
 //***************************************************************************
