@@ -19,8 +19,8 @@
 #include <math.h>
 #include <klocale.h> // for the i18n macro
 
-#include <QList>
-#include <QStringList>
+#include <QtCore/QList>
+#include <QtCore/QStringList>
 
 #include "libkwave/MultiTrackWriter.h"
 #include "libkwave/PluginManager.h"
@@ -31,30 +31,30 @@
 
 #include "ZeroPlugin.h"
 
-KWAVE_PLUGIN(ZeroPlugin, "zero", "2.1",
+KWAVE_PLUGIN(Kwave::ZeroPlugin, "zero", "2.3",
              I18N_NOOP("Zero Generator"), "Thomas Eschenbacher");
 
 #define ZERO_COUNT (64 * 1024)
 
 //***************************************************************************
-ZeroPlugin::ZeroPlugin(const PluginContext &context)
-    :Kwave::Plugin(context), m_zeroes()
+Kwave::ZeroPlugin::ZeroPlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager), m_zeroes()
 {
 }
 
 //***************************************************************************
-ZeroPlugin::~ZeroPlugin()
+Kwave::ZeroPlugin::~ZeroPlugin()
 {
 }
 
 //***************************************************************************
-void ZeroPlugin::run(QStringList params)
+void Kwave::ZeroPlugin::run(QStringList params)
 {
     QList<unsigned int> tracks;
     sample_index_t first = 0;
     sample_index_t last  = 0;
 
-    UndoTransactionGuard undo_guard(*this, i18n("Silence"));
+    Kwave::UndoTransactionGuard undo_guard(*this, i18n("Silence"));
 
     Kwave::MultiTrackWriter *writers = 0;
 
@@ -71,12 +71,14 @@ void ZeroPlugin::run(QStringList params)
 	int mode = params[0].toInt(&ok);
 	Q_ASSERT(ok);
 	if (!ok) return;
-	Q_ASSERT((mode == static_cast<int>(SelectTimeWidget::byTime)) ||
-	         (mode == static_cast<int>(SelectTimeWidget::bySamples)) ||
-	         (mode == static_cast<int>(SelectTimeWidget::byPercents)));
-	if ((mode != static_cast<int>(SelectTimeWidget::byTime)) &&
-	    (mode != static_cast<int>(SelectTimeWidget::bySamples)) &&
-	    (mode != static_cast<int>(SelectTimeWidget::byPercents)))
+	Q_ASSERT(
+	    (mode == static_cast<int>(Kwave::SelectTimeWidget::byTime)) ||
+	    (mode == static_cast<int>(Kwave::SelectTimeWidget::bySamples)) ||
+	    (mode == static_cast<int>(Kwave::SelectTimeWidget::byPercents))
+	);
+	if ((mode != static_cast<int>(Kwave::SelectTimeWidget::byTime)) &&
+	    (mode != static_cast<int>(Kwave::SelectTimeWidget::bySamples)) &&
+	    (mode != static_cast<int>(Kwave::SelectTimeWidget::byPercents)))
 	{
 	    return;
 	}
@@ -87,8 +89,8 @@ void ZeroPlugin::run(QStringList params)
 	if (!ok) return;
 
 	// convert from time to samples
-	unsigned int length = SelectTimeWidget::timeToSamples(
-	    static_cast<SelectTimeWidget::Mode>(mode),
+	unsigned int length = Kwave::SelectTimeWidget::timeToSamples(
+	    static_cast<Kwave::SelectTimeWidget::Mode>(mode),
 	    time, signalRate(), signalLength());
 
 	// some sanity check
@@ -98,9 +100,9 @@ void ZeroPlugin::run(QStringList params)
 
 	last  = first + length - 1;
 	writers = new Kwave::MultiTrackWriter(signalManager(),
-	    tracks, Insert, first, last);
+	    tracks, Kwave::Insert, first, last);
     } else {
-	writers = new Kwave::MultiTrackWriter(signalManager(), Overwrite);
+	writers = new Kwave::MultiTrackWriter(signalManager(), Kwave::Overwrite);
     }
 
     Q_ASSERT(writers);
